@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class Abdomen(PhysicalExam):
     """Abdomen clinical examination.
 
-    See https://schema.org/Abdomen.
-
+    See: https://schema.org/Abdomen
+    Model depth: 5
     """
-    type_: str = Field("Abdomen", const=True, alias='@type')
+    type_: str = Field(default="Abdomen", alias='@type')
     
-
-Abdomen.update_forward_refs()
