@@ -12,6 +12,5 @@ class AcceptAction(AllocateAction):
     See: https://schema.org/AcceptAction
     Model depth: 5
     """
-    type_: str = Field("AcceptAction", alias='@type')
+    type_: str = Field(default="AcceptAction", alias='@type')
     
-
