@@ -20,7 +20,7 @@ class Accommodation(Place):
     See: https://schema.org/Accommodation
     Model depth: 3
     """
-    type_: str = Field("Accommodation", alias='@type')
+    type_: str = Field(default="Accommodation", alias='@type')
     numberOfBedrooms: Optional[Union[List[Union[Decimal, 'Number', 'QuantitativeValue', str]], Decimal, 'Number', 'QuantitativeValue', str]] = Field(
         default=None,
         description="The total integer number of bedrooms in a some [[Accommodation]], [[ApartmentComplex]]"
@@ -103,7 +103,6 @@ class Accommodation(Place):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
