@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FinancialService import FinancialService
 
@@ -6,10 +9,8 @@ class AccountingService(FinancialService):
     """Accountancy business. As a [[LocalBusiness]] it can be described as a [[provider]]"
      "of one or more [[Service]]\(s).
 
-    See https://schema.org/AccountingService.
-
+    See: https://schema.org/AccountingService
+    Model depth: 5
     """
-    type_: str = Field("AccountingService", const=True, alias='@type')
+    type_: str = Field(default="AccountingService", alias='@type')
     
-
-AccountingService.update_forward_refs()
