@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Action import Action
 
@@ -6,10 +9,8 @@ class AchieveAction(Action):
     """The act of accomplishing something via previous efforts. It is an instantaneous action"
      "rather than an ongoing process.
 
-    See https://schema.org/AchieveAction.
-
+    See: https://schema.org/AchieveAction
+    Model depth: 3
     """
-    type_: str = Field("AchieveAction", const=True, alias='@type')
+    type_: str = Field(default="AchieveAction", alias='@type')
     
-
-AchieveAction.update_forward_refs()
