@@ -20,7 +20,7 @@ class Action(Thing):
     See: https://schema.org/Action
     Model depth: 2
     """
-    type_: str = Field("Action", alias='@type')
+    type_: str = Field(default="Action", alias='@type')
     result: Optional[Union[List[Union['Thing', str]], 'Thing', str]] = Field(
         default=None,
         description="The result produced in the action. e.g. John wrote *a book*.",
@@ -40,7 +40,7 @@ class Action(Thing):
         default=None,
         description="For failed actions, more information on the cause of the failure.",
     )
-    location: Optional[Union[List[Union[str, 'Text', 'Place', 'VirtualLocation', 'PostalAddress']], str, 'Text', 'Place', 'VirtualLocation', 'PostalAddress']] = Field(
+    location: Optional[Union[List[Union[str, 'Text', 'VirtualLocation', 'PostalAddress', 'Place']], str, 'Text', 'VirtualLocation', 'PostalAddress', 'Place']] = Field(
         default=None,
         description="The location of, for example, where an event is happening, where an organization is located,"
      "or where an action takes place.",
@@ -82,15 +82,14 @@ class Action(Thing):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.Text import Text
-    from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.VirtualLocation import VirtualLocation
     from pydantic_schemaorg.PostalAddress import PostalAddress
+    from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.DateTime import DateTime
     from pydantic_schemaorg.Time import Time
     from pydantic_schemaorg.EntryPoint import EntryPoint
