@@ -17,13 +17,13 @@ class ActionAccessSpecification(Intangible):
     See: https://schema.org/ActionAccessSpecification
     Model depth: 3
     """
-    type_: str = Field("ActionAccessSpecification", alias='@type')
-    category: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text', 'Thing', 'PhysicalActivityCategory']], AnyUrl, 'URL', str, 'Text', 'Thing', 'PhysicalActivityCategory']] = Field(
+    type_: str = Field(default="ActionAccessSpecification", alias='@type')
+    category: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text', 'PhysicalActivityCategory', 'Thing']], AnyUrl, 'URL', str, 'Text', 'PhysicalActivityCategory', 'Thing']] = Field(
         default=None,
         description="A category for the item. Greater signs or slashes can be used to informally indicate a"
      "category hierarchy.",
     )
-    availabilityStarts: Optional[Union[List[Union[ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]], ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]] = Field(
+    availabilityStarts: Optional[Union[List[Union[ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]], ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]] = Field(
         default=None,
         description="The beginning of the availability of the product or service included in the offer.",
     )
@@ -43,7 +43,7 @@ class ActionAccessSpecification(Intangible):
         description="An Offer which must be accepted before the user can perform the Action. For example, the"
      "user may need to buy a movie before being able to watch it.",
     )
-    availabilityEnds: Optional[Union[List[Union[ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]], ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]] = Field(
+    availabilityEnds: Optional[Union[List[Union[ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]], ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]] = Field(
         default=None,
         description="The end of the availability of the product or service included in the offer.",
     )
@@ -55,15 +55,14 @@ class ActionAccessSpecification(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.Text import Text
-    from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
+    from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.DateTime import DateTime
-    from pydantic_schemaorg.Date import Date
     from pydantic_schemaorg.Time import Time
+    from pydantic_schemaorg.Date import Date
     from pydantic_schemaorg.GeoShape import GeoShape
     from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.Boolean import Boolean
