@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ControlAction import ControlAction
 
@@ -6,10 +9,8 @@ class ActivateAction(ControlAction):
     """The act of starting or activating a device or application (e.g. starting a timer or turning"
      "on a flashlight).
 
-    See https://schema.org/ActivateAction.
-
+    See: https://schema.org/ActivateAction
+    Model depth: 4
     """
-    type_: str = Field("ActivateAction", const=True, alias='@type')
+    type_: str = Field(default="ActivateAction", alias='@type')
     
-
-ActivateAction.update_forward_refs()
