@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 class ActiveNotRecruiting(MedicalStudyStatus):
     """Active, but not recruiting new participants.
 
-    See https://schema.org/ActiveNotRecruiting.
-
+    See: https://schema.org/ActiveNotRecruiting
+    Model depth: 6
     """
-    type_: str = Field("ActiveNotRecruiting", const=True, alias='@type')
+    type_: str = Field(default="ActiveNotRecruiting", alias='@type')
     
-
-ActiveNotRecruiting.update_forward_refs()
