@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Article import Article
 
@@ -7,10 +10,8 @@ class AdvertiserContentArticle(Article):
      "Includes [advertorials](https://en.wikipedia.org/wiki/Advertorial), sponsored"
      "content, native advertising and other paid content.
 
-    See https://schema.org/AdvertiserContentArticle.
-
+    See: https://schema.org/AdvertiserContentArticle
+    Model depth: 4
     """
-    type_: str = Field("AdvertiserContentArticle", const=True, alias='@type')
+    type_: str = Field(default="AdvertiserContentArticle", alias='@type')
     
-
-AdvertiserContentArticle.update_forward_refs()
