@@ -13,6 +13,5 @@ class AerobicActivity(PhysicalActivityCategory):
     See: https://schema.org/AerobicActivity
     Model depth: 5
     """
-    type_: str = Field("AerobicActivity", alias='@type')
+    type_: str = Field(default="AerobicActivity", alias='@type')
     
-
