@@ -19,8 +19,8 @@ class AggregateOffer(Offer):
     See: https://schema.org/AggregateOffer
     Model depth: 4
     """
-    type_: str = Field("AggregateOffer", alias='@type')
-    offers: Optional[Union[List[Union['Demand', 'Offer', str]], 'Demand', 'Offer', str]] = Field(
+    type_: str = Field(default="AggregateOffer", alias='@type')
+    offers: Optional[Union[List[Union['Offer', 'Demand', str]], 'Offer', 'Demand', str]] = Field(
         default=None,
         description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the"
      "DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]]"
@@ -49,10 +49,9 @@ class AggregateOffer(Offer):
     )
     
 
-
 if TYPE_CHECKING:
-    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.Offer import Offer
+    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Integer import Integer
