@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReactAction import ReactAction
 
@@ -6,10 +9,8 @@ class AgreeAction(ReactAction):
     """The act of expressing a consistency of opinion with the object. An agent agrees to/about"
      "an object (a proposition, topic or theme) with participants.
 
-    See https://schema.org/AgreeAction.
-
+    See: https://schema.org/AgreeAction
+    Model depth: 5
     """
-    type_: str = Field("AgreeAction", const=True, alias='@type')
+    type_: str = Field(default="AgreeAction", alias='@type')
     
-
-AgreeAction.update_forward_refs()
