@@ -14,7 +14,7 @@ class Airport(CivicStructure):
     See: https://schema.org/Airport
     Model depth: 4
     """
-    type_: str = Field("Airport", alias='@type')
+    type_: str = Field(default="Airport", alias='@type')
     iataCode: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="IATA identifier for an airline or airport.",
@@ -25,6 +25,5 @@ class Airport(CivicStructure):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
