@@ -11,6 +11,5 @@ class AllocateAction(OrganizeAction):
     See: https://schema.org/AllocateAction
     Model depth: 4
     """
-    type_: str = Field("AllocateAction", alias='@type')
+    type_: str = Field(default="AllocateAction", alias='@type')
     
-
