@@ -12,6 +12,5 @@ class AmpStory(CreativeWork):
     See: https://schema.org/AmpStory
     Model depth: 3
     """
-    type_: str = Field("AmpStory", alias='@type')
+    type_: str = Field(default="AmpStory", alias='@type')
     
-
