@@ -11,6 +11,5 @@ class AmusementPark(EntertainmentBusiness):
     See: https://schema.org/AmusementPark
     Model depth: 5
     """
-    type_: str = Field("AmusementPark", alias='@type')
+    type_: str = Field(default="AmusementPark", alias='@type')
     
-
