@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
 
@@ -6,10 +9,8 @@ class AnaerobicActivity(PhysicalActivityCategory):
     """Physical activity that is of high-intensity which utilizes the anaerobic metabolism"
      "of the body.
 
-    See https://schema.org/AnaerobicActivity.
-
+    See: https://schema.org/AnaerobicActivity
+    Model depth: 5
     """
-    type_: str = Field("AnaerobicActivity", const=True, alias='@type')
+    type_: str = Field(default="AnaerobicActivity", alias='@type')
     
-
-AnaerobicActivity.update_forward_refs()
