@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.NewsArticle import NewsArticle
 
@@ -7,10 +10,8 @@ class AnalysisNewsArticle(NewsArticle):
      "incorporates the expertise of the author/producer, offering interpretations and"
      "conclusions.
 
-    See https://schema.org/AnalysisNewsArticle.
-
+    See: https://schema.org/AnalysisNewsArticle
+    Model depth: 5
     """
-    type_: str = Field("AnalysisNewsArticle", const=True, alias='@type')
+    type_: str = Field(default="AnalysisNewsArticle", alias='@type')
     
-
-AnalysisNewsArticle.update_forward_refs()
