@@ -15,7 +15,7 @@ class AnatomicalStructure(MedicalEntity):
     See: https://schema.org/AnatomicalStructure
     Model depth: 3
     """
-    type_: str = Field("AnatomicalStructure", alias='@type')
+    type_: str = Field(default="AnatomicalStructure", alias='@type')
     diagram: Optional[Union[List[Union['ImageObject', str]], 'ImageObject', str]] = Field(
         default=None,
         description="An image containing a diagram that illustrates the structure and/or its component substructures"
@@ -53,7 +53,6 @@ class AnatomicalStructure(MedicalEntity):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.ImageObject import ImageObject
     from pydantic_schemaorg.MedicalCondition import MedicalCondition
