@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -6,10 +9,8 @@ class Anesthesia(MedicalSpecialty):
     """A specific branch of medical science that pertains to study of anesthetics and their"
      "application.
 
-    See https://schema.org/Anesthesia.
-
+    See: https://schema.org/Anesthesia
+    Model depth: 6
     """
-    type_: str = Field("Anesthesia", const=True, alias='@type')
+    type_: str = Field(default="Anesthesia", alias='@type')
     
-
-Anesthesia.update_forward_refs()
