@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class AnimalShelter(LocalBusiness):
     """Animal shelter.
 
-    See https://schema.org/AnimalShelter.
-
+    See: https://schema.org/AnimalShelter
+    Model depth: 4
     """
-    type_: str = Field("AnimalShelter", const=True, alias='@type')
+    type_: str = Field(default="AnimalShelter", alias='@type')
     
-
-AnimalShelter.update_forward_refs()
