@@ -14,15 +14,14 @@ class Answer(Comment):
     See: https://schema.org/Answer
     Model depth: 4
     """
-    type_: str = Field("Answer", alias='@type')
-    answerExplanation: Optional[Union[List[Union['WebContent', 'Comment', str]], 'WebContent', 'Comment', str]] = Field(
+    type_: str = Field(default="Answer", alias='@type')
+    answerExplanation: Optional[Union[List[Union['Comment', 'WebContent', str]], 'Comment', 'WebContent', str]] = Field(
         default=None,
         description="A step-by-step or full explanation about Answer. Can outline how this Answer was achieved"
      "or contain more broad clarification or statement about it.",
     )
     
 
-
 if TYPE_CHECKING:
-    from pydantic_schemaorg.WebContent import WebContent
     from pydantic_schemaorg.Comment import Comment
+    from pydantic_schemaorg.WebContent import WebContent
