@@ -11,6 +11,5 @@ class Appearance(PhysicalExam):
     See: https://schema.org/Appearance
     Model depth: 5
     """
-    type_: str = Field("Appearance", alias='@type')
+    type_: str = Field(default="Appearance", alias='@type')
     
-
