@@ -15,8 +15,8 @@ class ArchiveComponent(CreativeWork):
     See: https://schema.org/ArchiveComponent
     Model depth: 3
     """
-    type_: str = Field("ArchiveComponent", alias='@type')
-    itemLocation: Optional[Union[List[Union[str, 'Text', 'Place', 'PostalAddress']], str, 'Text', 'Place', 'PostalAddress']] = Field(
+    type_: str = Field(default="ArchiveComponent", alias='@type')
+    itemLocation: Optional[Union[List[Union[str, 'Text', 'PostalAddress', 'Place']], str, 'Text', 'PostalAddress', 'Place']] = Field(
         default=None,
         description="Current location of the item.",
     )
@@ -26,9 +26,8 @@ class ArchiveComponent(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
-    from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.PostalAddress import PostalAddress
+    from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.ArchiveOrganization import ArchiveOrganization
