@@ -12,6 +12,5 @@ class ArriveAction(MoveAction):
     See: https://schema.org/ArriveAction
     Model depth: 4
     """
-    type_: str = Field("ArriveAction", alias='@type')
+    type_: str = Field(default="ArriveAction", alias='@type')
     
-
