@@ -14,7 +14,7 @@ class Artery(Vessel):
     See: https://schema.org/Artery
     Model depth: 5
     """
-    type_: str = Field("Artery", alias='@type')
+    type_: str = Field(default="Artery", alias='@type')
     supplyTo: Optional[Union[List[Union['AnatomicalStructure', str]], 'AnatomicalStructure', str]] = Field(
         default=None,
         description="The area to which the artery supplies blood.",
@@ -25,6 +25,5 @@ class Artery(Vessel):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.AnatomicalStructure import AnatomicalStructure
