@@ -17,7 +17,7 @@ class Article(CreativeWork):
     See: https://schema.org/Article
     Model depth: 3
     """
-    type_: str = Field("Article", alias='@type')
+    type_: str = Field(default="Article", alias='@type')
     backstory: Optional[Union[List[Union[str, 'Text', 'CreativeWork']], str, 'Text', 'CreativeWork']] = Field(
         default=None,
         description="For an [[Article]], typically a [[NewsArticle]], the backstory property provides"
@@ -70,7 +70,6 @@ class Article(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.CreativeWork import CreativeWork
