@@ -13,6 +13,5 @@ class AskPublicNewsArticle(NewsArticle):
     See: https://schema.org/AskPublicNewsArticle
     Model depth: 5
     """
-    type_: str = Field("AskPublicNewsArticle", alias='@type')
+    type_: str = Field(default="AskPublicNewsArticle", alias='@type')
     
-
