@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Action import Action
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Action import Action
 class AssessAction(Action):
     """The act of forming one's opinion, reaction or sentiment.
 
-    See https://schema.org/AssessAction.
-
+    See: https://schema.org/AssessAction
+    Model depth: 3
     """
-    type_: str = Field("AssessAction", const=True, alias='@type')
+    type_: str = Field(default="AssessAction", alias='@type')
     
-
-AssessAction.update_forward_refs()
