@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AllocateAction import AllocateAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AllocateAction import AllocateAction
 class AssignAction(AllocateAction):
     """The act of allocating an action/event/task to some destination (someone or something).
 
-    See https://schema.org/AssignAction.
-
+    See: https://schema.org/AssignAction
+    Model depth: 5
     """
-    type_: str = Field("AssignAction", const=True, alias='@type')
+    type_: str = Field(default="AssignAction", alias='@type')
     
-
-AssignAction.update_forward_refs()
