@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LegalService import LegalService
 
@@ -6,10 +9,8 @@ class Attorney(LegalService):
     """Professional service: Attorney. This type is deprecated - [[LegalService]] is more"
      "inclusive and less ambiguous.
 
-    See https://schema.org/Attorney.
-
+    See: https://schema.org/Attorney
+    Model depth: 5
     """
-    type_: str = Field("Attorney", const=True, alias='@type')
+    type_: str = Field(default="Attorney", alias='@type')
     
-
-Attorney.update_forward_refs()
