@@ -14,7 +14,7 @@ class Audience(Intangible):
     See: https://schema.org/Audience
     Model depth: 3
     """
-    type_: str = Field("Audience", alias='@type')
+    type_: str = Field(default="Audience", alias='@type')
     audienceType: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The target group associated with a given audience (e.g. veterans, car owners, musicians,"
@@ -26,7 +26,6 @@ class Audience(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
