@@ -15,6 +15,5 @@ class AudioObjectSnapshot(AudioObject):
     See: https://schema.org/AudioObjectSnapshot
     Model depth: 5
     """
-    type_: str = Field("AudioObjectSnapshot", alias='@type')
+    type_: str = Field(default="AudioObjectSnapshot", alias='@type')
     
-
