@@ -15,7 +15,7 @@ class Audiobook(AudioObject, Book):
     See: https://schema.org/Audiobook
     Model depth: 4
     """
-    type_: str = Field("Audiobook", alias='@type')
+    type_: str = Field(default="Audiobook", alias='@type')
     duration: Optional[Union[List[Union['Duration', str]], 'Duration', str]] = Field(
         default=None,
         description="The duration of the item (movie, audio recording, event, etc.) in [ISO 8601 date format](http://en.wikipedia.org/wiki/ISO_8601).",
@@ -26,7 +26,6 @@ class Audiobook(AudioObject, Book):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Duration import Duration
     from pydantic_schemaorg.Person import Person
