@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LegalValueLevel import LegalValueLevel
 
@@ -8,10 +11,8 @@ class AuthoritativeLegalValue(LegalValueLevel):
      "published by the EU Office of Publications). Something \"Authoritative\" is considered"
      "to be also [[OfficialLegalValue]]\".
 
-    See https://schema.org/AuthoritativeLegalValue.
-
+    See: https://schema.org/AuthoritativeLegalValue
+    Model depth: 5
     """
-    type_: str = Field("AuthoritativeLegalValue", const=True, alias='@type')
+    type_: str = Field(default="AuthoritativeLegalValue", alias='@type')
     
-
-AuthoritativeLegalValue.update_forward_refs()
