@@ -14,16 +14,15 @@ class AuthorizeAction(AllocateAction):
     See: https://schema.org/AuthorizeAction
     Model depth: 5
     """
-    type_: str = Field("AuthorizeAction", alias='@type')
-    recipient: Optional[Union[List[Union['Person', 'Organization', 'Audience', 'ContactPoint', str]], 'Person', 'Organization', 'Audience', 'ContactPoint', str]] = Field(
+    type_: str = Field(default="AuthorizeAction", alias='@type')
+    recipient: Optional[Union[List[Union['Person', 'Audience', 'Organization', 'ContactPoint', str]], 'Person', 'Audience', 'Organization', 'ContactPoint', str]] = Field(
         default=None,
         description="A sub property of participant. The participant who is at the receiving end of the action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
-    from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.Audience import Audience
+    from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.ContactPoint import ContactPoint
