@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 class AutoDealer(AutomotiveBusiness):
     """An car dealership.
 
-    See https://schema.org/AutoDealer.
-
+    See: https://schema.org/AutoDealer
+    Model depth: 5
     """
-    type_: str = Field("AutoDealer", const=True, alias='@type')
+    type_: str = Field(default="AutoDealer", alias='@type')
     
-
-AutoDealer.update_forward_refs()
