@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 class AutoRental(AutomotiveBusiness):
     """A car rental business.
 
-    See https://schema.org/AutoRental.
-
+    See: https://schema.org/AutoRental
+    Model depth: 5
     """
-    type_: str = Field("AutoRental", const=True, alias='@type')
+    type_: str = Field(default="AutoRental", alias='@type')
     
-
-AutoRental.update_forward_refs()
