@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 class AutoRepair(AutomotiveBusiness):
     """Car repair business.
 
-    See https://schema.org/AutoRepair.
-
+    See: https://schema.org/AutoRepair
+    Model depth: 5
     """
-    type_: str = Field("AutoRepair", const=True, alias='@type')
+    type_: str = Field(default="AutoRepair", alias='@type')
     
-
-AutoRepair.update_forward_refs()
