@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 class AutoWash(AutomotiveBusiness):
     """A car wash business.
 
-    See https://schema.org/AutoWash.
-
+    See: https://schema.org/AutoWash
+    Model depth: 5
     """
-    type_: str = Field("AutoWash", const=True, alias='@type')
+    type_: str = Field(default="AutoWash", alias='@type')
     
-
-AutoWash.update_forward_refs()
