@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FinancialService import FinancialService
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FinancialService import FinancialService
 class AutomatedTeller(FinancialService):
     """ATM/cash machine.
 
-    See https://schema.org/AutomatedTeller.
-
+    See: https://schema.org/AutomatedTeller
+    Model depth: 5
     """
-    type_: str = Field("AutomatedTeller", const=True, alias='@type')
+    type_: str = Field(default="AutomatedTeller", alias='@type')
     
-
-AutomatedTeller.update_forward_refs()
