@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class AutomotiveBusiness(LocalBusiness):
     """Car repair, sales, or parts.
 
-    See https://schema.org/AutomotiveBusiness.
-
+    See: https://schema.org/AutomotiveBusiness
+    Model depth: 4
     """
-    type_: str = Field("AutomotiveBusiness", const=True, alias='@type')
+    type_: str = Field(default="AutomotiveBusiness", alias='@type')
     
-
-AutomotiveBusiness.update_forward_refs()
