@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicineSystem import MedicineSystem
 
@@ -6,10 +9,8 @@ class Ayurvedic(MedicineSystem):
     """A system of medicine that originated in India over thousands of years and that focuses"
      "on integrating and balancing the body, mind, and spirit.
 
-    See https://schema.org/Ayurvedic.
-
+    See: https://schema.org/Ayurvedic
+    Model depth: 6
     """
-    type_: str = Field("Ayurvedic", const=True, alias='@type')
+    type_: str = Field(default="Ayurvedic", alias='@type')
     
-
-Ayurvedic.update_forward_refs()
