@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.NewsArticle import NewsArticle
 
@@ -11,10 +14,8 @@ class BackgroundNewsArticle(NewsArticle):
      "[[ScholarlyArticle]]. See also [[NewsArticle]] for related vocabulary from a learning/education"
      "perspective.
 
-    See https://schema.org/BackgroundNewsArticle.
-
+    See: https://schema.org/BackgroundNewsArticle
+    Model depth: 5
     """
-    type_: str = Field("BackgroundNewsArticle", const=True, alias='@type')
+    type_: str = Field(default="BackgroundNewsArticle", alias='@type')
     
-
-BackgroundNewsArticle.update_forward_refs()
