@@ -11,6 +11,5 @@ class Bacteria(InfectiousAgentClass):
     See: https://schema.org/Bacteria
     Model depth: 6
     """
-    type_: str = Field("Bacteria", alias='@type')
+    type_: str = Field(default="Bacteria", alias='@type')
     
-
