@@ -16,7 +16,7 @@ class BankAccount(FinancialProduct):
     See: https://schema.org/BankAccount
     Model depth: 5
     """
-    type_: str = Field("BankAccount", alias='@type')
+    type_: str = Field(default="BankAccount", alias='@type')
     accountMinimumInflow: Optional[Union[List[Union['MonetaryAmount', str]], 'MonetaryAmount', str]] = Field(
         default=None,
         description="A minimum amount that has to be paid in every month.",
@@ -33,7 +33,6 @@ class BankAccount(FinancialProduct):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
     from pydantic_schemaorg.URL import URL
