@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FinancialService import FinancialService
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FinancialService import FinancialService
 class BankOrCreditUnion(FinancialService):
     """Bank or credit union.
 
-    See https://schema.org/BankOrCreditUnion.
-
+    See: https://schema.org/BankOrCreditUnion
+    Model depth: 5
     """
-    type_: str = Field("BankOrCreditUnion", const=True, alias='@type')
+    type_: str = Field(default="BankOrCreditUnion", alias='@type')
     
-
-BankOrCreditUnion.update_forward_refs()
