@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 class BarOrPub(FoodEstablishment):
     """A bar or pub.
 
-    See https://schema.org/BarOrPub.
-
+    See: https://schema.org/BarOrPub
+    Model depth: 5
     """
-    type_: str = Field("BarOrPub", const=True, alias='@type')
+    type_: str = Field(default="BarOrPub", alias='@type')
     
-
-BarOrPub.update_forward_refs()
