@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class Beach(CivicStructure):
     """Beach.
 
-    See https://schema.org/Beach.
-
+    See: https://schema.org/Beach
+    Model depth: 4
     """
-    type_: str = Field("Beach", const=True, alias='@type')
+    type_: str = Field(default="Beach", alias='@type')
     
-
-Beach.update_forward_refs()
