@@ -11,6 +11,5 @@ class BikeStore(Store):
     See: https://schema.org/BikeStore
     Model depth: 5
     """
-    type_: str = Field("BikeStore", alias='@type')
+    type_: str = Field(default="BikeStore", alias='@type')
     
-
