@@ -16,7 +16,7 @@ class BioChemEntity(Thing):
     See: https://schema.org/BioChemEntity
     Model depth: 2
     """
-    type_: str = Field("BioChemEntity", alias='@type')
+    type_: str = Field(default="BioChemEntity", alias='@type')
     bioChemSimilarity: Optional[Union[List[Union['BioChemEntity', str]], 'BioChemEntity', str]] = Field(
         default=None,
         description="A similar BioChemEntity, e.g., obtained by fingerprint similarity algorithms.",
@@ -39,7 +39,7 @@ class BioChemEntity(Thing):
         default=None,
         description="Indicates a BioChemEntity that (in some sense) has this BioChemEntity as a part.",
     )
-    associatedDisease: Optional[Union[List[Union[AnyUrl, 'URL', 'PropertyValue', 'MedicalCondition', str]], AnyUrl, 'URL', 'PropertyValue', 'MedicalCondition', str]] = Field(
+    associatedDisease: Optional[Union[List[Union[AnyUrl, 'URL', 'MedicalCondition', 'PropertyValue', str]], AnyUrl, 'URL', 'MedicalCondition', 'PropertyValue', str]] = Field(
         default=None,
         description="Disease associated to this BioChemEntity. Such disease can be a MedicalCondition or"
      "a URL. If you want to add an evidence supporting the association, please use PropertyValue.",
@@ -73,7 +73,6 @@ class BioChemEntity(Thing):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.DefinedTerm import DefinedTerm
