@@ -16,7 +16,7 @@ class Blog(CreativeWork):
     See: https://schema.org/Blog
     Model depth: 3
     """
-    type_: str = Field("Blog", alias='@type')
+    type_: str = Field(default="Blog", alias='@type')
     blogPosts: Optional[Union[List[Union['BlogPosting', str]], 'BlogPosting', str]] = Field(
         default=None,
         description="Indicates a post that is part of a [[Blog]]. Note that historically, what we term a \"Blog\""
@@ -35,7 +35,6 @@ class Blog(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.BlogPosting import BlogPosting
     from pydantic_schemaorg.Text import Text
