@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class BoatTerminal(CivicStructure):
     """A terminal for boats, ships, and other water vessels.
 
-    See https://schema.org/BoatTerminal.
-
+    See: https://schema.org/BoatTerminal
+    Model depth: 4
     """
-    type_: str = Field("BoatTerminal", const=True, alias='@type')
+    type_: str = Field(default="BoatTerminal", alias='@type')
     
-
-BoatTerminal.update_forward_refs()
