@@ -14,7 +14,7 @@ class BoatTrip(Trip):
     See: https://schema.org/BoatTrip
     Model depth: 4
     """
-    type_: str = Field("BoatTrip", alias='@type')
+    type_: str = Field(default="BoatTrip", alias='@type')
     arrivalBoatTerminal: Optional[Union[List[Union['BoatTerminal', str]], 'BoatTerminal', str]] = Field(
         default=None,
         description="The terminal or port from which the boat arrives.",
@@ -25,6 +25,5 @@ class BoatTrip(Trip):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.BoatTerminal import BoatTerminal
