@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTyp
 class BodyMeasurementBust(BodyMeasurementTypeEnumeration):
     """Maximum girth of bust. Used, for example, to fit women's suits.
 
-    See https://schema.org/BodyMeasurementBust.
-
+    See: https://schema.org/BodyMeasurementBust
+    Model depth: 6
     """
-    type_: str = Field("BodyMeasurementBust", const=True, alias='@type')
+    type_: str = Field(default="BodyMeasurementBust", alias='@type')
     
-
-BodyMeasurementBust.update_forward_refs()
