@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTyp
 class BodyMeasurementHead(BodyMeasurementTypeEnumeration):
     """Maximum girth of head above the ears. Used, for example, to fit hats.
 
-    See https://schema.org/BodyMeasurementHead.
-
+    See: https://schema.org/BodyMeasurementHead
+    Model depth: 6
     """
-    type_: str = Field("BodyMeasurementHead", const=True, alias='@type')
+    type_: str = Field(default="BodyMeasurementHead", alias='@type')
     
-
-BodyMeasurementHead.update_forward_refs()
