@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTypeEnumeration
 
@@ -6,10 +9,8 @@ class BodyMeasurementHeight(BodyMeasurementTypeEnumeration):
     """Body height (measured between crown of head and soles of feet). Used, for example, to"
      "fit jackets.
 
-    See https://schema.org/BodyMeasurementHeight.
-
+    See: https://schema.org/BodyMeasurementHeight
+    Model depth: 6
     """
-    type_: str = Field("BodyMeasurementHeight", const=True, alias='@type')
+    type_: str = Field(default="BodyMeasurementHeight", alias='@type')
     
-
-BodyMeasurementHeight.update_forward_refs()
