@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTyp
 class BodyMeasurementInsideLeg(BodyMeasurementTypeEnumeration):
     """Inside leg (measured between crotch and soles of feet). Used, for example, to fit pants.
 
-    See https://schema.org/BodyMeasurementInsideLeg.
-
+    See: https://schema.org/BodyMeasurementInsideLeg
+    Model depth: 6
     """
-    type_: str = Field("BodyMeasurementInsideLeg", const=True, alias='@type')
+    type_: str = Field(default="BodyMeasurementInsideLeg", alias='@type')
     
-
-BodyMeasurementInsideLeg.update_forward_refs()
