@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MeasurementTypeEnumeration import MeasurementTypeEnumeration
 
@@ -6,10 +9,8 @@ class BodyMeasurementTypeEnumeration(MeasurementTypeEnumeration):
     """Enumerates types (or dimensions) of a person's body measurements, for example for fitting"
      "of clothes.
 
-    See https://schema.org/BodyMeasurementTypeEnumeration.
-
+    See: https://schema.org/BodyMeasurementTypeEnumeration
+    Model depth: 5
     """
-    type_: str = Field("BodyMeasurementTypeEnumeration", const=True, alias='@type')
+    type_: str = Field(default="BodyMeasurementTypeEnumeration", alias='@type')
     
-
-BodyMeasurementTypeEnumeration.update_forward_refs()
