@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.BodyMeasurementTypeEnumeration import BodyMeasurementTyp
 class BodyMeasurementWeight(BodyMeasurementTypeEnumeration):
     """Body weight. Used, for example, to measure pantyhose.
 
-    See https://schema.org/BodyMeasurementWeight.
-
+    See: https://schema.org/BodyMeasurementWeight
+    Model depth: 6
     """
-    type_: str = Field("BodyMeasurementWeight", const=True, alias='@type')
+    type_: str = Field(default="BodyMeasurementWeight", alias='@type')
     
-
-BodyMeasurementWeight.update_forward_refs()
