@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AnatomicalStructure import AnatomicalStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AnatomicalStructure import AnatomicalStructure
 class Bone(AnatomicalStructure):
     """Rigid connective tissue that comprises up the skeletal structure of the human body.
 
-    See https://schema.org/Bone.
-
+    See: https://schema.org/Bone
+    Model depth: 4
     """
-    type_: str = Field("Bone", const=True, alias='@type')
+    type_: str = Field(default="Bone", alias='@type')
     
-
-Bone.update_forward_refs()
