@@ -15,7 +15,7 @@ class Book(CreativeWork):
     See: https://schema.org/Book
     Model depth: 3
     """
-    type_: str = Field("Book", alias='@type')
+    type_: str = Field(default="Book", alias='@type')
     illustrator: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="The illustrator of the book.",
@@ -42,7 +42,6 @@ class Book(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Boolean import Boolean
