@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class BookFormatType(Enumeration):
     """The publication format of the book.
 
-    See https://schema.org/BookFormatType.
-
+    See: https://schema.org/BookFormatType
+    Model depth: 4
     """
-    type_: str = Field("BookFormatType", const=True, alias='@type')
+    type_: str = Field(default="BookFormatType", alias='@type')
     
-
-BookFormatType.update_forward_refs()
