@@ -11,6 +11,5 @@ class BookStore(Store):
     See: https://schema.org/BookStore
     Model depth: 5
     """
-    type_: str = Field("BookStore", alias='@type')
+    type_: str = Field(default="BookStore", alias='@type')
     
-
