@@ -15,14 +15,13 @@ class BorrowAction(TransferAction):
     See: https://schema.org/BorrowAction
     Model depth: 4
     """
-    type_: str = Field("BorrowAction", alias='@type')
+    type_: str = Field(default="BorrowAction", alias='@type')
     lender: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="A sub property of participant. The person that lends the object being borrowed.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
