@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 class Brewery(FoodEstablishment):
     """Brewery.
 
-    See https://schema.org/Brewery.
-
+    See: https://schema.org/Brewery
+    Model depth: 5
     """
-    type_: str = Field("Brewery", const=True, alias='@type')
+    type_: str = Field(default="Brewery", alias='@type')
     
-
-Brewery.update_forward_refs()
