@@ -11,6 +11,5 @@ class Bridge(CivicStructure):
     See: https://schema.org/Bridge
     Model depth: 4
     """
-    type_: str = Field("Bridge", alias='@type')
+    type_: str = Field(default="Bridge", alias='@type')
     
-
