@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicAlbumReleaseType import MusicAlbumReleaseType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicAlbumReleaseType import MusicAlbumReleaseType
 class BroadcastRelease(MusicAlbumReleaseType):
     """BroadcastRelease.
 
-    See https://schema.org/BroadcastRelease.
-
+    See: https://schema.org/BroadcastRelease
+    Model depth: 5
     """
-    type_: str = Field("BroadcastRelease", const=True, alias='@type')
+    type_: str = Field(default="BroadcastRelease", alias='@type')
     
-
-BroadcastRelease.update_forward_refs()
