@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PlaceOfWorship import PlaceOfWorship
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PlaceOfWorship import PlaceOfWorship
 class BuddhistTemple(PlaceOfWorship):
     """A Buddhist temple.
 
-    See https://schema.org/BuddhistTemple.
-
+    See: https://schema.org/BuddhistTemple
+    Model depth: 5
     """
-    type_: str = Field("BuddhistTemple", const=True, alias='@type')
+    type_: str = Field(default="BuddhistTemple", alias='@type')
     
-
-BuddhistTemple.update_forward_refs()
