@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Reservation import Reservation
 
@@ -7,10 +10,8 @@ class BusReservation(Reservation):
      "e.g. in confirmation emails or HTML pages with individual confirmations of reservations."
      "For offers of tickets, use [[Offer]].
 
-    See https://schema.org/BusReservation.
-
+    See: https://schema.org/BusReservation
+    Model depth: 4
     """
-    type_: str = Field("BusReservation", const=True, alias='@type')
+    type_: str = Field(default="BusReservation", alias='@type')
     
-
-BusReservation.update_forward_refs()
