@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class BusStop(CivicStructure):
     """A bus stop.
 
-    See https://schema.org/BusStop.
-
+    See: https://schema.org/BusStop
+    Model depth: 4
     """
-    type_: str = Field("BusStop", const=True, alias='@type')
+    type_: str = Field(default="BusStop", alias='@type')
     
-
-BusStop.update_forward_refs()
