@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -9,10 +12,8 @@ class BusinessEntityType(Enumeration):
      "* http://purl.org/goodrelations/v1#Enduser * http://purl.org/goodrelations/v1#PublicInstitution"
      "* http://purl.org/goodrelations/v1#Reseller
 
-    See https://schema.org/BusinessEntityType.
-
+    See: https://schema.org/BusinessEntityType
+    Model depth: 4
     """
-    type_: str = Field("BusinessEntityType", const=True, alias='@type')
+    type_: str = Field(default="BusinessEntityType", alias='@type')
     
-
-BusinessEntityType.update_forward_refs()
