@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Event import Event
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Event import Event
 class BusinessEvent(Event):
     """Event type: Business event.
 
-    See https://schema.org/BusinessEvent.
-
+    See: https://schema.org/BusinessEvent
+    Model depth: 3
     """
-    type_: str = Field("BusinessEvent", const=True, alias='@type')
+    type_: str = Field(default="BusinessEvent", alias='@type')
     
-
-BusinessEvent.update_forward_refs()
