@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -13,10 +16,8 @@ class BusinessFunction(Enumeration):
      "* http://purl.org/goodrelations/v1#Repair * http://purl.org/goodrelations/v1#Sell"
      "* http://purl.org/goodrelations/v1#Buy
 
-    See https://schema.org/BusinessFunction.
-
+    See: https://schema.org/BusinessFunction
+    Model depth: 4
     """
-    type_: str = Field("BusinessFunction", const=True, alias='@type')
+    type_: str = Field(default="BusinessFunction", alias='@type')
     
-
-BusinessFunction.update_forward_refs()
