@@ -15,7 +15,7 @@ class BuyAction(TradeAction):
     See: https://schema.org/BuyAction
     Model depth: 4
     """
-    type_: str = Field("BuyAction", alias='@type')
+    type_: str = Field(default="BuyAction", alias='@type')
     vendor: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="'vendor' is an earlier term for 'seller'.",
@@ -31,7 +31,6 @@ class BuyAction(TradeAction):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
