@@ -11,6 +11,5 @@ class CT(MedicalImagingTechnique):
     See: https://schema.org/CT
     Model depth: 6
     """
-    type_: str = Field("CT", alias='@type')
+    type_: str = Field(default="CT", alias='@type')
     
-
