@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PlanAction import PlanAction
 
@@ -6,10 +9,8 @@ class CancelAction(PlanAction):
     """The act of asserting that a future event/action is no longer going to happen. Related"
      "actions: * [[ConfirmAction]]: The antonym of CancelAction.
 
-    See https://schema.org/CancelAction.
-
+    See: https://schema.org/CancelAction
+    Model depth: 5
     """
-    type_: str = Field("CancelAction", const=True, alias='@type')
+    type_: str = Field(default="CancelAction", alias='@type')
     
-
-CancelAction.update_forward_refs()
