@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class CardiovascularExam(PhysicalExam):
     """Cardiovascular system assessment withclinical examination.
 
-    See https://schema.org/CardiovascularExam.
-
+    See: https://schema.org/CardiovascularExam
+    Model depth: 5
     """
-    type_: str = Field("CardiovascularExam", const=True, alias='@type')
+    type_: str = Field(default="CardiovascularExam", alias='@type')
     
-
-CardiovascularExam.update_forward_refs()
