@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalObservationalStudyDesign import MedicalObservationalStudyDesign
 
@@ -11,10 +14,8 @@ class CaseSeries(MedicalObservationalStudyDesign):
      "depending on whether all cases presenting to the reporting authors over a period of time"
      "were included, or only a selection.
 
-    See https://schema.org/CaseSeries.
-
+    See: https://schema.org/CaseSeries
+    Model depth: 6
     """
-    type_: str = Field("CaseSeries", const=True, alias='@type')
+    type_: str = Field(default="CaseSeries", alias='@type')
     
-
-CaseSeries.update_forward_refs()
