@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EntertainmentBusiness import EntertainmentBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.EntertainmentBusiness import EntertainmentBusiness
 class Casino(EntertainmentBusiness):
     """A casino.
 
-    See https://schema.org/Casino.
-
+    See: https://schema.org/Casino
+    Model depth: 5
     """
-    type_: str = Field("Casino", const=True, alias='@type')
+    type_: str = Field(default="Casino", alias='@type')
     
-
-Casino.update_forward_refs()
