@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType
 class CassetteFormat(MusicReleaseFormatType):
     """CassetteFormat.
 
-    See https://schema.org/CassetteFormat.
-
+    See: https://schema.org/CassetteFormat
+    Model depth: 5
     """
-    type_: str = Field("CassetteFormat", const=True, alias='@type')
+    type_: str = Field(default="CassetteFormat", alias='@type')
     
-
-CassetteFormat.update_forward_refs()
