@@ -15,7 +15,7 @@ class CategoryCode(DefinedTerm):
     See: https://schema.org/CategoryCode
     Model depth: 4
     """
-    type_: str = Field("CategoryCode", alias='@type')
+    type_: str = Field(default="CategoryCode", alias='@type')
     codeValue: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="A short textual code that uniquely identifies the value.",
@@ -26,7 +26,6 @@ class CategoryCode(DefinedTerm):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.URL import URL
