@@ -14,13 +14,12 @@ class CategoryCodeSet(DefinedTermSet):
     See: https://schema.org/CategoryCodeSet
     Model depth: 4
     """
-    type_: str = Field("CategoryCodeSet", alias='@type')
+    type_: str = Field(default="CategoryCodeSet", alias='@type')
     hasCategoryCode: Optional[Union[List[Union['CategoryCode', str]], 'CategoryCode', str]] = Field(
         default=None,
         description="A Category code contained in this code set.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.CategoryCode import CategoryCode
