@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class CausesHealthAspect(HealthAspectEnumeration):
     """Information about the causes and main actions that gave rise to the topic.
 
-    See https://schema.org/CausesHealthAspect.
-
+    See: https://schema.org/CausesHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("CausesHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="CausesHealthAspect", alias='@type')
     
-
-CausesHealthAspect.update_forward_refs()
