@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.UKNonprofitType import UKNonprofitType
 
@@ -6,10 +9,8 @@ class CharitableIncorporatedOrganization(UKNonprofitType):
     """CharitableIncorporatedOrganization: Non-profit type referring to a Charitable"
      "Incorporated Organization (UK).
 
-    See https://schema.org/CharitableIncorporatedOrganization.
-
+    See: https://schema.org/CharitableIncorporatedOrganization
+    Model depth: 6
     """
-    type_: str = Field("CharitableIncorporatedOrganization", const=True, alias='@type')
+    type_: str = Field(default="CharitableIncorporatedOrganization", alias='@type')
     
-
-CharitableIncorporatedOrganization.update_forward_refs()
