@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CommunicateAction import CommunicateAction
 
@@ -12,10 +15,8 @@ class CheckInAction(CommunicateAction):
      "CheckInAction implies that the agent is informing/confirming the *start* of a previously"
      "reserved service rather than its validity/existence.
 
-    See https://schema.org/CheckInAction.
-
+    See: https://schema.org/CheckInAction
+    Model depth: 5
     """
-    type_: str = Field("CheckInAction", const=True, alias='@type')
+    type_: str = Field(default="CheckInAction", alias='@type')
     
-
-CheckInAction.update_forward_refs()
