@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WebPage import WebPage
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WebPage import WebPage
 class CheckoutPage(WebPage):
     """Web page type: Checkout page.
 
-    See https://schema.org/CheckoutPage.
-
+    See: https://schema.org/CheckoutPage
+    Model depth: 4
     """
-    type_: str = Field("CheckoutPage", const=True, alias='@type')
+    type_: str = Field(default="CheckoutPage", alias='@type')
     
-
-CheckoutPage.update_forward_refs()
