@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class ChildCare(LocalBusiness):
     """A Childcare center.
 
-    See https://schema.org/ChildCare.
-
+    See: https://schema.org/ChildCare
+    Model depth: 4
     """
-    type_: str = Field("ChildCare", const=True, alias='@type')
+    type_: str = Field(default="ChildCare", alias='@type')
     
-
-ChildCare.update_forward_refs()
