@@ -14,7 +14,7 @@ class ChooseAction(AssessAction):
     See: https://schema.org/ChooseAction
     Model depth: 4
     """
-    type_: str = Field("ChooseAction", alias='@type')
+    type_: str = Field(default="ChooseAction", alias='@type')
     option: Optional[Union[List[Union[str, 'Text', 'Thing']], str, 'Text', 'Thing']] = Field(
         default=None,
         description="A sub property of object. The options subject to this action.",
@@ -25,7 +25,6 @@ class ChooseAction(AssessAction):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Thing import Thing
