@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PlaceOfWorship import PlaceOfWorship
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PlaceOfWorship import PlaceOfWorship
 class Church(PlaceOfWorship):
     """A church.
 
-    See https://schema.org/Church.
-
+    See: https://schema.org/Church
+    Model depth: 5
     """
-    type_: str = Field("Church", const=True, alias='@type')
+    type_: str = Field(default="Church", alias='@type')
     
-
-Church.update_forward_refs()
