@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 class City(AdministrativeArea):
     """A city or town.
 
-    See https://schema.org/City.
-
+    See: https://schema.org/City
+    Model depth: 4
     """
-    type_: str = Field("City", const=True, alias='@type')
+    type_: str = Field(default="City", alias='@type')
     
-
-City.update_forward_refs()
