@@ -23,7 +23,7 @@ class Claim(CreativeWork):
     See: https://schema.org/Claim
     Model depth: 3
     """
-    type_: str = Field("Claim", alias='@type')
+    type_: str = Field(default="Claim", alias='@type')
     firstAppearance: Optional[Union[List[Union['CreativeWork', str]], 'CreativeWork', str]] = Field(
         default=None,
         description="Indicates the first known occurence of a [[Claim]] in some [[CreativeWork]].",
@@ -39,7 +39,6 @@ class Claim(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.CreativeWork import CreativeWork
     from pydantic_schemaorg.Person import Person
