@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PriceComponentTypeEnumeration import PriceComponentTypeEnumeration
 
@@ -6,10 +9,8 @@ class CleaningFee(PriceComponentTypeEnumeration):
     """Represents the cleaning fee part of the total price for an offered product, for example"
      "a vacation rental.
 
-    See https://schema.org/CleaningFee.
-
+    See: https://schema.org/CleaningFee
+    Model depth: 5
     """
-    type_: str = Field("CleaningFee", const=True, alias='@type')
+    type_: str = Field(default="CleaningFee", alias='@type')
     
-
-CleaningFee.update_forward_refs()
