@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalAudienceType import MedicalAudienceType
 
@@ -6,10 +9,8 @@ class Clinician(MedicalAudienceType):
     """Medical clinicians, including practicing physicians and other medical professionals"
      "involved in clinical practice.
 
-    See https://schema.org/Clinician.
-
+    See: https://schema.org/Clinician
+    Model depth: 6
     """
-    type_: str = Field("Clinician", const=True, alias='@type')
+    type_: str = Field(default="Clinician", alias='@type')
     
-
-Clinician.update_forward_refs()
