@@ -15,7 +15,7 @@ class Clip(CreativeWork):
     See: https://schema.org/Clip
     Model depth: 3
     """
-    type_: str = Field("Clip", alias='@type')
+    type_: str = Field(default="Clip", alias='@type')
     partOfSeason: Optional[Union[List[Union['CreativeWorkSeason', str]], 'CreativeWorkSeason', str]] = Field(
         default=None,
         description="The season to which this episode belongs.",
@@ -67,7 +67,6 @@ class Clip(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.CreativeWorkSeason import CreativeWorkSeason
     from pydantic_schemaorg.Person import Person
