@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GamePlayMode import GamePlayMode
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GamePlayMode import GamePlayMode
 class CoOp(GamePlayMode):
     """Play mode: CoOp. Co-operative games, where you play on the same team with friends.
 
-    See https://schema.org/CoOp.
-
+    See: https://schema.org/CoOp
+    Model depth: 5
     """
-    type_: str = Field("CoOp", const=True, alias='@type')
+    type_: str = Field(default="CoOp", alias='@type')
     
-
-CoOp.update_forward_refs()
