@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -6,10 +9,8 @@ class Code(CreativeWork):
     """Computer programming source code. Example: Full (compile ready) solutions, code snippet"
      "samples, scripts, templates.
 
-    See https://schema.org/Code.
-
+    See: https://schema.org/Code
+    Model depth: 3
     """
-    type_: str = Field("Code", const=True, alias='@type')
+    type_: str = Field(default="Code", alias='@type')
     
-
-Code.update_forward_refs()
