@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WebPage import WebPage
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WebPage import WebPage
 class CollectionPage(WebPage):
     """Web page type: Collection page.
 
-    See https://schema.org/CollectionPage.
-
+    See: https://schema.org/CollectionPage
+    Model depth: 4
     """
-    type_: str = Field("CollectionPage", const=True, alias='@type')
+    type_: str = Field(default="CollectionPage", alias='@type')
     
-
-CollectionPage.update_forward_refs()
