@@ -18,7 +18,7 @@ class ComicIssue(PublicationIssue):
     See: https://schema.org/ComicIssue
     Model depth: 4
     """
-    type_: str = Field("ComicIssue", alias='@type')
+    type_: str = Field(default="ComicIssue", alias='@type')
     colorist: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="The individual who adds color to inked drawings.",
@@ -48,7 +48,6 @@ class ComicIssue(PublicationIssue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Text import Text
