@@ -16,7 +16,7 @@ class ComicStory(CreativeWork):
     See: https://schema.org/ComicStory
     Model depth: 3
     """
-    type_: str = Field("ComicStory", alias='@type')
+    type_: str = Field(default="ComicStory", alias='@type')
     colorist: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="The individual who adds color to inked drawings.",
@@ -41,6 +41,5 @@ class ComicStory(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
