@@ -15,7 +15,7 @@ class Comment(CreativeWork):
     See: https://schema.org/Comment
     Model depth: 3
     """
-    type_: str = Field("Comment", alias='@type')
+    type_: str = Field(default="Comment", alias='@type')
     downvoteCount: Optional[Union[List[Union[int, 'Integer', str]], int, 'Integer', str]] = Field(
         default=None,
         description="The number of downvotes this question, answer or comment has received from the community.",
@@ -30,6 +30,5 @@ class Comment(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Integer import Integer
