@@ -14,13 +14,12 @@ class CommentAction(CommunicateAction):
     See: https://schema.org/CommentAction
     Model depth: 5
     """
-    type_: str = Field("CommentAction", alias='@type')
+    type_: str = Field(default="CommentAction", alias='@type')
     resultComment: Optional[Union[List[Union['Comment', str]], 'Comment', str]] = Field(
         default=None,
         description="A sub property of result. The Comment created or sent as a result of this action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Comment import Comment
