@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 class CompilationAlbum(MusicAlbumProductionType):
     """CompilationAlbum.
 
-    See https://schema.org/CompilationAlbum.
-
+    See: https://schema.org/CompilationAlbum
+    Model depth: 5
     """
-    type_: str = Field("CompilationAlbum", const=True, alias='@type')
+    type_: str = Field(default="CompilationAlbum", alias='@type')
     
-
-CompilationAlbum.update_forward_refs()
