@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 class Completed(MedicalStudyStatus):
     """Completed.
 
-    See https://schema.org/Completed.
-
+    See: https://schema.org/Completed
+    Model depth: 6
     """
-    type_: str = Field("Completed", const=True, alias='@type')
+    type_: str = Field(default="Completed", alias='@type')
     
-
-Completed.update_forward_refs()
