@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.InformAction import InformAction
 
@@ -6,10 +9,8 @@ class ConfirmAction(InformAction):
     """The act of notifying someone that a future event/action is going to happen as expected."
      "Related actions: * [[CancelAction]]: The antonym of ConfirmAction.
 
-    See https://schema.org/ConfirmAction.
-
+    See: https://schema.org/ConfirmAction
+    Model depth: 6
     """
-    type_: str = Field("ConfirmAction", const=True, alias='@type')
+    type_: str = Field(default="ConfirmAction", alias='@type')
     
-
-ConfirmAction.update_forward_refs()
