@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WebPage import WebPage
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WebPage import WebPage
 class ContactPage(WebPage):
     """Web page type: Contact page.
 
-    See https://schema.org/ContactPage.
-
+    See: https://schema.org/ContactPage
+    Model depth: 4
     """
-    type_: str = Field("ContactPage", const=True, alias='@type')
+    type_: str = Field(default="ContactPage", alias='@type')
     
-
-ContactPage.update_forward_refs()
