@@ -14,7 +14,7 @@ class ContactPoint(StructuredValue):
     See: https://schema.org/ContactPoint
     Model depth: 4
     """
-    type_: str = Field("ContactPoint", alias='@type')
+    type_: str = Field(default="ContactPoint", alias='@type')
     areaServed: Optional[Union[List[Union[str, 'Text', 'GeoShape', 'AdministrativeArea', 'Place']], str, 'Text', 'GeoShape', 'AdministrativeArea', 'Place']] = Field(
         default=None,
         description="The geographic area where a service or offered item is provided.",
@@ -31,7 +31,7 @@ class ContactPoint(StructuredValue):
      "codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47). See also"
      "[[inLanguage]]",
     )
-    serviceArea: Optional[Union[List[Union['AdministrativeArea', 'GeoShape', 'Place', str]], 'AdministrativeArea', 'GeoShape', 'Place', str]] = Field(
+    serviceArea: Optional[Union[List[Union['GeoShape', 'AdministrativeArea', 'Place', str]], 'GeoShape', 'AdministrativeArea', 'Place', str]] = Field(
         default=None,
         description="The geographic area where the service is provided.",
     )
@@ -64,7 +64,6 @@ class ContactPoint(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.GeoShape import GeoShape
