@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class ContactPointOption(Enumeration):
     """Enumerated options related to a ContactPoint.
 
-    See https://schema.org/ContactPointOption.
-
+    See: https://schema.org/ContactPointOption
+    Model depth: 4
     """
-    type_: str = Field("ContactPointOption", const=True, alias='@type')
+    type_: str = Field(default="ContactPointOption", alias='@type')
     
-
-ContactPointOption.update_forward_refs()
