@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class ContagiousnessHealthAspect(HealthAspectEnumeration):
     """Content about contagion mechanisms and contagiousness information over the topic.
 
-    See https://schema.org/ContagiousnessHealthAspect.
-
+    See: https://schema.org/ContagiousnessHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("ContagiousnessHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="ContagiousnessHealthAspect", alias='@type')
     
-
-ContagiousnessHealthAspect.update_forward_refs()
