@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Landform import Landform
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Landform import Landform
 class Continent(Landform):
     """One of the continents (for example, Europe or Africa).
 
-    See https://schema.org/Continent.
-
+    See: https://schema.org/Continent
+    Model depth: 4
     """
-    type_: str = Field("Continent", const=True, alias='@type')
+    type_: str = Field(default="Continent", alias='@type')
     
-
-Continent.update_forward_refs()
