@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -6,10 +9,8 @@ class Conversation(CreativeWork):
     """One or more messages between organizations or people on a particular topic. Individual"
      "messages can be linked to the conversation with isPartOf or hasPart properties.
 
-    See https://schema.org/Conversation.
-
+    See: https://schema.org/Conversation
+    Model depth: 3
     """
-    type_: str = Field("Conversation", const=True, alias='@type')
+    type_: str = Field(default="Conversation", alias='@type')
     
-
-Conversation.update_forward_refs()
