@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Comment import Comment
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Comment import Comment
 class CorrectionComment(Comment):
     """A [[comment]] that corrects [[CreativeWork]].
 
-    See https://schema.org/CorrectionComment.
-
+    See: https://schema.org/CorrectionComment
+    Model depth: 4
     """
-    type_: str = Field("CorrectionComment", const=True, alias='@type')
+    type_: str = Field(default="CorrectionComment", alias='@type')
     
-
-CorrectionComment.update_forward_refs()
