@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 class Country(AdministrativeArea):
     """A country.
 
-    See https://schema.org/Country.
-
+    See: https://schema.org/Country
+    Model depth: 4
     """
-    type_: str = Field("Country", const=True, alias='@type')
+    type_: str = Field(default="Country", alias='@type')
     
-
-Country.update_forward_refs()
