@@ -11,6 +11,5 @@ class CoverArt(VisualArtwork):
     See: https://schema.org/CoverArt
     Model depth: 4
     """
-    type_: str = Field("CoverArt", alias='@type')
+    type_: str = Field(default="CoverArt", alias='@type')
     
-
