@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalClinic import MedicalClinic
 
@@ -10,10 +13,8 @@ class CovidTestingFacility(MedicalClinic):
      "address, opening hours. Note that in an emergency, such information may not always be"
      "reliable.
 
-    See https://schema.org/CovidTestingFacility.
-
+    See: https://schema.org/CovidTestingFacility
+    Model depth: 5
     """
-    type_: str = Field("CovidTestingFacility", const=True, alias='@type')
+    type_: str = Field(default="CovidTestingFacility", alias='@type')
     
-
-CovidTestingFacility.update_forward_refs()
