@@ -18,7 +18,7 @@ class CreativeWork(Thing):
     See: https://schema.org/CreativeWork
     Model depth: 2
     """
-    type_: str = Field("CreativeWork", alias='@type')
+    type_: str = Field(default="CreativeWork", alias='@type')
     pattern: Optional[Union[List[Union[str, 'Text', 'DefinedTerm']], str, 'Text', 'DefinedTerm']] = Field(
         default=None,
         description="A pattern that something has, for example 'polka dot', 'striped', 'Canadian flag'."
@@ -42,7 +42,7 @@ class CreativeWork(Thing):
         default=None,
         description="Fictional person connected with a creative work.",
     )
-    offers: Optional[Union[List[Union['Demand', 'Offer', str]], 'Demand', 'Offer', str]] = Field(
+    offers: Optional[Union[List[Union['Offer', 'Demand', str]], 'Offer', 'Demand', str]] = Field(
         default=None,
         description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the"
      "DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]]"
@@ -185,11 +185,11 @@ class CreativeWork(Thing):
         default=None,
         description="Comments, typically from users.",
     )
-    audio: Optional[Union[List[Union['AudioObject', 'MusicRecording', 'Clip', str]], 'AudioObject', 'MusicRecording', 'Clip', str]] = Field(
+    audio: Optional[Union[List[Union['MusicRecording', 'AudioObject', 'Clip', str]], 'MusicRecording', 'AudioObject', 'Clip', str]] = Field(
         default=None,
         description="An embedded audio object.",
     )
-    video: Optional[Union[List[Union['VideoObject', 'Clip', str]], 'VideoObject', 'Clip', str]] = Field(
+    video: Optional[Union[List[Union['Clip', 'VideoObject', str]], 'Clip', 'VideoObject', str]] = Field(
         default=None,
         description="An embedded video object.",
     )
@@ -350,7 +350,7 @@ class CreativeWork(Thing):
         description="Example/instance/realization/derivation of the concept of this creative work. eg."
      "The paperback edition, first edition, or eBook.",
     )
-    size: Optional[Union[List[Union[str, 'Text', 'SizeSpecification', 'DefinedTerm', 'QuantitativeValue']], str, 'Text', 'SizeSpecification', 'DefinedTerm', 'QuantitativeValue']] = Field(
+    size: Optional[Union[List[Union[str, 'Text', 'QuantitativeValue', 'SizeSpecification', 'DefinedTerm']], str, 'Text', 'QuantitativeValue', 'SizeSpecification', 'DefinedTerm']] = Field(
         default=None,
         description="A standardized size of a product or creative work, specified either through a simple"
      "textual string (for example 'XL', '32Wx34L'), a QuantitativeValue with a unitCode,"
@@ -621,14 +621,13 @@ class CreativeWork(Thing):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.DefinedTerm import DefinedTerm
     from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.Person import Person
-    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.Offer import Offer
+    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.Product import Product
@@ -640,8 +639,8 @@ if TYPE_CHECKING:
     from pydantic_schemaorg.ItemList import ItemList
     from pydantic_schemaorg.AlignmentObject import AlignmentObject
     from pydantic_schemaorg.Comment import Comment
-    from pydantic_schemaorg.AudioObject import AudioObject
     from pydantic_schemaorg.MusicRecording import MusicRecording
+    from pydantic_schemaorg.AudioObject import AudioObject
     from pydantic_schemaorg.Clip import Clip
     from pydantic_schemaorg.VideoObject import VideoObject
     from pydantic_schemaorg.Integer import Integer
