@@ -15,7 +15,7 @@ class CreativeWorkSeason(CreativeWork):
     See: https://schema.org/CreativeWorkSeason
     Model depth: 3
     """
-    type_: str = Field("CreativeWorkSeason", alias='@type')
+    type_: str = Field(default="CreativeWorkSeason", alias='@type')
     trailer: Optional[Union[List[Union['VideoObject', str]], 'VideoObject', str]] = Field(
         default=None,
         description="The trailer of a movie or tv/radio series, season, episode, etc.",
@@ -65,7 +65,6 @@ class CreativeWorkSeason(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.VideoObject import VideoObject
     from pydantic_schemaorg.Episode import Episode
