@@ -2,11 +2,11 @@ from __future__ import annotations
 
 
 from pydantic import Field
-from pydantic_schemaorg.LoanOrCredit import LoanOrCredit
 from pydantic_schemaorg.PaymentCard import PaymentCard
+from pydantic_schemaorg.LoanOrCredit import LoanOrCredit
 
 
-class CreditCard(LoanOrCredit, PaymentCard):
+class CreditCard(PaymentCard, LoanOrCredit):
     """A card payment method of a particular brand or name. Used to mark up a particular payment"
      "method and/or the financial product/service that supplies the card account. Commonly"
      "used values: * http://purl.org/goodrelations/v1#AmericanExpress * http://purl.org/goodrelations/v1#DinersClub"
@@ -16,6 +16,5 @@ class CreditCard(LoanOrCredit, PaymentCard):
     See: https://schema.org/CreditCard
     Model depth: 6
     """
-    type_: str = Field("CreditCard", alias='@type')
+    type_: str = Field(default="CreditCard", alias='@type')
     
-
