@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class Crematorium(CivicStructure):
     """A crematorium.
 
-    See https://schema.org/Crematorium.
-
+    See: https://schema.org/Crematorium
+    Model depth: 4
     """
-    type_: str = Field("Crematorium", const=True, alias='@type')
+    type_: str = Field(default="Crematorium", alias='@type')
     
-
-Crematorium.update_forward_refs()
