@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FinancialProduct import FinancialProduct
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FinancialProduct import FinancialProduct
 class CurrencyConversionService(FinancialProduct):
     """A service to convert funds from one currency to another currency.
 
-    See https://schema.org/CurrencyConversionService.
-
+    See: https://schema.org/CurrencyConversionService
+    Model depth: 5
     """
-    type_: str = Field("CurrencyConversionService", const=True, alias='@type')
+    type_: str = Field(default="CurrencyConversionService", alias='@type')
     
-
-CurrencyConversionService.update_forward_refs()
