@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 class DJMixAlbum(MusicAlbumProductionType):
     """DJMixAlbum.
 
-    See https://schema.org/DJMixAlbum.
-
+    See: https://schema.org/DJMixAlbum
+    Model depth: 5
     """
-    type_: str = Field("DJMixAlbum", const=True, alias='@type')
+    type_: str = Field(default="DJMixAlbum", alias='@type')
     
-
-DJMixAlbum.update_forward_refs()
