@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Event import Event
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Event import Event
 class DanceEvent(Event):
     """Event type: A social dance.
 
-    See https://schema.org/DanceEvent.
-
+    See: https://schema.org/DanceEvent
+    Model depth: 3
     """
-    type_: str = Field("DanceEvent", const=True, alias='@type')
+    type_: str = Field(default="DanceEvent", alias='@type')
     
-
-DanceEvent.update_forward_refs()
