@@ -15,7 +15,7 @@ class DataDownload(MediaObject):
     See: https://schema.org/DataDownload
     Model depth: 4
     """
-    type_: str = Field("DataDownload", alias='@type')
+    type_: str = Field(default="DataDownload", alias='@type')
     measurementTechnique: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text']], AnyUrl, 'URL', str, 'Text']] = Field(
         default=None,
         description="A technique or technology used in a [[Dataset]] (or [[DataDownload]], [[DataCatalog]]),"
@@ -32,7 +32,6 @@ class DataDownload(MediaObject):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.Text import Text
