@@ -19,7 +19,7 @@ class DatedMoneySpecification(StructuredValue):
     See: https://schema.org/DatedMoneySpecification
     Model depth: 4
     """
-    type_: str = Field("DatedMoneySpecification", alias='@type')
+    type_: str = Field(default="DatedMoneySpecification", alias='@type')
     amount: Optional[Union[List[Union[Decimal, 'Number', 'MonetaryAmount', str]], Decimal, 'Number', 'MonetaryAmount', str]] = Field(
         default=None,
         description="The amount of money.",
@@ -42,7 +42,6 @@ class DatedMoneySpecification(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
