@@ -15,6 +15,5 @@ class DayOfWeek(Enumeration):
     See: https://schema.org/DayOfWeek
     Model depth: 4
     """
-    type_: str = Field("DayOfWeek", alias='@type')
+    type_: str = Field(default="DayOfWeek", alias='@type')
     
-
