@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ControlAction import ControlAction
 
@@ -6,10 +9,8 @@ class DeactivateAction(ControlAction):
     """The act of stopping or deactivating a device or application (e.g. stopping a timer or"
      "turning off a flashlight).
 
-    See https://schema.org/DeactivateAction.
-
+    See: https://schema.org/DeactivateAction
+    Model depth: 4
     """
-    type_: str = Field("DeactivateAction", const=True, alias='@type')
+    type_: str = Field(default="DeactivateAction", alias='@type')
     
-
-DeactivateAction.update_forward_refs()
