@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MediaManipulationRatingEnumeration import MediaManipulationRatingEnumeration
 
@@ -20,10 +23,8 @@ class DecontextualizedContent(MediaManipulationRatingEnumeration):
      "it. For example, using incorrect dates or locations, or sharing brief clips from a longer"
      "recording to mislead viewers. (Audio rated “original” can also be missing context.)
 
-    See https://schema.org/DecontextualizedContent.
-
+    See: https://schema.org/DecontextualizedContent
+    Model depth: 5
     """
-    type_: str = Field("DecontextualizedContent", const=True, alias='@type')
+    type_: str = Field(default="DecontextualizedContent", alias='@type')
     
-
-DecontextualizedContent.update_forward_refs()
