@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GovernmentBuilding import GovernmentBuilding
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GovernmentBuilding import GovernmentBuilding
 class DefenceEstablishment(GovernmentBuilding):
     """A defence establishment, such as an army or navy base.
 
-    See https://schema.org/DefenceEstablishment.
-
+    See: https://schema.org/DefenceEstablishment
+    Model depth: 5
     """
-    type_: str = Field("DefenceEstablishment", const=True, alias='@type')
+    type_: str = Field(default="DefenceEstablishment", alias='@type')
     
-
-DefenceEstablishment.update_forward_refs()
