@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LegalValueLevel import LegalValueLevel
 
@@ -7,10 +10,8 @@ class DefinitiveLegalValue(LegalValueLevel):
      "binding. (e.g. The digitally signed version of an Official Journal.) Something \"Definitive\""
      "is considered to be also [[AuthoritativeLegalValue]].
 
-    See https://schema.org/DefinitiveLegalValue.
-
+    See: https://schema.org/DefinitiveLegalValue
+    Model depth: 5
     """
-    type_: str = Field("DefinitiveLegalValue", const=True, alias='@type')
+    type_: str = Field(default="DefinitiveLegalValue", alias='@type')
     
-
-DefinitiveLegalValue.update_forward_refs()
