@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.UpdateAction import UpdateAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.UpdateAction import UpdateAction
 class DeleteAction(UpdateAction):
     """The act of editing a recipient by removing one of its objects.
 
-    See https://schema.org/DeleteAction.
-
+    See: https://schema.org/DeleteAction
+    Model depth: 4
     """
-    type_: str = Field("DeleteAction", const=True, alias='@type')
+    type_: str = Field(default="DeleteAction", alias='@type')
     
-
-DeleteAction.update_forward_refs()
