@@ -14,7 +14,7 @@ class DeliveryChargeSpecification(PriceSpecification):
     See: https://schema.org/DeliveryChargeSpecification
     Model depth: 5
     """
-    type_: str = Field("DeliveryChargeSpecification", alias='@type')
+    type_: str = Field(default="DeliveryChargeSpecification", alias='@type')
     areaServed: Optional[Union[List[Union[str, 'Text', 'GeoShape', 'AdministrativeArea', 'Place']], str, 'Text', 'GeoShape', 'AdministrativeArea', 'Place']] = Field(
         default=None,
         description="The geographic area where a service or offered item is provided.",
@@ -38,7 +38,6 @@ class DeliveryChargeSpecification(PriceSpecification):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.GeoShape import GeoShape
