@@ -18,7 +18,7 @@ class Demand(Intangible):
     See: https://schema.org/Demand
     Model depth: 3
     """
-    type_: str = Field("Demand", alias='@type')
+    type_: str = Field(default="Demand", alias='@type')
     includesObject: Optional[Union[List[Union['TypeAndQuantityNode', str]], 'TypeAndQuantityNode', str]] = Field(
         default=None,
         description="This links to a node or nodes indicating the exact quantity of the products included in"
@@ -66,7 +66,7 @@ class Demand(Intangible):
      "above a certain order volume, or to limit the acceptance of credit cards to purchases"
      "to a certain minimal amount.",
     )
-    acceptedPaymentMethod: Optional[Union[List[Union['LoanOrCredit', 'PaymentMethod', str]], 'LoanOrCredit', 'PaymentMethod', str]] = Field(
+    acceptedPaymentMethod: Optional[Union[List[Union['PaymentMethod', 'LoanOrCredit', str]], 'PaymentMethod', 'LoanOrCredit', str]] = Field(
         default=None,
         description="The payment method(s) accepted by seller for this offer.",
     )
@@ -79,7 +79,7 @@ class Demand(Intangible):
         default=None,
         description="The duration for which the given offer is valid.",
     )
-    availabilityStarts: Optional[Union[List[Union[ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]], ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]] = Field(
+    availabilityStarts: Optional[Union[List[Union[ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]], ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]] = Field(
         default=None,
         description="The beginning of the availability of the product or service included in the offer.",
     )
@@ -122,7 +122,7 @@ class Demand(Intangible):
         default=None,
         description="The date when the item becomes valid.",
     )
-    itemOffered: Optional[Union[List[Union['CreativeWork', 'Trip', 'Event', 'Product', 'Service', 'MenuItem', 'AggregateOffer', str]], 'CreativeWork', 'Trip', 'Event', 'Product', 'Service', 'MenuItem', 'AggregateOffer', str]] = Field(
+    itemOffered: Optional[Union[List[Union['Product', 'Event', 'MenuItem', 'AggregateOffer', 'Service', 'Trip', 'CreativeWork', str]], 'Product', 'Event', 'MenuItem', 'AggregateOffer', 'Service', 'Trip', 'CreativeWork', str]] = Field(
         default=None,
         description="An item being offered (or demanded). The transactional nature of the offer or demand"
      "is documented using [[businessFunction]], e.g. sell, lease etc. While several common"
@@ -134,7 +134,7 @@ class Demand(Intangible):
         description="The GTIN-14 code of the product, or the product to which the offer refers. See [GS1 GTIN"
      "Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
     )
-    availabilityEnds: Optional[Union[List[Union[ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]], ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]] = Field(
+    availabilityEnds: Optional[Union[List[Union[ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]], ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]] = Field(
         default=None,
         description="The end of the availability of the product or service included in the offer.",
     )
@@ -195,7 +195,6 @@ class Demand(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.TypeAndQuantityNode import TypeAndQuantityNode
     from pydantic_schemaorg.Text import Text
@@ -206,21 +205,21 @@ if TYPE_CHECKING:
     from pydantic_schemaorg.BusinessEntityType import BusinessEntityType
     from pydantic_schemaorg.ItemAvailability import ItemAvailability
     from pydantic_schemaorg.PriceSpecification import PriceSpecification
-    from pydantic_schemaorg.LoanOrCredit import LoanOrCredit
     from pydantic_schemaorg.PaymentMethod import PaymentMethod
+    from pydantic_schemaorg.LoanOrCredit import LoanOrCredit
     from pydantic_schemaorg.BusinessFunction import BusinessFunction
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
     from pydantic_schemaorg.DateTime import DateTime
-    from pydantic_schemaorg.Date import Date
     from pydantic_schemaorg.Time import Time
+    from pydantic_schemaorg.Date import Date
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.WarrantyPromise import WarrantyPromise
-    from pydantic_schemaorg.CreativeWork import CreativeWork
-    from pydantic_schemaorg.Trip import Trip
-    from pydantic_schemaorg.Event import Event
     from pydantic_schemaorg.Product import Product
-    from pydantic_schemaorg.Service import Service
+    from pydantic_schemaorg.Event import Event
     from pydantic_schemaorg.MenuItem import MenuItem
     from pydantic_schemaorg.AggregateOffer import AggregateOffer
+    from pydantic_schemaorg.Service import Service
+    from pydantic_schemaorg.Trip import Trip
+    from pydantic_schemaorg.CreativeWork import CreativeWork
     from pydantic_schemaorg.OfferItemCondition import OfferItemCondition
