@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 class DemoAlbum(MusicAlbumProductionType):
     """DemoAlbum.
 
-    See https://schema.org/DemoAlbum.
-
+    See: https://schema.org/DemoAlbum
+    Model depth: 5
     """
-    type_: str = Field("DemoAlbum", const=True, alias='@type')
+    type_: str = Field(default="DemoAlbum", alias='@type')
     
-
-DemoAlbum.update_forward_refs()
