@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 class Dentistry(MedicalSpecialty):
     """A branch of medicine that is involved in the dental care.
 
-    See https://schema.org/Dentistry.
-
+    See: https://schema.org/Dentistry
+    Model depth: 6
     """
-    type_: str = Field("Dentistry", const=True, alias='@type')
+    type_: str = Field(default="Dentistry", alias='@type')
     
-
-Dentistry.update_forward_refs()
