@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 class DiabeticDiet(RestrictedDiet):
     """A diet appropriate for people with diabetes.
 
-    See https://schema.org/DiabeticDiet.
-
+    See: https://schema.org/DiabeticDiet
+    Model depth: 5
     """
-    type_: str = Field("DiabeticDiet", const=True, alias='@type')
+    type_: str = Field(default="DiabeticDiet", alias='@type')
     
-
-DiabeticDiet.update_forward_refs()
