@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalDevicePurpose import MedicalDevicePurpose
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalDevicePurpose import MedicalDevicePurpose
 class Diagnostic(MedicalDevicePurpose):
     """A medical device used for diagnostic purposes.
 
-    See https://schema.org/Diagnostic.
-
+    See: https://schema.org/Diagnostic
+    Model depth: 6
     """
-    type_: str = Field("Diagnostic", const=True, alias='@type')
+    type_: str = Field(default="Diagnostic", alias='@type')
     
-
-Diagnostic.update_forward_refs()
