@@ -14,13 +14,12 @@ class DiagnosticLab(MedicalOrganization):
     See: https://schema.org/DiagnosticLab
     Model depth: 4
     """
-    type_: str = Field("DiagnosticLab", alias='@type')
+    type_: str = Field(default="DiagnosticLab", alias='@type')
     availableTest: Optional[Union[List[Union['MedicalTest', str]], 'MedicalTest', str]] = Field(
         default=None,
         description="A diagnostic test or procedure offered by this lab.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalTest import MedicalTest
