@@ -16,7 +16,7 @@ class Diet(LifestyleModification, CreativeWork):
     See: https://schema.org/Diet
     Model depth: 3
     """
-    type_: str = Field("Diet", alias='@type')
+    type_: str = Field(default="Diet", alias='@type')
     risks: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Specific physiologic risks associated to the diet plan.",
@@ -41,7 +41,6 @@ class Diet(LifestyleModification, CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Person import Person
