@@ -1,15 +1,16 @@
+from __future__ import annotations
+
+
 from pydantic import Field
-from pydantic_schemaorg.MedicalBusiness import MedicalBusiness
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
+from pydantic_schemaorg.MedicalBusiness import MedicalBusiness
 
 
-class DietNutrition(MedicalBusiness, MedicalSpecialty):
+class DietNutrition(MedicalSpecialty, MedicalBusiness):
     """Dietetic and nutrition as a medical specialty.
 
-    See https://schema.org/DietNutrition.
-
+    See: https://schema.org/DietNutrition
+    Model depth: 5
     """
-    type_: str = Field("DietNutrition", const=True, alias='@type')
+    type_: str = Field(default="DietNutrition", alias='@type')
     
-
-DietNutrition.update_forward_refs()
