@@ -17,7 +17,7 @@ class DietarySupplement(Substance):
     See: https://schema.org/DietarySupplement
     Model depth: 4
     """
-    type_: str = Field("DietarySupplement", alias='@type')
+    type_: str = Field(default="DietarySupplement", alias='@type')
     safetyConsideration: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Any potential safety concern associated with the supplement. May include interactions"
@@ -71,7 +71,6 @@ class DietarySupplement(Substance):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.RecommendedDoseSchedule import RecommendedDoseSchedule
