@@ -14,21 +14,20 @@ class DigitalDocumentPermission(Intangible):
     See: https://schema.org/DigitalDocumentPermission
     Model depth: 3
     """
-    type_: str = Field("DigitalDocumentPermission", alias='@type')
+    type_: str = Field(default="DigitalDocumentPermission", alias='@type')
     permissionType: Optional[Union[List[Union['DigitalDocumentPermissionType', str]], 'DigitalDocumentPermissionType', str]] = Field(
         default=None,
         description="The type of permission granted the person, organization, or audience.",
     )
-    grantee: Optional[Union[List[Union['Person', 'Organization', 'Audience', 'ContactPoint', str]], 'Person', 'Organization', 'Audience', 'ContactPoint', str]] = Field(
+    grantee: Optional[Union[List[Union['Person', 'Audience', 'Organization', 'ContactPoint', str]], 'Person', 'Audience', 'Organization', 'ContactPoint', str]] = Field(
         default=None,
         description="The person, organization, contact point, or audience that has been granted this permission.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.DigitalDocumentPermissionType import DigitalDocumentPermissionType
     from pydantic_schemaorg.Person import Person
-    from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.Audience import Audience
+    from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.ContactPoint import ContactPoint
