@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class DigitalDocumentPermissionType(Enumeration):
     """A type of permission which can be granted for accessing a digital document.
 
-    See https://schema.org/DigitalDocumentPermissionType.
-
+    See: https://schema.org/DigitalDocumentPermissionType
+    Model depth: 4
     """
-    type_: str = Field("DigitalDocumentPermissionType", const=True, alias='@type')
+    type_: str = Field(default="DigitalDocumentPermissionType", alias='@type')
     
-
-DigitalDocumentPermissionType.update_forward_refs()
