@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType
 class DigitalFormat(MusicReleaseFormatType):
     """DigitalFormat.
 
-    See https://schema.org/DigitalFormat.
-
+    See: https://schema.org/DigitalFormat
+    Model depth: 5
     """
-    type_: str = Field("DigitalFormat", const=True, alias='@type')
+    type_: str = Field(default="DigitalFormat", alias='@type')
     
-
-DigitalFormat.update_forward_refs()
