@@ -11,6 +11,5 @@ class DisabilitySupport(GovernmentBenefitsType):
     See: https://schema.org/DisabilitySupport
     Model depth: 5
     """
-    type_: str = Field("DisabilitySupport", alias='@type')
+    type_: str = Field(default="DisabilitySupport", alias='@type')
     
-
