@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.SocialMediaPosting import SocialMediaPosting
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.SocialMediaPosting import SocialMediaPosting
 class DiscussionForumPosting(SocialMediaPosting):
     """A posting to a discussion forum.
 
-    See https://schema.org/DiscussionForumPosting.
-
+    See: https://schema.org/DiscussionForumPosting
+    Model depth: 5
     """
-    type_: str = Field("DiscussionForumPosting", const=True, alias='@type')
+    type_: str = Field(default="DiscussionForumPosting", alias='@type')
     
-
-DiscussionForumPosting.update_forward_refs()
