@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 class Distillery(FoodEstablishment):
     """A distillery.
 
-    See https://schema.org/Distillery.
-
+    See: https://schema.org/Distillery
+    Model depth: 5
     """
-    type_: str = Field("Distillery", const=True, alias='@type')
+    type_: str = Field(default="Distillery", alias='@type')
     
-
-Distillery.update_forward_refs()
