@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.TransferAction import TransferAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.TransferAction import TransferAction
 class DownloadAction(TransferAction):
     """The act of downloading an object.
 
-    See https://schema.org/DownloadAction.
-
+    See: https://schema.org/DownloadAction
+    Model depth: 4
     """
-    type_: str = Field("DownloadAction", const=True, alias='@type')
+    type_: str = Field(default="DownloadAction", alias='@type')
     
-
-DownloadAction.update_forward_refs()
