@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CreativeWork import CreativeWork
 class Drawing(CreativeWork):
     """A picture or diagram made with a pencil, pen, or crayon rather than paint.
 
-    See https://schema.org/Drawing.
-
+    See: https://schema.org/Drawing
+    Model depth: 3
     """
-    type_: str = Field("Drawing", const=True, alias='@type')
+    type_: str = Field(default="Drawing", alias='@type')
     
-
-Drawing.update_forward_refs()
