@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.QualitativeValue import QualitativeValue
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.QualitativeValue import QualitativeValue
 class DriveWheelConfigurationValue(QualitativeValue):
     """A value indicating which roadwheels will receive torque.
 
-    See https://schema.org/DriveWheelConfigurationValue.
-
+    See: https://schema.org/DriveWheelConfigurationValue
+    Model depth: 5
     """
-    type_: str = Field("DriveWheelConfigurationValue", const=True, alias='@type')
+    type_: str = Field(default="DriveWheelConfigurationValue", alias='@type')
     
-
-DriveWheelConfigurationValue.update_forward_refs()
