@@ -20,7 +20,7 @@ class DrugCost(MedicalEntity):
     See: https://schema.org/DrugCost
     Model depth: 3
     """
-    type_: str = Field("DrugCost", alias='@type')
+    type_: str = Field(default="DrugCost", alias='@type')
     costCategory: Optional[Union[List[Union['DrugCostCategory', str]], 'DrugCostCategory', str]] = Field(
         default=None,
         description="The category of cost, such as wholesale, retail, reimbursement cap, etc.",
@@ -48,7 +48,6 @@ class DrugCost(MedicalEntity):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.DrugCostCategory import DrugCostCategory
     from pydantic_schemaorg.Text import Text
