@@ -12,6 +12,5 @@ class DrugPregnancyCategory(MedicalEnumeration):
     See: https://schema.org/DrugPregnancyCategory
     Model depth: 5
     """
-    type_: str = Field("DrugPregnancyCategory", alias='@type')
+    type_: str = Field(default="DrugPregnancyCategory", alias='@type')
     
-
