@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
 class DrugPrescriptionStatus(MedicalEnumeration):
     """Indicates whether this drug is available by prescription or over-the-counter.
 
-    See https://schema.org/DrugPrescriptionStatus.
-
+    See: https://schema.org/DrugPrescriptionStatus
+    Model depth: 5
     """
-    type_: str = Field("DrugPrescriptionStatus", const=True, alias='@type')
+    type_: str = Field(default="DrugPrescriptionStatus", alias='@type')
     
-
-DrugPrescriptionStatus.update_forward_refs()
