@@ -11,6 +11,5 @@ class DryCleaningOrLaundry(LocalBusiness):
     See: https://schema.org/DryCleaningOrLaundry
     Model depth: 4
     """
-    type_: str = Field("DryCleaningOrLaundry", alias='@type')
+    type_: str = Field(default="DryCleaningOrLaundry", alias='@type')
     
-
