@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Quantity import Quantity
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Quantity import Quantity
 class Duration(Quantity):
     """Quantity: Duration (use [ISO 8601 duration format](http://en.wikipedia.org/wiki/ISO_8601)).
 
-    See https://schema.org/Duration.
-
+    See: https://schema.org/Duration
+    Model depth: 4
     """
-    type_: str = Field("Duration", const=True, alias='@type')
+    type_: str = Field(default="Duration", alias='@type')
     
-
-Duration.update_forward_refs()
