@@ -11,6 +11,5 @@ class EBook(BookFormatType):
     See: https://schema.org/EBook
     Model depth: 5
     """
-    type_: str = Field("EBook", alias='@type')
+    type_: str = Field(default="EBook", alias='@type')
     
-
