@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EUEnergyEfficiencyEnumeration import EUEnergyEfficiencyEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.EUEnergyEfficiencyEnumeration import EUEnergyEfficiencyE
 class EUEnergyEfficiencyCategoryA1Plus(EUEnergyEfficiencyEnumeration):
     """Represents EU Energy Efficiency Class A+ as defined in EU energy labeling regulations.
 
-    See https://schema.org/EUEnergyEfficiencyCategoryA1Plus.
-
+    See: https://schema.org/EUEnergyEfficiencyCategoryA1Plus
+    Model depth: 6
     """
-    type_: str = Field("EUEnergyEfficiencyCategoryA1Plus", const=True, alias='@type')
+    type_: str = Field(default="EUEnergyEfficiencyCategoryA1Plus", alias='@type')
     
-
-EUEnergyEfficiencyCategoryA1Plus.update_forward_refs()
