@@ -11,6 +11,5 @@ class EUEnergyEfficiencyCategoryA3Plus(EUEnergyEfficiencyEnumeration):
     See: https://schema.org/EUEnergyEfficiencyCategoryA3Plus
     Model depth: 6
     """
-    type_: str = Field("EUEnergyEfficiencyCategoryA3Plus", alias='@type')
+    type_: str = Field(default="EUEnergyEfficiencyCategoryA3Plus", alias='@type')
     
-
