@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EUEnergyEfficiencyEnumeration import EUEnergyEfficiencyEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.EUEnergyEfficiencyEnumeration import EUEnergyEfficiencyE
 class EUEnergyEfficiencyCategoryB(EUEnergyEfficiencyEnumeration):
     """Represents EU Energy Efficiency Class B as defined in EU energy labeling regulations.
 
-    See https://schema.org/EUEnergyEfficiencyCategoryB.
-
+    See: https://schema.org/EUEnergyEfficiencyCategoryB
+    Model depth: 6
     """
-    type_: str = Field("EUEnergyEfficiencyCategoryB", const=True, alias='@type')
+    type_: str = Field(default="EUEnergyEfficiencyCategoryB", alias='@type')
     
-
-EUEnergyEfficiencyCategoryB.update_forward_refs()
