@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EUEnergyEfficiencyEnumeration import EUEnergyEfficiencyEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.EUEnergyEfficiencyEnumeration import EUEnergyEfficiencyE
 class EUEnergyEfficiencyCategoryC(EUEnergyEfficiencyEnumeration):
     """Represents EU Energy Efficiency Class C as defined in EU energy labeling regulations.
 
-    See https://schema.org/EUEnergyEfficiencyCategoryC.
-
+    See: https://schema.org/EUEnergyEfficiencyCategoryC
+    Model depth: 6
     """
-    type_: str = Field("EUEnergyEfficiencyCategoryC", const=True, alias='@type')
+    type_: str = Field(default="EUEnergyEfficiencyCategoryC", alias='@type')
     
-
-EUEnergyEfficiencyCategoryC.update_forward_refs()
