@@ -11,6 +11,5 @@ class EUEnergyEfficiencyCategoryE(EUEnergyEfficiencyEnumeration):
     See: https://schema.org/EUEnergyEfficiencyCategoryE
     Model depth: 6
     """
-    type_: str = Field("EUEnergyEfficiencyCategoryE", alias='@type')
+    type_: str = Field(default="EUEnergyEfficiencyCategoryE", alias='@type')
     
-
