@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class Ear(PhysicalExam):
     """Ear function assessment with clinical examination.
 
-    See https://schema.org/Ear.
-
+    See: https://schema.org/Ear
+    Model depth: 5
     """
-    type_: str = Field("Ear", const=True, alias='@type')
+    type_: str = Field(default="Ear", alias='@type')
     
-
-Ear.update_forward_refs()
