@@ -14,13 +14,12 @@ class EducationalAudience(Audience):
     See: https://schema.org/EducationalAudience
     Model depth: 4
     """
-    type_: str = Field("EducationalAudience", alias='@type')
+    type_: str = Field(default="EducationalAudience", alias='@type')
     educationalRole: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="An educationalRole of an EducationalAudience.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
