@@ -15,13 +15,12 @@ class EducationalOrganization(CivicStructure, Organization):
     See: https://schema.org/EducationalOrganization
     Model depth: 3
     """
-    type_: str = Field("EducationalOrganization", alias='@type')
+    type_: str = Field(default="EducationalOrganization", alias='@type')
     alumni: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="Alumni of an organization.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
