@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class EffectivenessHealthAspect(HealthAspectEnumeration):
     """Content about the effectiveness-related aspects of a health topic.
 
-    See https://schema.org/EffectivenessHealthAspect.
-
+    See: https://schema.org/EffectivenessHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("EffectivenessHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="EffectivenessHealthAspect", alias='@type')
     
-
-EffectivenessHealthAspect.update_forward_refs()
