@@ -11,6 +11,5 @@ class ElementarySchool(EducationalOrganization):
     See: https://schema.org/ElementarySchool
     Model depth: 4
     """
-    type_: str = Field("ElementarySchool", alias='@type')
+    type_: str = Field(default="ElementarySchool", alias='@type')
     
-
