@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GovernmentBuilding import GovernmentBuilding
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GovernmentBuilding import GovernmentBuilding
 class Embassy(GovernmentBuilding):
     """An embassy.
 
-    See https://schema.org/Embassy.
-
+    See: https://schema.org/Embassy
+    Model depth: 5
     """
-    type_: str = Field("Embassy", const=True, alias='@type')
+    type_: str = Field(default="Embassy", alias='@type')
     
-
-Embassy.update_forward_refs()
