@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class EmergencyService(LocalBusiness):
     """An emergency service, such as a fire station or ER.
 
-    See https://schema.org/EmergencyService.
-
+    See: https://schema.org/EmergencyService
+    Model depth: 4
     """
-    type_: str = Field("EmergencyService", const=True, alias='@type')
+    type_: str = Field(default="EmergencyService", alias='@type')
     
-
-EmergencyService.update_forward_refs()
