@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AggregateRating import AggregateRating
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AggregateRating import AggregateRating
 class EmployerAggregateRating(AggregateRating):
     """An aggregate rating of an Organization related to its role as an employer.
 
-    See https://schema.org/EmployerAggregateRating.
-
+    See: https://schema.org/EmployerAggregateRating
+    Model depth: 5
     """
-    type_: str = Field("EmployerAggregateRating", const=True, alias='@type')
+    type_: str = Field(default="EmployerAggregateRating", alias='@type')
     
-
-EmployerAggregateRating.update_forward_refs()
