@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class EmploymentAgency(LocalBusiness):
     """An employment agency.
 
-    See https://schema.org/EmploymentAgency.
-
+    See: https://schema.org/EmploymentAgency
+    Model depth: 4
     """
-    type_: str = Field("EmploymentAgency", const=True, alias='@type')
+    type_: str = Field(default="EmploymentAgency", alias='@type')
     
-
-EmploymentAgency.update_forward_refs()
