@@ -14,14 +14,13 @@ class EndorseAction(ReactAction):
     See: https://schema.org/EndorseAction
     Model depth: 5
     """
-    type_: str = Field("EndorseAction", alias='@type')
+    type_: str = Field(default="EndorseAction", alias='@type')
     endorsee: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="A sub property of participant. The person/organization being supported.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
