@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Quantity import Quantity
 
@@ -6,10 +9,8 @@ class Energy(Quantity):
     """Properties that take Energy as values are of the form '&lt;Number&gt; &lt;Energy unit"
      "of measure&gt;'.
 
-    See https://schema.org/Energy.
-
+    See: https://schema.org/Energy
+    Model depth: 4
     """
-    type_: str = Field("Energy", const=True, alias='@type')
+    type_: str = Field(default="Energy", alias='@type')
     
-
-Energy.update_forward_refs()
