@@ -18,7 +18,7 @@ class EnergyConsumptionDetails(Intangible):
     See: https://schema.org/EnergyConsumptionDetails
     Model depth: 3
     """
-    type_: str = Field("EnergyConsumptionDetails", alias='@type')
+    type_: str = Field(default="EnergyConsumptionDetails", alias='@type')
     energyEfficiencyScaleMax: Optional[Union[List[Union['EUEnergyEfficiencyEnumeration', str]], 'EUEnergyEfficiencyEnumeration', str]] = Field(
         default=None,
         description="Specifies the most energy efficient class on the regulated EU energy consumption scale"
@@ -39,7 +39,6 @@ class EnergyConsumptionDetails(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.EUEnergyEfficiencyEnumeration import EUEnergyEfficiencyEnumeration
     from pydantic_schemaorg.EnergyEfficiencyEnumeration import EnergyEfficiencyEnumeration
