@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -6,10 +9,8 @@ class EnergyEfficiencyEnumeration(Enumeration):
     """Enumerates energy efficiency levels (also known as \"classes\" or \"ratings\") and"
      "certifications that are part of several international energy efficiency standards.
 
-    See https://schema.org/EnergyEfficiencyEnumeration.
-
+    See: https://schema.org/EnergyEfficiencyEnumeration
+    Model depth: 4
     """
-    type_: str = Field("EnergyEfficiencyEnumeration", const=True, alias='@type')
+    type_: str = Field(default="EnergyEfficiencyEnumeration", alias='@type')
     
-
-EnergyEfficiencyEnumeration.update_forward_refs()
