@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EnergyStarEnergyEfficiencyEnumeration import EnergyStarEnergyEfficiencyEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.EnergyStarEnergyEfficiencyEnumeration import EnergyStarE
 class EnergyStarCertified(EnergyStarEnergyEfficiencyEnumeration):
     """Represents EnergyStar certification.
 
-    See https://schema.org/EnergyStarCertified.
-
+    See: https://schema.org/EnergyStarCertified
+    Model depth: 6
     """
-    type_: str = Field("EnergyStarCertified", const=True, alias='@type')
+    type_: str = Field(default="EnergyStarCertified", alias='@type')
     
-
-EnergyStarCertified.update_forward_refs()
