@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EnergyEfficiencyEnumeration import EnergyEfficiencyEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.EnergyEfficiencyEnumeration import EnergyEfficiencyEnume
 class EnergyStarEnergyEfficiencyEnumeration(EnergyEfficiencyEnumeration):
     """Used to indicate whether a product is EnergyStar certified.
 
-    See https://schema.org/EnergyStarEnergyEfficiencyEnumeration.
-
+    See: https://schema.org/EnergyStarEnergyEfficiencyEnumeration
+    Model depth: 5
     """
-    type_: str = Field("EnergyStarEnergyEfficiencyEnumeration", const=True, alias='@type')
+    type_: str = Field(default="EnergyStarEnergyEfficiencyEnumeration", alias='@type')
     
-
-EnergyStarEnergyEfficiencyEnumeration.update_forward_refs()
