@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 class EnrollingByInvitation(MedicalStudyStatus):
     """Enrolling participants by invitation only.
 
-    See https://schema.org/EnrollingByInvitation.
-
+    See: https://schema.org/EnrollingByInvitation
+    Model depth: 6
     """
-    type_: str = Field("EnrollingByInvitation", const=True, alias='@type')
+    type_: str = Field(default="EnrollingByInvitation", alias='@type')
     
-
-EnrollingByInvitation.update_forward_refs()
