@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class EntertainmentBusiness(LocalBusiness):
     """A business providing entertainment.
 
-    See https://schema.org/EntertainmentBusiness.
-
+    See: https://schema.org/EntertainmentBusiness
+    Model depth: 4
     """
-    type_: str = Field("EntertainmentBusiness", const=True, alias='@type')
+    type_: str = Field(default="EntertainmentBusiness", alias='@type')
     
-
-EntertainmentBusiness.update_forward_refs()
