@@ -15,7 +15,7 @@ class EntryPoint(Intangible):
     See: https://schema.org/EntryPoint
     Model depth: 3
     """
-    type_: str = Field("EntryPoint", alias='@type')
+    type_: str = Field(default="EntryPoint", alias='@type')
     contentType: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The supported content type(s) for an EntryPoint response.",
@@ -49,7 +49,6 @@ class EntryPoint(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.SoftwareApplication import SoftwareApplication
