@@ -14,7 +14,7 @@ class Episode(CreativeWork):
     See: https://schema.org/Episode
     Model depth: 3
     """
-    type_: str = Field("Episode", alias='@type')
+    type_: str = Field(default="Episode", alias='@type')
     partOfSeason: Optional[Union[List[Union['CreativeWorkSeason', str]], 'CreativeWorkSeason', str]] = Field(
         default=None,
         description="The season to which this episode belongs.",
@@ -66,7 +66,6 @@ class Episode(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.CreativeWorkSeason import CreativeWorkSeason
     from pydantic_schemaorg.Person import Person
