@@ -19,7 +19,7 @@ class Event(Thing):
     See: https://schema.org/Event
     Model depth: 2
     """
-    type_: str = Field("Event", alias='@type')
+    type_: str = Field(default="Event", alias='@type')
     subEvent: Optional[Union[List[Union['Event', str]], 'Event', str]] = Field(
         default=None,
         description="An Event that is part of this event. For example, a conference event includes many presentations,"
@@ -29,7 +29,7 @@ class Event(Thing):
         default=None,
         description="The subject matter of the content.",
     )
-    offers: Optional[Union[List[Union['Demand', 'Offer', str]], 'Demand', 'Offer', str]] = Field(
+    offers: Optional[Union[List[Union['Offer', 'Demand', str]], 'Offer', 'Demand', str]] = Field(
         default=None,
         description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the"
      "DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]]"
@@ -90,7 +90,7 @@ class Event(Thing):
         description="A director of e.g. tv, radio, movie, video gaming etc. content, or of an event. Directors"
      "can be associated with individual items or with a series, episode, clip.",
     )
-    location: Optional[Union[List[Union[str, 'Text', 'Place', 'VirtualLocation', 'PostalAddress']], str, 'Text', 'Place', 'VirtualLocation', 'PostalAddress']] = Field(
+    location: Optional[Union[List[Union[str, 'Text', 'VirtualLocation', 'PostalAddress', 'Place']], str, 'Text', 'VirtualLocation', 'PostalAddress', 'Place']] = Field(
         default=None,
         description="The location of, for example, where an event is happening, where an organization is located,"
      "or where an action takes place.",
@@ -214,11 +214,10 @@ class Event(Thing):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Thing import Thing
-    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.Offer import Offer
+    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.DateTime import DateTime
     from pydantic_schemaorg.Time import Time
     from pydantic_schemaorg.Text import Text
@@ -228,9 +227,9 @@ if TYPE_CHECKING:
     from pydantic_schemaorg.AggregateRating import AggregateRating
     from pydantic_schemaorg.Duration import Duration
     from pydantic_schemaorg.Date import Date
-    from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.VirtualLocation import VirtualLocation
     from pydantic_schemaorg.PostalAddress import PostalAddress
+    from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.EventStatusType import EventStatusType
     from pydantic_schemaorg.Audience import Audience
     from pydantic_schemaorg.CreativeWork import CreativeWork
