@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EventStatusType import EventStatusType
 
@@ -7,10 +10,8 @@ class EventCancelled(EventStatusType):
      "to be cancelled. Either startDate or previousStartDate may be used to specify the event's"
      "cancelled date(s).
 
-    See https://schema.org/EventCancelled.
-
+    See: https://schema.org/EventCancelled
+    Model depth: 6
     """
-    type_: str = Field("EventCancelled", const=True, alias='@type')
+    type_: str = Field(default="EventCancelled", alias='@type')
     
-
-EventCancelled.update_forward_refs()
