@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EventStatusType import EventStatusType
 
@@ -6,10 +9,8 @@ class EventMovedOnline(EventStatusType):
     """Indicates that the event was changed to allow online participation. See [[eventAttendanceMode]]"
      "for specifics of whether it is now fully or partially online.
 
-    See https://schema.org/EventMovedOnline.
-
+    See: https://schema.org/EventMovedOnline
+    Model depth: 6
     """
-    type_: str = Field("EventMovedOnline", const=True, alias='@type')
+    type_: str = Field(default="EventMovedOnline", alias='@type')
     
-
-EventMovedOnline.update_forward_refs()
