@@ -12,6 +12,5 @@ class EventPostponed(EventStatusType):
     See: https://schema.org/EventPostponed
     Model depth: 6
     """
-    type_: str = Field("EventPostponed", alias='@type')
+    type_: str = Field(default="EventPostponed", alias='@type')
     
-
