@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EventStatusType import EventStatusType
 
@@ -7,10 +10,8 @@ class EventRescheduled(EventStatusType):
      "date and the startDate should be set to the event's new date. (If the event has been rescheduled"
      "multiple times, the previousStartDate property may be repeated).
 
-    See https://schema.org/EventRescheduled.
-
+    See: https://schema.org/EventRescheduled
+    Model depth: 6
     """
-    type_: str = Field("EventRescheduled", const=True, alias='@type')
+    type_: str = Field(default="EventRescheduled", alias='@type')
     
-
-EventRescheduled.update_forward_refs()
