@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Reservation import Reservation
 
@@ -7,10 +10,8 @@ class EventReservation(Reservation):
      "is for information about actual reservations, e.g. in confirmation emails or HTML pages"
      "with individual confirmations of reservations. For offers of tickets, use [[Offer]].
 
-    See https://schema.org/EventReservation.
-
+    See: https://schema.org/EventReservation
+    Model depth: 4
     """
-    type_: str = Field("EventReservation", const=True, alias='@type')
+    type_: str = Field(default="EventReservation", alias='@type')
     
-
-EventReservation.update_forward_refs()
