@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalEvidenceLevel import MedicalEvidenceLevel
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalEvidenceLevel import MedicalEvidenceLevel
 class EvidenceLevelA(MedicalEvidenceLevel):
     """Data derived from multiple randomized clinical trials or meta-analyses.
 
-    See https://schema.org/EvidenceLevelA.
-
+    See: https://schema.org/EvidenceLevelA
+    Model depth: 6
     """
-    type_: str = Field("EvidenceLevelA", const=True, alias='@type')
+    type_: str = Field(default="EvidenceLevelA", alias='@type')
     
-
-EvidenceLevelA.update_forward_refs()
