@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalEvidenceLevel import MedicalEvidenceLevel
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalEvidenceLevel import MedicalEvidenceLevel
 class EvidenceLevelC(MedicalEvidenceLevel):
     """Only consensus opinion of experts, case studies, or standard-of-care.
 
-    See https://schema.org/EvidenceLevelC.
-
+    See: https://schema.org/EvidenceLevelC
+    Model depth: 6
     """
-    type_: str = Field("EvidenceLevelC", const=True, alias='@type')
+    type_: str = Field(default="EvidenceLevelC", alias='@type')
     
-
-EvidenceLevelC.update_forward_refs()
