@@ -15,7 +15,7 @@ class ExchangeRateSpecification(StructuredValue):
     See: https://schema.org/ExchangeRateSpecification
     Model depth: 4
     """
-    type_: str = Field("ExchangeRateSpecification", alias='@type')
+    type_: str = Field(default="ExchangeRateSpecification", alias='@type')
     exchangeRateSpread: Optional[Union[List[Union[Decimal, 'Number', 'MonetaryAmount', str]], Decimal, 'Number', 'MonetaryAmount', str]] = Field(
         default=None,
         description="The difference between the price at which a broker or other intermediary buys and sells"
@@ -35,7 +35,6 @@ class ExchangeRateSpecification(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
