@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RefundTypeEnumeration import RefundTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RefundTypeEnumeration import RefundTypeEnumeration
 class ExchangeRefund(RefundTypeEnumeration):
     """Specifies that a refund can be done as an exchange for the same product.
 
-    See https://schema.org/ExchangeRefund.
-
+    See: https://schema.org/ExchangeRefund
+    Model depth: 5
     """
-    type_: str = Field("ExchangeRefund", const=True, alias='@type')
+    type_: str = Field(default="ExchangeRefund", alias='@type')
     
-
-ExchangeRefund.update_forward_refs()
