@@ -11,6 +11,5 @@ class ExerciseGym(SportsActivityLocation):
     See: https://schema.org/ExerciseGym
     Model depth: 5
     """
-    type_: str = Field("ExerciseGym", alias='@type')
+    type_: str = Field(default="ExerciseGym", alias='@type')
     
-
