@@ -17,7 +17,7 @@ class ExercisePlan(PhysicalActivity, CreativeWork):
     See: https://schema.org/ExercisePlan
     Model depth: 3
     """
-    type_: str = Field("ExercisePlan", alias='@type')
+    type_: str = Field(default="ExercisePlan", alias='@type')
     repetitions: Optional[Union[List[Union[Decimal, 'Number', 'QuantitativeValue', str]], Decimal, 'Number', 'QuantitativeValue', str]] = Field(
         default=None,
         description="Number of times one should repeat the activity.",
@@ -57,7 +57,6 @@ class ExercisePlan(PhysicalActivity, CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
