@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RadioChannel import RadioChannel
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RadioChannel import RadioChannel
 class FMRadioChannel(RadioChannel):
     """A radio channel that uses FM.
 
-    See https://schema.org/FMRadioChannel.
-
+    See: https://schema.org/FMRadioChannel
+    Model depth: 5
     """
-    type_: str = Field("FMRadioChannel", const=True, alias='@type')
+    type_: str = Field(default="FMRadioChannel", alias='@type')
     
-
-FMRadioChannel.update_forward_refs()
