@@ -11,6 +11,5 @@ class Female(GenderType):
     See: https://schema.org/Female
     Model depth: 5
     """
-    type_: str = Field("Female", alias='@type')
+    type_: str = Field(default="Female", alias='@type')
     
-
