@@ -15,7 +15,7 @@ class FinancialService(LocalBusiness):
     See: https://schema.org/FinancialService
     Model depth: 4
     """
-    type_: str = Field("FinancialService", alias='@type')
+    type_: str = Field(default="FinancialService", alias='@type')
     feesAndCommissionsSpecification: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text']], AnyUrl, 'URL', str, 'Text']] = Field(
         default=None,
         description="Description of fees, commissions, and other terms applied either to a class of financial"
@@ -23,7 +23,6 @@ class FinancialService(LocalBusiness):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.Text import Text
