@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Action import Action
 
@@ -6,10 +9,8 @@ class FindAction(Action):
     """The act of finding an object. Related actions: * [[SearchAction]]: FindAction is generally"
      "lead by a SearchAction, but not necessarily.
 
-    See https://schema.org/FindAction.
-
+    See: https://schema.org/FindAction
+    Model depth: 3
     """
-    type_: str = Field("FindAction", const=True, alias='@type')
+    type_: str = Field(default="FindAction", alias='@type')
     
-
-FindAction.update_forward_refs()
