@@ -1,15 +1,16 @@
+from __future__ import annotations
+
+
 from pydantic import Field
-from pydantic_schemaorg.CivicStructure import CivicStructure
 from pydantic_schemaorg.EmergencyService import EmergencyService
+from pydantic_schemaorg.CivicStructure import CivicStructure
 
 
-class FireStation(CivicStructure, EmergencyService):
+class FireStation(EmergencyService, CivicStructure):
     """A fire station. With firemen.
 
-    See https://schema.org/FireStation.
-
+    See: https://schema.org/FireStation
+    Model depth: 4
     """
-    type_: str = Field("FireStation", const=True, alias='@type')
+    type_: str = Field(default="FireStation", alias='@type')
     
-
-FireStation.update_forward_refs()
