@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
 class Flexibility(PhysicalActivityCategory):
     """Physical activity that is engaged in to improve joint and muscle flexibility.
 
-    See https://schema.org/Flexibility.
-
+    See: https://schema.org/Flexibility
+    Model depth: 5
     """
-    type_: str = Field("Flexibility", const=True, alias='@type')
+    type_: str = Field(default="Flexibility", alias='@type')
     
-
-Flexibility.update_forward_refs()
