@@ -15,7 +15,7 @@ class Flight(Trip):
     See: https://schema.org/Flight
     Model depth: 4
     """
-    type_: str = Field("Flight", alias='@type')
+    type_: str = Field(default="Flight", alias='@type')
     boardingPolicy: Optional[Union[List[Union['BoardingPolicyType', str]], 'BoardingPolicyType', str]] = Field(
         default=None,
         description="The type of boarding policy used by the airline (e.g. zone-based or group-based).",
@@ -80,7 +80,6 @@ class Flight(Trip):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.BoardingPolicyType import BoardingPolicyType
     from pydantic_schemaorg.Text import Text
