@@ -16,7 +16,7 @@ class FlightReservation(Reservation):
     See: https://schema.org/FlightReservation
     Model depth: 4
     """
-    type_: str = Field("FlightReservation", alias='@type')
+    type_: str = Field(default="FlightReservation", alias='@type')
     passengerSequenceNumber: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The passenger's sequence number as assigned by the airline.",
@@ -36,7 +36,6 @@ class FlightReservation(Reservation):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.QualitativeValue import QualitativeValue
