@@ -24,14 +24,13 @@ class FollowAction(InteractAction):
     See: https://schema.org/FollowAction
     Model depth: 4
     """
-    type_: str = Field("FollowAction", alias='@type')
+    type_: str = Field(default="FollowAction", alias='@type')
     followee: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="A sub property of object. The person or organization being followed.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
