@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Event import Event
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Event import Event
 class FoodEvent(Event):
     """Event type: Food event.
 
-    See https://schema.org/FoodEvent.
-
+    See: https://schema.org/FoodEvent
+    Model depth: 3
     """
-    type_: str = Field("FoodEvent", const=True, alias='@type')
+    type_: str = Field(default="FoodEvent", alias='@type')
     
-
-FoodEvent.update_forward_refs()
