@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Service import Service
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Service import Service
 class FoodService(Service):
     """A food service, like breakfast, lunch, or dinner.
 
-    See https://schema.org/FoodService.
-
+    See: https://schema.org/FoodService
+    Model depth: 4
     """
-    type_: str = Field("FoodService", const=True, alias='@type')
+    type_: str = Field(default="FoodService", alias='@type')
     
-
-FoodService.update_forward_refs()
