@@ -11,6 +11,5 @@ class FreeReturn(ReturnFeesEnumeration):
     See: https://schema.org/FreeReturn
     Model depth: 5
     """
-    type_: str = Field("FreeReturn", alias='@type')
+    type_: str = Field(default="FreeReturn", alias='@type')
     
-
