@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Project import Project
 
@@ -9,10 +12,8 @@ class FundingAgency(Project):
      "corporate sponsorship etc. Examples of funding agencies include ERC, REA, NIH, Bill"
      "and Melinda Gates Foundation...
 
-    See https://schema.org/FundingAgency.
-
+    See: https://schema.org/FundingAgency
+    Model depth: 4
     """
-    type_: str = Field("FundingAgency", const=True, alias='@type')
+    type_: str = Field(default="FundingAgency", alias='@type')
     
-
-FundingAgency.update_forward_refs()
