@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 
@@ -12,10 +15,8 @@ class FundingScheme(Organization):
      "handled by other, dedicated, organizations - [[FundingAgency]]s such as ERC, REA,"
      "...
 
-    See https://schema.org/FundingScheme.
-
+    See: https://schema.org/FundingScheme
+    Model depth: 3
     """
-    type_: str = Field("FundingScheme", const=True, alias='@type')
+    type_: str = Field(default="FundingScheme", alias='@type')
     
-
-FundingScheme.update_forward_refs()
