@@ -17,8 +17,8 @@ class Game(CreativeWork):
     See: https://schema.org/Game
     Model depth: 3
     """
-    type_: str = Field("Game", alias='@type')
-    gameLocation: Optional[Union[List[Union[AnyUrl, 'URL', 'Place', 'PostalAddress', str]], AnyUrl, 'URL', 'Place', 'PostalAddress', str]] = Field(
+    type_: str = Field(default="Game", alias='@type')
+    gameLocation: Optional[Union[List[Union[AnyUrl, 'URL', 'PostalAddress', 'Place', str]], AnyUrl, 'URL', 'PostalAddress', 'Place', str]] = Field(
         default=None,
         description="Real or fictional location of the game (or part of game).",
     )
@@ -43,10 +43,9 @@ class Game(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
-    from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.PostalAddress import PostalAddress
+    from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
