@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class GamePlayMode(Enumeration):
     """Indicates whether this game is multi-player, co-op or single-player.
 
-    See https://schema.org/GamePlayMode.
-
+    See: https://schema.org/GamePlayMode
+    Model depth: 4
     """
-    type_: str = Field("GamePlayMode", const=True, alias='@type')
+    type_: str = Field(default="GamePlayMode", alias='@type')
     
-
-GamePlayMode.update_forward_refs()
