@@ -14,7 +14,7 @@ class GameServer(Intangible):
     See: https://schema.org/GameServer
     Model depth: 3
     """
-    type_: str = Field("GameServer", alias='@type')
+    type_: str = Field(default="GameServer", alias='@type')
     serverStatus: Optional[Union[List[Union['GameServerStatus', str]], 'GameServerStatus', str]] = Field(
         default=None,
         description="Status of a game server.",
@@ -29,7 +29,6 @@ class GameServer(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.GameServerStatus import GameServerStatus
     from pydantic_schemaorg.Integer import Integer
