@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.StatusEnumeration import StatusEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.StatusEnumeration import StatusEnumeration
 class GameServerStatus(StatusEnumeration):
     """Status of a game server.
 
-    See https://schema.org/GameServerStatus.
-
+    See: https://schema.org/GameServerStatus
+    Model depth: 5
     """
-    type_: str = Field("GameServerStatus", const=True, alias='@type')
+    type_: str = Field(default="GameServerStatus", alias='@type')
     
-
-GameServerStatus.update_forward_refs()
