@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 class GasStation(AutomotiveBusiness):
     """A gas station.
 
-    See https://schema.org/GasStation.
-
+    See: https://schema.org/GasStation
+    Model depth: 5
     """
-    type_: str = Field("GasStation", const=True, alias='@type')
+    type_: str = Field(default="GasStation", alias='@type')
     
-
-GasStation.update_forward_refs()
