@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -6,10 +9,8 @@ class Gastroenterologic(MedicalSpecialty):
     """A specific branch of medical science that pertains to diagnosis and treatment of disorders"
      "of digestive system.
 
-    See https://schema.org/Gastroenterologic.
-
+    See: https://schema.org/Gastroenterologic
+    Model depth: 6
     """
-    type_: str = Field("Gastroenterologic", const=True, alias='@type')
+    type_: str = Field(default="Gastroenterologic", alias='@type')
     
-
-Gastroenterologic.update_forward_refs()
