@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class GenderType(Enumeration):
     """An enumeration of genders.
 
-    See https://schema.org/GenderType.
-
+    See: https://schema.org/GenderType
+    Model depth: 4
     """
-    type_: str = Field("GenderType", const=True, alias='@type')
+    type_: str = Field(default="GenderType", alias='@type')
     
-
-GenderType.update_forward_refs()
