@@ -11,6 +11,5 @@ class GeneralContractor(HomeAndConstructionBusiness):
     See: https://schema.org/GeneralContractor
     Model depth: 5
     """
-    type_: str = Field("GeneralContractor", alias='@type')
+    type_: str = Field(default="GeneralContractor", alias='@type')
     
-
