@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class Genitourinary(PhysicalExam):
     """Genitourinary system function assessment with clinical examination.
 
-    See https://schema.org/Genitourinary.
-
+    See: https://schema.org/Genitourinary
+    Model depth: 5
     """
-    type_: str = Field("Genitourinary", const=True, alias='@type')
+    type_: str = Field(default="Genitourinary", alias='@type')
     
-
-Genitourinary.update_forward_refs()
