@@ -18,7 +18,7 @@ class GeoShape(StructuredValue):
     See: https://schema.org/GeoShape
     Model depth: 4
     """
-    type_: str = Field("GeoShape", alias='@type')
+    type_: str = Field(default="GeoShape", alias='@type')
     polygon: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="A polygon is the area enclosed by a point-to-point path for which the starting and ending"
@@ -62,7 +62,6 @@ class GeoShape(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Number import Number
