@@ -15,7 +15,7 @@ class GeospatialGeometry(Intangible):
     See: https://schema.org/GeospatialGeometry
     Model depth: 3
     """
-    type_: str = Field("GeospatialGeometry", alias='@type')
+    type_: str = Field(default="GeospatialGeometry", alias='@type')
     geoEquals: Optional[Union[List[Union['GeospatialGeometry', 'Place', str]], 'GeospatialGeometry', 'Place', str]] = Field(
         default=None,
         description="Represents spatial relations in which two geometries (or the places they represent)"
@@ -80,6 +80,5 @@ class GeospatialGeometry(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Place import Place
