@@ -13,6 +13,5 @@ class Geriatric(MedicalSpecialty, MedicalBusiness):
     See: https://schema.org/Geriatric
     Model depth: 5
     """
-    type_: str = Field("Geriatric", alias='@type')
+    type_: str = Field(default="Geriatric", alias='@type')
     
-
