@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 class GlutenFreeDiet(RestrictedDiet):
     """A diet exclusive of gluten.
 
-    See https://schema.org/GlutenFreeDiet.
-
+    See: https://schema.org/GlutenFreeDiet
+    Model depth: 5
     """
-    type_: str = Field("GlutenFreeDiet", const=True, alias='@type')
+    type_: str = Field(default="GlutenFreeDiet", alias='@type')
     
-
-GlutenFreeDiet.update_forward_refs()
