@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 class GolfCourse(SportsActivityLocation):
     """A golf course.
 
-    See https://schema.org/GolfCourse.
-
+    See: https://schema.org/GolfCourse
+    Model depth: 5
     """
-    type_: str = Field("GolfCourse", const=True, alias='@type')
+    type_: str = Field(default="GolfCourse", alias='@type')
     
-
-GolfCourse.update_forward_refs()
