@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -6,10 +9,8 @@ class GovernmentBenefitsType(Enumeration):
     """GovernmentBenefitsType enumerates several kinds of government benefits to support"
      "the COVID-19 situation. Note that this structure may not capture all benefits offered.
 
-    See https://schema.org/GovernmentBenefitsType.
-
+    See: https://schema.org/GovernmentBenefitsType
+    Model depth: 4
     """
-    type_: str = Field("GovernmentBenefitsType", const=True, alias='@type')
+    type_: str = Field(default="GovernmentBenefitsType", alias='@type')
     
-
-GovernmentBenefitsType.update_forward_refs()
