@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class GovernmentBuilding(CivicStructure):
     """A government building.
 
-    See https://schema.org/GovernmentBuilding.
-
+    See: https://schema.org/GovernmentBuilding
+    Model depth: 4
     """
-    type_: str = Field("GovernmentBuilding", const=True, alias='@type')
+    type_: str = Field(default="GovernmentBuilding", alias='@type')
     
-
-GovernmentBuilding.update_forward_refs()
