@@ -23,7 +23,7 @@ class Grant(Intangible):
     See: https://schema.org/Grant
     Model depth: 3
     """
-    type_: str = Field("Grant", alias='@type')
+    type_: str = Field(default="Grant", alias='@type')
     fundedItem: Optional[Union[List[Union['Thing', str]], 'Thing', str]] = Field(
         default=None,
         description="Indicates an item funded or sponsored through a [[Grant]].",
@@ -35,7 +35,6 @@ class Grant(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.Person import Person
