@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HomeAndConstructionBusiness import HomeAndConstructionBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HomeAndConstructionBusiness import HomeAndConstructionBu
 class HVACBusiness(HomeAndConstructionBusiness):
     """A business that provide Heating, Ventilation and Air Conditioning services.
 
-    See https://schema.org/HVACBusiness.
-
+    See: https://schema.org/HVACBusiness
+    Model depth: 5
     """
-    type_: str = Field("HVACBusiness", const=True, alias='@type')
+    type_: str = Field(default="HVACBusiness", alias='@type')
     
-
-HVACBusiness.update_forward_refs()
