@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class Head(PhysicalExam):
     """Head assessment with clinical examination.
 
-    See https://schema.org/Head.
-
+    See: https://schema.org/Head
+    Model depth: 5
     """
-    type_: str = Field("Head", const=True, alias='@type')
+    type_: str = Field(default="Head", alias='@type')
     
-
-Head.update_forward_refs()
