@@ -15,7 +15,7 @@ class HealthPlanCostSharingSpecification(Intangible):
     See: https://schema.org/HealthPlanCostSharingSpecification
     Model depth: 3
     """
-    type_: str = Field("HealthPlanCostSharingSpecification", alias='@type')
+    type_: str = Field(default="HealthPlanCostSharingSpecification", alias='@type')
     healthPlanCoinsuranceOption: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Whether the coinsurance applies before or after deductible, etc. TODO: Is this a closed"
@@ -39,7 +39,6 @@ class HealthPlanCostSharingSpecification(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.PriceSpecification import PriceSpecification
