@@ -15,7 +15,7 @@ class HealthPlanNetwork(Intangible):
     See: https://schema.org/HealthPlanNetwork
     Model depth: 3
     """
-    type_: str = Field("HealthPlanNetwork", alias='@type')
+    type_: str = Field(default="HealthPlanNetwork", alias='@type')
     healthPlanNetworkTier: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The tier(s) for this network.",
@@ -31,7 +31,6 @@ class HealthPlanNetwork(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Boolean import Boolean
