@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EducationalOrganization import EducationalOrganization
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.EducationalOrganization import EducationalOrganization
 class HighSchool(EducationalOrganization):
     """A high school.
 
-    See https://schema.org/HighSchool.
-
+    See: https://schema.org/HighSchool
+    Model depth: 4
     """
-    type_: str = Field("HighSchool", const=True, alias='@type')
+    type_: str = Field(default="HighSchool", alias='@type')
     
-
-HighSchool.update_forward_refs()
