@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Store import Store
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Store import Store
 class HobbyShop(Store):
     """A store that sells materials useful or necessary for various hobbies.
 
-    See https://schema.org/HobbyShop.
-
+    See: https://schema.org/HobbyShop
+    Model depth: 5
     """
-    type_: str = Field("HobbyShop", const=True, alias='@type')
+    type_: str = Field(default="HobbyShop", alias='@type')
     
-
-HobbyShop.update_forward_refs()
