@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -7,10 +10,8 @@ class HomeAndConstructionBusiness(LocalBusiness):
      "provides services around homes and buildings. As a [[LocalBusiness]] it can be described"
      "as a [[provider]] of one or more [[Service]]\(s).
 
-    See https://schema.org/HomeAndConstructionBusiness.
-
+    See: https://schema.org/HomeAndConstructionBusiness
+    Model depth: 4
     """
-    type_: str = Field("HomeAndConstructionBusiness", const=True, alias='@type')
+    type_: str = Field(default="HomeAndConstructionBusiness", alias='@type')
     
-
-HomeAndConstructionBusiness.update_forward_refs()
