@@ -12,6 +12,5 @@ class Homeopathic(MedicineSystem):
     See: https://schema.org/Homeopathic
     Model depth: 6
     """
-    type_: str = Field("Homeopathic", alias='@type')
+    type_: str = Field(default="Homeopathic", alias='@type')
     
-
