@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LodgingBusiness import LodgingBusiness
 
@@ -7,10 +10,8 @@ class Hostel(LodgingBusiness):
      "<a href=\"/docs/hotels.html\">dedicated document on the use of schema.org for marking"
      "up hotels and other forms of accommodations</a>.
 
-    See https://schema.org/Hostel.
-
+    See: https://schema.org/Hostel
+    Model depth: 5
     """
-    type_: str = Field("Hostel", const=True, alias='@type')
+    type_: str = Field(default="Hostel", alias='@type')
     
-
-Hostel.update_forward_refs()
