@@ -14,6 +14,5 @@ class Hotel(LodgingBusiness):
     See: https://schema.org/Hotel
     Model depth: 5
     """
-    type_: str = Field("Hotel", alias='@type')
+    type_: str = Field(default="Hotel", alias='@type')
     
-
