@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -6,10 +9,8 @@ class HowOrWhereHealthAspect(HealthAspectEnumeration):
     """Information about how or where to find a topic. Also may contain location data that can"
      "be used for where to look for help if the topic is observed.
 
-    See https://schema.org/HowOrWhereHealthAspect.
-
+    See: https://schema.org/HowOrWhereHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("HowOrWhereHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="HowOrWhereHealthAspect", alias='@type')
     
-
-HowOrWhereHealthAspect.update_forward_refs()
