@@ -14,7 +14,7 @@ class HowTo(CreativeWork):
     See: https://schema.org/HowTo
     Model depth: 3
     """
-    type_: str = Field("HowTo", alias='@type')
+    type_: str = Field(default="HowTo", alias='@type')
     yield_: Optional[Union[List[Union[str, 'Text', 'QuantitativeValue']], str, 'Text', 'QuantitativeValue']] = Field(
         default=None,alias="yield",
         description="The quantity that results by performing instructions. For example, a paper airplane,"
@@ -48,7 +48,7 @@ class HowTo(CreativeWork):
         description="A sub property of instrument. An object used (but not consumed) when performing instructions"
      "or a direction.",
     )
-    steps: Optional[Union[List[Union[str, 'Text', 'ItemList', 'CreativeWork']], str, 'Text', 'ItemList', 'CreativeWork']] = Field(
+    steps: Optional[Union[List[Union[str, 'Text', 'CreativeWork', 'ItemList']], str, 'Text', 'CreativeWork', 'ItemList']] = Field(
         default=None,
         description="A single step item (as HowToStep, text, document, video, etc.) or a HowToSection (originally"
      "misnamed 'steps'; 'step' is preferred).",
@@ -59,7 +59,6 @@ class HowTo(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
