@@ -16,14 +16,13 @@ class HowToItem(ListItem):
     See: https://schema.org/HowToItem
     Model depth: 4
     """
-    type_: str = Field("HowToItem", alias='@type')
+    type_: str = Field(default="HowToItem", alias='@type')
     requiredQuantity: Optional[Union[List[Union[Decimal, 'Number', str, 'Text', 'QuantitativeValue']], Decimal, 'Number', str, 'Text', 'QuantitativeValue']] = Field(
         default=None,
         description="The required quantity of the item(s).",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.Text import Text
