@@ -17,16 +17,15 @@ class HowToSection(ListItem, ItemList, CreativeWork):
     See: https://schema.org/HowToSection
     Model depth: 3
     """
-    type_: str = Field("HowToSection", alias='@type')
-    steps: Optional[Union[List[Union[str, 'Text', 'ItemList', 'CreativeWork']], str, 'Text', 'ItemList', 'CreativeWork']] = Field(
+    type_: str = Field(default="HowToSection", alias='@type')
+    steps: Optional[Union[List[Union[str, 'Text', 'CreativeWork', 'ItemList']], str, 'Text', 'CreativeWork', 'ItemList']] = Field(
         default=None,
         description="A single step item (as HowToStep, text, document, video, etc.) or a HowToSection (originally"
      "misnamed 'steps'; 'step' is preferred).",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
-    from pydantic_schemaorg.ItemList import ItemList
     from pydantic_schemaorg.CreativeWork import CreativeWork
+    from pydantic_schemaorg.ItemList import ItemList
