@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HowToItem import HowToItem
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HowToItem import HowToItem
 class HowToTool(HowToItem):
     """A tool used (but not consumed) when performing instructions for how to achieve a result.
 
-    See https://schema.org/HowToTool.
-
+    See: https://schema.org/HowToTool
+    Model depth: 5
     """
-    type_: str = Field("HowToTool", const=True, alias='@type')
+    type_: str = Field(default="HowToTool", alias='@type')
     
-
-HowToTool.update_forward_refs()
