@@ -18,7 +18,7 @@ class HyperToc(CreativeWork):
     See: https://schema.org/HyperToc
     Model depth: 3
     """
-    type_: str = Field("HyperToc", alias='@type')
+    type_: str = Field(default="HyperToc", alias='@type')
     associatedMedia: Optional[Union[List[Union['MediaObject', str]], 'MediaObject', str]] = Field(
         default=None,
         description="A media object that encodes this CreativeWork. This property is a synonym for encoding.",
@@ -29,7 +29,6 @@ class HyperToc(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MediaObject import MediaObject
     from pydantic_schemaorg.HyperTocEntry import HyperTocEntry
