@@ -11,6 +11,5 @@ class IceCreamShop(FoodEstablishment):
     See: https://schema.org/IceCreamShop
     Model depth: 5
     """
-    type_: str = Field("IceCreamShop", alias='@type')
+    type_: str = Field(default="IceCreamShop", alias='@type')
     
-
