@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AssessAction import AssessAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AssessAction import AssessAction
 class IgnoreAction(AssessAction):
     """The act of intentionally disregarding the object. An agent ignores an object.
 
-    See https://schema.org/IgnoreAction.
-
+    See: https://schema.org/IgnoreAction
+    Model depth: 4
     """
-    type_: str = Field("IgnoreAction", const=True, alias='@type')
+    type_: str = Field(default="IgnoreAction", alias='@type')
     
-
-IgnoreAction.update_forward_refs()
