@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ImageObject import ImageObject
 
@@ -9,10 +12,8 @@ class ImageObjectSnapshot(ImageObject):
      "about the files, e.g. creator or dateCreated that aren't represented in their actual"
      "content, do not affect this notion of identity.
 
-    See https://schema.org/ImageObjectSnapshot.
-
+    See: https://schema.org/ImageObjectSnapshot
+    Model depth: 5
     """
-    type_: str = Field("ImageObjectSnapshot", const=True, alias='@type')
+    type_: str = Field(default="ImageObjectSnapshot", alias='@type')
     
-
-ImageObjectSnapshot.update_forward_refs()
