@@ -14,13 +14,12 @@ class ImagingTest(MedicalTest):
     See: https://schema.org/ImagingTest
     Model depth: 4
     """
-    type_: str = Field("ImagingTest", alias='@type')
+    type_: str = Field(default="ImagingTest", alias='@type')
     imagingTechnique: Optional[Union[List[Union['MedicalImagingTechnique', str]], 'MedicalImagingTechnique', str]] = Field(
         default=None,
         description="Imaging technique used.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique
