@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ItemAvailability import ItemAvailability
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ItemAvailability import ItemAvailability
 class InStock(ItemAvailability):
     """Indicates that the item is in stock.
 
-    See https://schema.org/InStock.
-
+    See: https://schema.org/InStock
+    Model depth: 5
     """
-    type_: str = Field("InStock", const=True, alias='@type')
+    type_: str = Field(default="InStock", alias='@type')
     
-
-InStock.update_forward_refs()
