@@ -17,7 +17,7 @@ class InfectiousDisease(MedicalCondition):
     See: https://schema.org/InfectiousDisease
     Model depth: 4
     """
-    type_: str = Field("InfectiousDisease", alias='@type')
+    type_: str = Field(default="InfectiousDisease", alias='@type')
     transmissionMethod: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="How the disease spreads, either as a route or vector, for example 'direct contact', 'Aedes"
@@ -33,7 +33,6 @@ class InfectiousDisease(MedicalCondition):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.InfectiousAgentClass import InfectiousAgentClass
