@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class IngredientsHealthAspect(HealthAspectEnumeration):
     """Content discussing ingredients-related aspects of a health topic.
 
-    See https://schema.org/IngredientsHealthAspect.
-
+    See: https://schema.org/IngredientsHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("IngredientsHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="IngredientsHealthAspect", alias='@type')
     
-
-IngredientsHealthAspect.update_forward_refs()
