@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PriceComponentTypeEnumeration import PriceComponentTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PriceComponentTypeEnumeration import PriceComponentTypeE
 class Installment(PriceComponentTypeEnumeration):
     """Represents the installment pricing component of the total price for an offered product.
 
-    See https://schema.org/Installment.
-
+    See: https://schema.org/Installment
+    Model depth: 5
     """
-    type_: str = Field("Installment", const=True, alias='@type')
+    type_: str = Field(default="Installment", alias='@type')
     
-
-Installment.update_forward_refs()
