@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FinancialService import FinancialService
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FinancialService import FinancialService
 class InsuranceAgency(FinancialService):
     """An Insurance agency.
 
-    See https://schema.org/InsuranceAgency.
-
+    See: https://schema.org/InsuranceAgency
+    Model depth: 5
     """
-    type_: str = Field("InsuranceAgency", const=True, alias='@type')
+    type_: str = Field(default="InsuranceAgency", alias='@type')
     
-
-InsuranceAgency.update_forward_refs()
