@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Action import Action
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Action import Action
 class InteractAction(Action):
     """The act of interacting with another person or organization.
 
-    See https://schema.org/InteractAction.
-
+    See: https://schema.org/InteractAction
+    Model depth: 3
     """
-    type_: str = Field("InteractAction", const=True, alias='@type')
+    type_: str = Field(default="InteractAction", alias='@type')
     
-
-InteractAction.update_forward_refs()
