@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 class InternationalTrial(MedicalTrialDesign):
     """An international trial.
 
-    See https://schema.org/InternationalTrial.
-
+    See: https://schema.org/InternationalTrial
+    Model depth: 6
     """
-    type_: str = Field("InternationalTrial", const=True, alias='@type')
+    type_: str = Field(default="InternationalTrial", alias='@type')
     
-
-InternationalTrial.update_forward_refs()
