@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class InternetCafe(LocalBusiness):
     """An internet cafe.
 
-    See https://schema.org/InternetCafe.
-
+    See: https://schema.org/InternetCafe
+    Model depth: 4
     """
-    type_: str = Field("InternetCafe", const=True, alias='@type')
+    type_: str = Field(default="InternetCafe", alias='@type')
     
-
-InternetCafe.update_forward_refs()
