@@ -14,13 +14,12 @@ class InviteAction(CommunicateAction):
     See: https://schema.org/InviteAction
     Model depth: 5
     """
-    type_: str = Field("InviteAction", alias='@type')
+    type_: str = Field(default="InviteAction", alias='@type')
     event: Optional[Union[List[Union['Event', str]], 'Event', str]] = Field(
         default=None,
         description="Upcoming or past event associated with this place, organization, or action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Event import Event
