@@ -16,7 +16,7 @@ class Invoice(Intangible):
     See: https://schema.org/Invoice
     Model depth: 3
     """
-    type_: str = Field("Invoice", alias='@type')
+    type_: str = Field(default="Invoice", alias='@type')
     paymentDue: Optional[Union[List[Union[ISO8601Date, 'DateTime', str]], ISO8601Date, 'DateTime', str]] = Field(
         default=None,
         description="The date that payment is due.",
@@ -33,7 +33,7 @@ class Invoice(Intangible):
         default=None,
         description="The time interval used to compute the invoice.",
     )
-    category: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text', 'Thing', 'PhysicalActivityCategory']], AnyUrl, 'URL', str, 'Text', 'Thing', 'PhysicalActivityCategory']] = Field(
+    category: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text', 'PhysicalActivityCategory', 'Thing']], AnyUrl, 'URL', str, 'Text', 'PhysicalActivityCategory', 'Thing']] = Field(
         default=None,
         description="A category for the item. Greater signs or slashes can be used to informally indicate a"
      "category hierarchy.",
@@ -46,7 +46,7 @@ class Invoice(Intangible):
         default=None,
         description="Party placing the order or paying the invoice.",
     )
-    totalPaymentDue: Optional[Union[List[Union['PriceSpecification', 'MonetaryAmount', str]], 'PriceSpecification', 'MonetaryAmount', str]] = Field(
+    totalPaymentDue: Optional[Union[List[Union['MonetaryAmount', 'PriceSpecification', str]], 'MonetaryAmount', 'PriceSpecification', str]] = Field(
         default=None,
         description="The total amount due.",
     )
@@ -67,7 +67,7 @@ class Invoice(Intangible):
         default=None,
         description="A number that confirms the given order or payment has been received.",
     )
-    minimumPaymentDue: Optional[Union[List[Union['PriceSpecification', 'MonetaryAmount', str]], 'PriceSpecification', 'MonetaryAmount', str]] = Field(
+    minimumPaymentDue: Optional[Union[List[Union['MonetaryAmount', 'PriceSpecification', str]], 'MonetaryAmount', 'PriceSpecification', str]] = Field(
         default=None,
         description="The minimum payment required at this time.",
     )
@@ -90,19 +90,18 @@ class Invoice(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.DateTime import DateTime
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Duration import Duration
     from pydantic_schemaorg.URL import URL
-    from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
+    from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.PaymentStatusType import PaymentStatusType
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
-    from pydantic_schemaorg.PriceSpecification import PriceSpecification
     from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
+    from pydantic_schemaorg.PriceSpecification import PriceSpecification
     from pydantic_schemaorg.Date import Date
     from pydantic_schemaorg.Order import Order
     from pydantic_schemaorg.PaymentMethod import PaymentMethod
