@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PriceTypeEnumeration import PriceTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PriceTypeEnumeration import PriceTypeEnumeration
 class InvoicePrice(PriceTypeEnumeration):
     """Represents the invoice price of an offered product.
 
-    See https://schema.org/InvoicePrice.
-
+    See: https://schema.org/InvoicePrice
+    Model depth: 5
     """
-    type_: str = Field("InvoicePrice", const=True, alias='@type')
+    type_: str = Field(default="InvoicePrice", alias='@type')
     
-
-InvoicePrice.update_forward_refs()
