@@ -15,7 +15,7 @@ class ItemList(Intangible):
     See: https://schema.org/ItemList
     Model depth: 3
     """
-    type_: str = Field("ItemList", alias='@type')
+    type_: str = Field(default="ItemList", alias='@type')
     itemListElement: Optional[Union[List[Union[str, 'Text', 'Thing', 'ListItem']], str, 'Text', 'Thing', 'ListItem']] = Field(
         default=None,
         description="For itemListElement values, you can use simple strings (e.g. \"Peter\", \"Paul\","
@@ -39,7 +39,6 @@ class ItemList(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Thing import Thing
