@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ItemListOrderType import ItemListOrderType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ItemListOrderType import ItemListOrderType
 class ItemListOrderAscending(ItemListOrderType):
     """An ItemList ordered with lower values listed first.
 
-    See https://schema.org/ItemListOrderAscending.
-
+    See: https://schema.org/ItemListOrderAscending
+    Model depth: 5
     """
-    type_: str = Field("ItemListOrderAscending", const=True, alias='@type')
+    type_: str = Field(default="ItemListOrderAscending", alias='@type')
     
-
-ItemListOrderAscending.update_forward_refs()
