@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ItemListOrderType import ItemListOrderType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ItemListOrderType import ItemListOrderType
 class ItemListUnordered(ItemListOrderType):
     """An ItemList ordered with no explicit order.
 
-    See https://schema.org/ItemListUnordered.
-
+    See: https://schema.org/ItemListUnordered
+    Model depth: 5
     """
-    type_: str = Field("ItemListUnordered", const=True, alias='@type')
+    type_: str = Field(default="ItemListUnordered", alias='@type')
     
-
-ItemListUnordered.update_forward_refs()
