@@ -18,13 +18,12 @@ class JoinAction(InteractAction):
     See: https://schema.org/JoinAction
     Model depth: 4
     """
-    type_: str = Field("JoinAction", alias='@type')
+    type_: str = Field(default="JoinAction", alias='@type')
     event: Optional[Union[List[Union['Event', str]], 'Event', str]] = Field(
         default=None,
         description="Upcoming or past event associated with this place, organization, or action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Event import Event
