@@ -14,7 +14,7 @@ class Joint(AnatomicalStructure):
     See: https://schema.org/Joint
     Model depth: 4
     """
-    type_: str = Field("Joint", alias='@type')
+    type_: str = Field(default="Joint", alias='@type')
     functionalClass: Optional[Union[List[Union[str, 'Text', 'MedicalEntity']], str, 'Text', 'MedicalEntity']] = Field(
         default=None,
         description="The degree of mobility the joint allows.",
@@ -29,7 +29,6 @@ class Joint(AnatomicalStructure):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.MedicalEntity import MedicalEntity
