@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 class KosherDiet(RestrictedDiet):
     """A diet conforming to Jewish dietary practices.
 
-    See https://schema.org/KosherDiet.
-
+    See: https://schema.org/KosherDiet
+    Model depth: 5
     """
-    type_: str = Field("KosherDiet", const=True, alias='@type')
+    type_: str = Field(default="KosherDiet", alias='@type')
     
-
-KosherDiet.update_forward_refs()
