@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -6,10 +9,8 @@ class LaboratoryScience(MedicalSpecialty):
     """A medical science pertaining to chemical, hematological, immunologic, microscopic,"
      "or bacteriological diagnostic analyses or research.
 
-    See https://schema.org/LaboratoryScience.
-
+    See: https://schema.org/LaboratoryScience
+    Model depth: 6
     """
-    type_: str = Field("LaboratoryScience", const=True, alias='@type')
+    type_: str = Field(default="LaboratoryScience", alias='@type')
     
-
-LaboratoryScience.update_forward_refs()
