@@ -14,6 +14,5 @@ class Landform(Place):
     See: https://schema.org/Landform
     Model depth: 3
     """
-    type_: str = Field("Landform", alias='@type')
+    type_: str = Field(default="Landform", alias='@type')
     
-
