@@ -15,6 +15,5 @@ class Language(Intangible):
     See: https://schema.org/Language
     Model depth: 3
     """
-    type_: str = Field("Language", alias='@type')
+    type_: str = Field(default="Language", alias='@type')
     
-
