@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicReleaseFormatType import MusicReleaseFormatType
 class LaserDiscFormat(MusicReleaseFormatType):
     """LaserDiscFormat.
 
-    See https://schema.org/LaserDiscFormat.
-
+    See: https://schema.org/LaserDiscFormat
+    Model depth: 5
     """
-    type_: str = Field("LaserDiscFormat", const=True, alias='@type')
+    type_: str = Field(default="LaserDiscFormat", alias='@type')
     
-
-LaserDiscFormat.update_forward_refs()
