@@ -16,13 +16,12 @@ class LeaveAction(InteractAction):
     See: https://schema.org/LeaveAction
     Model depth: 4
     """
-    type_: str = Field("LeaveAction", alias='@type')
+    type_: str = Field(default="LeaveAction", alias='@type')
     event: Optional[Union[List[Union['Event', str]], 'Event', str]] = Field(
         default=None,
         description="Upcoming or past event associated with this place, organization, or action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Event import Event
