@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.SteeringPositionValue import SteeringPositionValue
 
@@ -6,10 +9,8 @@ class LeftHandDriving(SteeringPositionValue):
     """The steering position is on the left side of the vehicle (viewed from the main direction"
      "of driving).
 
-    See https://schema.org/LeftHandDriving.
-
+    See: https://schema.org/LeftHandDriving
+    Model depth: 6
     """
-    type_: str = Field("LeftHandDriving", const=True, alias='@type')
+    type_: str = Field(default="LeftHandDriving", alias='@type')
     
-
-LeftHandDriving.update_forward_refs()
