@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -7,10 +10,8 @@ class LegalService(LocalBusiness):
      "e.g. law firms. As a [[LocalBusiness]] it can be described as a [[provider]] of one or"
      "more [[Service]]\(s).
 
-    See https://schema.org/LegalService.
-
+    See: https://schema.org/LegalService
+    Model depth: 4
     """
-    type_: str = Field("LegalService", const=True, alias='@type')
+    type_: str = Field(default="LegalService", alias='@type')
     
-
-LegalService.update_forward_refs()
