@@ -17,7 +17,7 @@ class Legislation(CreativeWork):
     See: https://schema.org/Legislation
     Model depth: 3
     """
-    type_: str = Field("Legislation", alias='@type')
+    type_: str = Field(default="Legislation", alias='@type')
     legislationPassedBy: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="The person or organization that originally passed or made the law : typically parliament"
@@ -102,7 +102,6 @@ class Legislation(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
