@@ -17,7 +17,7 @@ class LegislationObject(MediaObject, Legislation):
     See: https://schema.org/LegislationObject
     Model depth: 4
     """
-    type_: str = Field("LegislationObject", alias='@type')
+    type_: str = Field(default="LegislationObject", alias='@type')
     legislationLegalValue: Optional[Union[List[Union['LegalValueLevel', str]], 'LegalValueLevel', str]] = Field(
         default=None,
         description="The legal value of this legislation file. The same legislation can be written in multiple"
@@ -26,6 +26,5 @@ class LegislationObject(MediaObject, Legislation):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.LegalValueLevel import LegalValueLevel
