@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GovernmentBuilding import GovernmentBuilding
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GovernmentBuilding import GovernmentBuilding
 class LegislativeBuilding(GovernmentBuilding):
     """A legislative building&#x2014;for example, the state capitol.
 
-    See https://schema.org/LegislativeBuilding.
-
+    See: https://schema.org/LegislativeBuilding
+    Model depth: 5
     """
-    type_: str = Field("LegislativeBuilding", const=True, alias='@type')
+    type_: str = Field(default="LegislativeBuilding", alias='@type')
     
-
-LegislativeBuilding.update_forward_refs()
