@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
 
@@ -6,10 +9,8 @@ class LeisureTimeActivity(PhysicalActivityCategory):
     """Any physical activity engaged in for recreational purposes. Examples may include ballroom"
      "dancing, roller skating, canoeing, fishing, etc.
 
-    See https://schema.org/LeisureTimeActivity.
-
+    See: https://schema.org/LeisureTimeActivity
+    Model depth: 5
     """
-    type_: str = Field("LeisureTimeActivity", const=True, alias='@type')
+    type_: str = Field(default="LeisureTimeActivity", alias='@type')
     
-
-LeisureTimeActivity.update_forward_refs()
