@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Organization import Organization
 class LibrarySystem(Organization):
     """A [[LibrarySystem]] is a collaborative system amongst several libraries.
 
-    See https://schema.org/LibrarySystem.
-
+    See: https://schema.org/LibrarySystem
+    Model depth: 3
     """
-    type_: str = Field("LibrarySystem", const=True, alias='@type')
+    type_: str = Field(default="LibrarySystem", alias='@type')
     
-
-LibrarySystem.update_forward_refs()
