@@ -12,6 +12,5 @@ class LimitedByGuaranteeCharity(UKNonprofitType):
     See: https://schema.org/LimitedByGuaranteeCharity
     Model depth: 6
     """
-    type_: str = Field("LimitedByGuaranteeCharity", alias='@type')
+    type_: str = Field(default="LimitedByGuaranteeCharity", alias='@type')
     
-
