@@ -14,7 +14,7 @@ class ListItem(Intangible):
     See: https://schema.org/ListItem
     Model depth: 3
     """
-    type_: str = Field("ListItem", alias='@type')
+    type_: str = Field(default="ListItem", alias='@type')
     position: Optional[Union[List[Union[int, 'Integer', str, 'Text']], int, 'Integer', str, 'Text']] = Field(
         default=None,
         description="The position of an item in a series or sequence of items.",
@@ -33,7 +33,6 @@ class ListItem(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Integer import Integer
     from pydantic_schemaorg.Text import Text
