@@ -12,6 +12,5 @@ class ListPrice(PriceTypeEnumeration):
     See: https://schema.org/ListPrice
     Model depth: 5
     """
-    type_: str = Field("ListPrice", alias='@type')
+    type_: str = Field(default="ListPrice", alias='@type')
     
-
