@@ -17,7 +17,7 @@ class LoanOrCredit(FinancialProduct):
     See: https://schema.org/LoanOrCredit
     Model depth: 5
     """
-    type_: str = Field("LoanOrCredit", alias='@type')
+    type_: str = Field(default="LoanOrCredit", alias='@type')
     loanRepaymentForm: Optional[Union[List[Union['RepaymentSpecification', str]], 'RepaymentSpecification', str]] = Field(
         default=None,
         description="A form of paying back money previously borrowed from a lender. Repayment usually takes"
@@ -65,7 +65,6 @@ class LoanOrCredit(FinancialProduct):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.RepaymentSpecification import RepaymentSpecification
     from pydantic_schemaorg.Text import Text
