@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HomeAndConstructionBusiness import HomeAndConstructionBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HomeAndConstructionBusiness import HomeAndConstructionBu
 class Locksmith(HomeAndConstructionBusiness):
     """A locksmith.
 
-    See https://schema.org/Locksmith.
-
+    See: https://schema.org/Locksmith
+    Model depth: 5
     """
-    type_: str = Field("Locksmith", const=True, alias='@type')
+    type_: str = Field(default="Locksmith", alias='@type')
     
-
-Locksmith.update_forward_refs()
