@@ -18,7 +18,7 @@ class LodgingBusiness(LocalBusiness):
     See: https://schema.org/LodgingBusiness
     Model depth: 4
     """
-    type_: str = Field("LodgingBusiness", alias='@type')
+    type_: str = Field(default="LodgingBusiness", alias='@type')
     amenityFeature: Optional[Union[List[Union['LocationFeatureSpecification', str]], 'LocationFeatureSpecification', str]] = Field(
         default=None,
         description="An amenity feature (e.g. a characteristic or service) of the Accommodation. This generic"
@@ -62,7 +62,6 @@ class LodgingBusiness(LocalBusiness):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.LocationFeatureSpecification import LocationFeatureSpecification
     from pydantic_schemaorg.Number import Number
