@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalObservationalStudyDesign import MedicalObservationalStudyDesign
 
@@ -8,10 +11,8 @@ class Longitudinal(MedicalObservationalStudyDesign):
      "differences across generations. Longitudinal studies are also used in medicine to"
      "uncover predictors of certain diseases.
 
-    See https://schema.org/Longitudinal.
-
+    See: https://schema.org/Longitudinal
+    Model depth: 6
     """
-    type_: str = Field("Longitudinal", const=True, alias='@type')
+    type_: str = Field(default="Longitudinal", alias='@type')
     
-
-Longitudinal.update_forward_refs()
