@@ -14,13 +14,12 @@ class LoseAction(AchieveAction):
     See: https://schema.org/LoseAction
     Model depth: 4
     """
-    type_: str = Field("LoseAction", alias='@type')
+    type_: str = Field(default="LoseAction", alias='@type')
     winner: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="A sub property of participant. The winner of the action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
