@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 class LowCalorieDiet(RestrictedDiet):
     """A diet focused on reduced calorie intake.
 
-    See https://schema.org/LowCalorieDiet.
-
+    See: https://schema.org/LowCalorieDiet
+    Model depth: 5
     """
-    type_: str = Field("LowCalorieDiet", const=True, alias='@type')
+    type_: str = Field(default="LowCalorieDiet", alias='@type')
     
-
-LowCalorieDiet.update_forward_refs()
