@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 class LowFatDiet(RestrictedDiet):
     """A diet focused on reduced fat and cholesterol intake.
 
-    See https://schema.org/LowFatDiet.
-
+    See: https://schema.org/LowFatDiet
+    Model depth: 5
     """
-    type_: str = Field("LowFatDiet", const=True, alias='@type')
+    type_: str = Field(default="LowFatDiet", alias='@type')
     
-
-LowFatDiet.update_forward_refs()
