@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 class LowLactoseDiet(RestrictedDiet):
     """A diet appropriate for people with lactose intolerance.
 
-    See https://schema.org/LowLactoseDiet.
-
+    See: https://schema.org/LowLactoseDiet
+    Model depth: 5
     """
-    type_: str = Field("LowLactoseDiet", const=True, alias='@type')
+    type_: str = Field(default="LowLactoseDiet", alias='@type')
     
-
-LowLactoseDiet.update_forward_refs()
