@@ -11,6 +11,5 @@ class LowSaltDiet(RestrictedDiet):
     See: https://schema.org/LowSaltDiet
     Model depth: 5
     """
-    type_: str = Field("LowSaltDiet", alias='@type')
+    type_: str = Field(default="LowSaltDiet", alias='@type')
     
-
