@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class Lung(PhysicalExam):
     """Lung and respiratory system clinical examination.
 
-    See https://schema.org/Lung.
-
+    See: https://schema.org/Lung
+    Model depth: 5
     """
-    type_: str = Field("Lung", const=True, alias='@type')
+    type_: str = Field(default="Lung", alias='@type')
     
-
-Lung.update_forward_refs()
