@@ -15,7 +15,7 @@ class LymphaticVessel(Vessel):
     See: https://schema.org/LymphaticVessel
     Model depth: 5
     """
-    type_: str = Field("LymphaticVessel", alias='@type')
+    type_: str = Field(default="LymphaticVessel", alias='@type')
     originatesFrom: Optional[Union[List[Union['Vessel', str]], 'Vessel', str]] = Field(
         default=None,
         description="The vasculature the lymphatic structure originates, or afferents, from.",
@@ -24,15 +24,14 @@ class LymphaticVessel(Vessel):
         default=None,
         description="The vasculature the lymphatic structure runs, or efferents, to.",
     )
-    regionDrained: Optional[Union[List[Union['AnatomicalSystem', 'AnatomicalStructure', str]], 'AnatomicalSystem', 'AnatomicalStructure', str]] = Field(
+    regionDrained: Optional[Union[List[Union['AnatomicalStructure', 'AnatomicalSystem', str]], 'AnatomicalStructure', 'AnatomicalSystem', str]] = Field(
         default=None,
         description="The anatomical or organ system drained by this vessel; generally refers to a specific"
      "part of an organ.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Vessel import Vessel
-    from pydantic_schemaorg.AnatomicalSystem import AnatomicalSystem
     from pydantic_schemaorg.AnatomicalStructure import AnatomicalStructure
+    from pydantic_schemaorg.AnatomicalSystem import AnatomicalSystem
