@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique
 class MRI(MedicalImagingTechnique):
     """Magnetic resonance imaging.
 
-    See https://schema.org/MRI.
-
+    See: https://schema.org/MRI
+    Model depth: 6
     """
-    type_: str = Field("MRI", const=True, alias='@type')
+    type_: str = Field(default="MRI", alias='@type')
     
-
-MRI.update_forward_refs()
