@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GenderType import GenderType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GenderType import GenderType
 class Male(GenderType):
     """The male gender.
 
-    See https://schema.org/Male.
-
+    See: https://schema.org/Male
+    Model depth: 5
     """
-    type_: str = Field("Male", const=True, alias='@type')
+    type_: str = Field(default="Male", alias='@type')
     
-
-Male.update_forward_refs()
