@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CreativeWork import CreativeWork
 class Manuscript(CreativeWork):
     """A book, document, or piece of music written by hand rather than typed or printed.
 
-    See https://schema.org/Manuscript.
-
+    See: https://schema.org/Manuscript
+    Model depth: 3
     """
-    type_: str = Field("Manuscript", const=True, alias='@type')
+    type_: str = Field(default="Manuscript", alias='@type')
     
-
-Manuscript.update_forward_refs()
