@@ -14,13 +14,12 @@ class Map(CreativeWork):
     See: https://schema.org/Map
     Model depth: 3
     """
-    type_: str = Field("Map", alias='@type')
+    type_: str = Field(default="Map", alias='@type')
     mapType: Optional[Union[List[Union['MapCategoryType', str]], 'MapCategoryType', str]] = Field(
         default=None,
         description="Indicates the kind of Map, from the MapCategoryType Enumeration.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MapCategoryType import MapCategoryType
