@@ -11,6 +11,5 @@ class MapCategoryType(Enumeration):
     See: https://schema.org/MapCategoryType
     Model depth: 4
     """
-    type_: str = Field("MapCategoryType", alias='@type')
+    type_: str = Field(default="MapCategoryType", alias='@type')
     
-
