@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.InteractAction import InteractAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.InteractAction import InteractAction
 class MarryAction(InteractAction):
     """The act of marrying a person.
 
-    See https://schema.org/MarryAction.
-
+    See: https://schema.org/MarryAction
+    Model depth: 4
     """
-    type_: str = Field("MarryAction", const=True, alias='@type')
+    type_: str = Field(default="MarryAction", alias='@type')
     
-
-MarryAction.update_forward_refs()
