@@ -13,6 +13,5 @@ class MaximumDoseSchedule(DoseSchedule):
     See: https://schema.org/MaximumDoseSchedule
     Model depth: 5
     """
-    type_: str = Field("MaximumDoseSchedule", alias='@type')
+    type_: str = Field(default="MaximumDoseSchedule", alias='@type')
     
-
