@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class MayTreatHealthAspect(HealthAspectEnumeration):
     """Related topics may be treated by a Topic.
 
-    See https://schema.org/MayTreatHealthAspect.
-
+    See: https://schema.org/MayTreatHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("MayTreatHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="MayTreatHealthAspect", alias='@type')
     
-
-MayTreatHealthAspect.update_forward_refs()
