@@ -16,6 +16,5 @@ class MediaManipulationRatingEnumeration(Enumeration):
     See: https://schema.org/MediaManipulationRatingEnumeration
     Model depth: 4
     """
-    type_: str = Field("MediaManipulationRatingEnumeration", alias='@type')
+    type_: str = Field(default="MediaManipulationRatingEnumeration", alias='@type')
     
-
