@@ -20,7 +20,7 @@ class MediaObject(CreativeWork):
     See: https://schema.org/MediaObject
     Model depth: 3
     """
-    type_: str = Field("MediaObject", alias='@type')
+    type_: str = Field(default="MediaObject", alias='@type')
     bitrate: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The bitrate of the media object.",
@@ -129,7 +129,6 @@ class MediaObject(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.URL import URL
