@@ -14,7 +14,7 @@ class MediaSubscription(Intangible):
     See: https://schema.org/MediaSubscription
     Model depth: 3
     """
-    type_: str = Field("MediaSubscription", alias='@type')
+    type_: str = Field(default="MediaSubscription", alias='@type')
     expectsAcceptanceOf: Optional[Union[List[Union['Offer', str]], 'Offer', str]] = Field(
         default=None,
         description="An Offer which must be accepted before the user can perform the Action. For example, the"
@@ -28,7 +28,6 @@ class MediaSubscription(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Offer import Offer
     from pydantic_schemaorg.Organization import Organization
