@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
 class MedicalAudienceType(MedicalEnumeration):
     """Target audiences types for medical web pages. Enumerated type.
 
-    See https://schema.org/MedicalAudienceType.
-
+    See: https://schema.org/MedicalAudienceType
+    Model depth: 5
     """
-    type_: str = Field("MedicalAudienceType", const=True, alias='@type')
+    type_: str = Field(default="MedicalAudienceType", alias='@type')
     
-
-MedicalAudienceType.update_forward_refs()
