@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -6,10 +9,8 @@ class MedicalBusiness(LocalBusiness):
     """A particular physical or virtual business of an organization for medical purposes."
      "Examples of MedicalBusiness include differents business run by health professionals.
 
-    See https://schema.org/MedicalBusiness.
-
+    See: https://schema.org/MedicalBusiness
+    Model depth: 4
     """
-    type_: str = Field("MedicalBusiness", const=True, alias='@type')
+    type_: str = Field(default="MedicalBusiness", alias='@type')
     
-
-MedicalBusiness.update_forward_refs()
