@@ -15,7 +15,7 @@ class MedicalCode(CategoryCode, MedicalIntangible):
     See: https://schema.org/MedicalCode
     Model depth: 4
     """
-    type_: str = Field("MedicalCode", alias='@type')
+    type_: str = Field(default="MedicalCode", alias='@type')
     codeValue: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="A short textual code that uniquely identifies the value.",
@@ -26,6 +26,5 @@ class MedicalCode(CategoryCode, MedicalIntangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
