@@ -15,7 +15,7 @@ class MedicalConditionStage(MedicalIntangible):
     See: https://schema.org/MedicalConditionStage
     Model depth: 4
     """
-    type_: str = Field("MedicalConditionStage", alias='@type')
+    type_: str = Field(default="MedicalConditionStage", alias='@type')
     stageAsNumber: Optional[Union[List[Union[Decimal, 'Number', str]], Decimal, 'Number', str]] = Field(
         default=None,
         description="The stage represented as a number, e.g. 3.",
@@ -26,7 +26,6 @@ class MedicalConditionStage(MedicalIntangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.Text import Text
