@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalEntity import MedicalEntity
 
@@ -8,10 +11,8 @@ class MedicalContraindication(MedicalEntity):
      "or relative (the patient is at higher risk of complications, but that these risks may"
      "be outweighed by other considerations or mitigated by other measures).
 
-    See https://schema.org/MedicalContraindication.
-
+    See: https://schema.org/MedicalContraindication
+    Model depth: 3
     """
-    type_: str = Field("MedicalContraindication", const=True, alias='@type')
+    type_: str = Field(default="MedicalContraindication", alias='@type')
     
-
-MedicalContraindication.update_forward_refs()
