@@ -14,7 +14,7 @@ class MedicalDevice(MedicalEntity):
     See: https://schema.org/MedicalDevice
     Model depth: 3
     """
-    type_: str = Field("MedicalDevice", alias='@type')
+    type_: str = Field(default="MedicalDevice", alias='@type')
     postOp: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="A description of the postoperative procedures, care, and/or followups for this device.",
@@ -50,7 +50,6 @@ class MedicalDevice(MedicalEntity):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.MedicalEntity import MedicalEntity
