@@ -14,7 +14,7 @@ class MedicalEntity(Thing):
     See: https://schema.org/MedicalEntity
     Model depth: 2
     """
-    type_: str = Field("MedicalEntity", alias='@type')
+    type_: str = Field(default="MedicalEntity", alias='@type')
     medicineSystem: Optional[Union[List[Union['MedicineSystem', str]], 'MedicineSystem', str]] = Field(
         default=None,
         description="The system of medicine that includes this MedicalEntity, for example 'evidence-based',"
@@ -49,7 +49,6 @@ class MedicalEntity(Thing):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicineSystem import MedicineSystem
     from pydantic_schemaorg.MedicalGuideline import MedicalGuideline
