@@ -20,13 +20,12 @@ class MedicalObservationalStudy(MedicalStudy):
     See: https://schema.org/MedicalObservationalStudy
     Model depth: 4
     """
-    type_: str = Field("MedicalObservationalStudy", alias='@type')
+    type_: str = Field(default="MedicalObservationalStudy", alias='@type')
     studyDesign: Optional[Union[List[Union['MedicalObservationalStudyDesign', str]], 'MedicalObservationalStudyDesign', str]] = Field(
         default=None,
         description="Specifics about the observational study design (enumerated).",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalObservationalStudyDesign import MedicalObservationalStudyDesign
