@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
 class MedicalObservationalStudyDesign(MedicalEnumeration):
     """Design models for observational medical studies. Enumerated type.
 
-    See https://schema.org/MedicalObservationalStudyDesign.
-
+    See: https://schema.org/MedicalObservationalStudyDesign
+    Model depth: 5
     """
-    type_: str = Field("MedicalObservationalStudyDesign", const=True, alias='@type')
+    type_: str = Field(default="MedicalObservationalStudyDesign", alias='@type')
     
-
-MedicalObservationalStudyDesign.update_forward_refs()
