@@ -15,7 +15,7 @@ class MedicalOrganization(Organization):
     See: https://schema.org/MedicalOrganization
     Model depth: 3
     """
-    type_: str = Field("MedicalOrganization", alias='@type')
+    type_: str = Field(default="MedicalOrganization", alias='@type')
     medicalSpecialty: Optional[Union[List[Union['MedicalSpecialty', str]], 'MedicalSpecialty', str]] = Field(
         default=None,
         description="A medical specialty of the provider.",
@@ -31,7 +31,6 @@ class MedicalOrganization(Organization):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
     from pydantic_schemaorg.Boolean import Boolean
