@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalAudienceType import MedicalAudienceType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalAudienceType import MedicalAudienceType
 class MedicalResearcher(MedicalAudienceType):
     """Medical researchers.
 
-    See https://schema.org/MedicalResearcher.
-
+    See: https://schema.org/MedicalResearcher
+    Model depth: 6
     """
-    type_: str = Field("MedicalResearcher", const=True, alias='@type')
+    type_: str = Field(default="MedicalResearcher", alias='@type')
     
-
-MedicalResearcher.update_forward_refs()
