@@ -15,13 +15,12 @@ class MedicalRiskFactor(MedicalEntity):
     See: https://schema.org/MedicalRiskFactor
     Model depth: 3
     """
-    type_: str = Field("MedicalRiskFactor", alias='@type')
+    type_: str = Field(default="MedicalRiskFactor", alias='@type')
     increasesRiskOf: Optional[Union[List[Union['MedicalEntity', str]], 'MedicalEntity', str]] = Field(
         default=None,
         description="The condition, complication, etc. influenced by this factor.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalEntity import MedicalEntity
