@@ -14,7 +14,7 @@ class MedicalScholarlyArticle(ScholarlyArticle):
     See: https://schema.org/MedicalScholarlyArticle
     Model depth: 5
     """
-    type_: str = Field("MedicalScholarlyArticle", alias='@type')
+    type_: str = Field(default="MedicalScholarlyArticle", alias='@type')
     publicationType: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The type of the medical article, taken from the US NLM MeSH publication type catalog."
@@ -22,6 +22,5 @@ class MedicalScholarlyArticle(ScholarlyArticle):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
