@@ -21,7 +21,7 @@ class MedicalStudy(MedicalEntity):
     See: https://schema.org/MedicalStudy
     Model depth: 3
     """
-    type_: str = Field("MedicalStudy", alias='@type')
+    type_: str = Field(default="MedicalStudy", alias='@type')
     studyLocation: Optional[Union[List[Union['AdministrativeArea', str]], 'AdministrativeArea', str]] = Field(
         default=None,
         description="The location in which the study is taking/took place.",
@@ -31,7 +31,7 @@ class MedicalStudy(MedicalEntity):
         description="A subject of the study, i.e. one of the medical conditions, therapies, devices, drugs,"
      "etc. investigated by the study.",
     )
-    status: Optional[Union[List[Union[str, 'Text', 'MedicalStudyStatus', 'EventStatusType']], str, 'Text', 'MedicalStudyStatus', 'EventStatusType']] = Field(
+    status: Optional[Union[List[Union[str, 'Text', 'EventStatusType', 'MedicalStudyStatus']], str, 'Text', 'EventStatusType', 'MedicalStudyStatus']] = Field(
         default=None,
         description="The status of the study (enumerated).",
     )
@@ -46,13 +46,12 @@ class MedicalStudy(MedicalEntity):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
     from pydantic_schemaorg.MedicalEntity import MedicalEntity
     from pydantic_schemaorg.Text import Text
-    from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
     from pydantic_schemaorg.EventStatusType import EventStatusType
+    from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.MedicalCondition import MedicalCondition
