@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSignOrSymptom import MedicalSignOrSymptom
 
@@ -6,10 +9,8 @@ class MedicalSymptom(MedicalSignOrSymptom):
     """Any complaint sensed and expressed by the patient (therefore defined as subjective)"
      "like stomachache, lower-back pain, or fatigue.
 
-    See https://schema.org/MedicalSymptom.
-
+    See: https://schema.org/MedicalSymptom
+    Model depth: 5
     """
-    type_: str = Field("MedicalSymptom", const=True, alias='@type')
+    type_: str = Field(default="MedicalSymptom", alias='@type')
     
-
-MedicalSymptom.update_forward_refs()
