@@ -14,13 +14,12 @@ class MedicalTestPanel(MedicalTest):
     See: https://schema.org/MedicalTestPanel
     Model depth: 4
     """
-    type_: str = Field("MedicalTestPanel", alias='@type')
+    type_: str = Field(default="MedicalTestPanel", alias='@type')
     subTest: Optional[Union[List[Union['MedicalTest', str]], 'MedicalTest', str]] = Field(
         default=None,
         description="A component test of the panel.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalTest import MedicalTest
