@@ -18,7 +18,7 @@ class MedicalTherapy(TherapeuticProcedure):
     See: https://schema.org/MedicalTherapy
     Model depth: 5
     """
-    type_: str = Field("MedicalTherapy", alias='@type')
+    type_: str = Field(default="MedicalTherapy", alias='@type')
     duplicateTherapy: Optional[Union[List[Union['MedicalTherapy', str]], 'MedicalTherapy', str]] = Field(
         default=None,
         description="A therapy that duplicates or overlaps this one.",
@@ -37,7 +37,6 @@ class MedicalTherapy(TherapeuticProcedure):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalEntity import MedicalEntity
     from pydantic_schemaorg.Text import Text
