@@ -17,13 +17,12 @@ class MedicalTrial(MedicalStudy):
     See: https://schema.org/MedicalTrial
     Model depth: 4
     """
-    type_: str = Field("MedicalTrial", alias='@type')
+    type_: str = Field(default="MedicalTrial", alias='@type')
     trialDesign: Optional[Union[List[Union['MedicalTrialDesign', str]], 'MedicalTrialDesign', str]] = Field(
         default=None,
         description="Specifics about the trial design (enumerated).",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
