@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
 class MedicalTrialDesign(MedicalEnumeration):
     """Design models for medical trials. Enumerated type.
 
-    See https://schema.org/MedicalTrialDesign.
-
+    See: https://schema.org/MedicalTrialDesign
+    Model depth: 5
     """
-    type_: str = Field("MedicalTrialDesign", const=True, alias='@type')
+    type_: str = Field(default="MedicalTrialDesign", alias='@type')
     
-
-MedicalTrialDesign.update_forward_refs()
