@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Room import Room
 
@@ -9,10 +12,8 @@ class MeetingRoom(Room):
      "<br /><br /> See also the <a href=\"/docs/hotels.html\">dedicated document on the"
      "use of schema.org for marking up hotels and other forms of accommodations</a>.
 
-    See https://schema.org/MeetingRoom.
-
+    See: https://schema.org/MeetingRoom
+    Model depth: 5
     """
-    type_: str = Field("MeetingRoom", const=True, alias='@type')
+    type_: str = Field(default="MeetingRoom", alias='@type')
     
-
-MeetingRoom.update_forward_refs()
