@@ -14,7 +14,7 @@ class Menu(CreativeWork):
     See: https://schema.org/Menu
     Model depth: 3
     """
-    type_: str = Field("Menu", alias='@type')
+    type_: str = Field(default="Menu", alias='@type')
     hasMenuSection: Optional[Union[List[Union['MenuSection', str]], 'MenuSection', str]] = Field(
         default=None,
         description="A subgrouping of the menu (by dishes, course, serving time period, etc.).",
@@ -25,7 +25,6 @@ class Menu(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MenuSection import MenuSection
     from pydantic_schemaorg.MenuItem import MenuItem
