@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class MerchantReturnEnumeration(Enumeration):
     """Enumerates several kinds of product return policies.
 
-    See https://schema.org/MerchantReturnEnumeration.
-
+    See: https://schema.org/MerchantReturnEnumeration
+    Model depth: 4
     """
-    type_: str = Field("MerchantReturnEnumeration", const=True, alias='@type')
+    type_: str = Field(default="MerchantReturnEnumeration", alias='@type')
     
-
-MerchantReturnEnumeration.update_forward_refs()
