@@ -11,6 +11,5 @@ class MerchantReturnUnlimitedWindow(MerchantReturnEnumeration):
     See: https://schema.org/MerchantReturnUnlimitedWindow
     Model depth: 5
     """
-    type_: str = Field("MerchantReturnUnlimitedWindow", alias='@type')
+    type_: str = Field(default="MerchantReturnUnlimitedWindow", alias='@type')
     
-
