@@ -15,8 +15,8 @@ class Message(CreativeWork):
     See: https://schema.org/Message
     Model depth: 3
     """
-    type_: str = Field("Message", alias='@type')
-    sender: Optional[Union[List[Union['Person', 'Organization', 'Audience', str]], 'Person', 'Organization', 'Audience', str]] = Field(
+    type_: str = Field(default="Message", alias='@type')
+    sender: Optional[Union[List[Union['Person', 'Audience', 'Organization', str]], 'Person', 'Audience', 'Organization', str]] = Field(
         default=None,
         description="A sub property of participant. The participant who is at the sending end of the action.",
     )
@@ -24,11 +24,11 @@ class Message(CreativeWork):
         default=None,
         description="A sub property of recipient. The recipient copied on a message.",
     )
-    toRecipient: Optional[Union[List[Union['Person', 'Organization', 'Audience', 'ContactPoint', str]], 'Person', 'Organization', 'Audience', 'ContactPoint', str]] = Field(
+    toRecipient: Optional[Union[List[Union['Person', 'Audience', 'Organization', 'ContactPoint', str]], 'Person', 'Audience', 'Organization', 'ContactPoint', str]] = Field(
         default=None,
         description="A sub property of recipient. The recipient who was directly sent the message.",
     )
-    recipient: Optional[Union[List[Union['Person', 'Organization', 'Audience', 'ContactPoint', str]], 'Person', 'Organization', 'Audience', 'ContactPoint', str]] = Field(
+    recipient: Optional[Union[List[Union['Person', 'Audience', 'Organization', 'ContactPoint', str]], 'Person', 'Audience', 'Organization', 'ContactPoint', str]] = Field(
         default=None,
         description="A sub property of participant. The participant who is at the receiving end of the action.",
     )
@@ -55,11 +55,10 @@ class Message(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
-    from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.Audience import Audience
+    from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.ContactPoint import ContactPoint
     from pydantic_schemaorg.CreativeWork import CreativeWork
     from pydantic_schemaorg.DateTime import DateTime
