@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class MisconceptionsHealthAspect(HealthAspectEnumeration):
     """Content about common misconceptions and myths that are related to a topic.
 
-    See https://schema.org/MisconceptionsHealthAspect.
-
+    See: https://schema.org/MisconceptionsHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("MisconceptionsHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="MisconceptionsHealthAspect", alias='@type')
     
-
-MisconceptionsHealthAspect.update_forward_refs()
