@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EventAttendanceModeEnumeration import EventAttendanceModeEnumeration
 
@@ -6,10 +9,8 @@ class MixedEventAttendanceMode(EventAttendanceModeEnumeration):
     """MixedEventAttendanceMode - an event that is conducted as a combination of both offline"
      "and online modes.
 
-    See https://schema.org/MixedEventAttendanceMode.
-
+    See: https://schema.org/MixedEventAttendanceMode
+    Model depth: 5
     """
-    type_: str = Field("MixedEventAttendanceMode", const=True, alias='@type')
+    type_: str = Field(default="MixedEventAttendanceMode", alias='@type')
     
-
-MixedEventAttendanceMode.update_forward_refs()
