@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 class MixtapeAlbum(MusicAlbumProductionType):
     """MixtapeAlbum.
 
-    See https://schema.org/MixtapeAlbum.
-
+    See: https://schema.org/MixtapeAlbum
+    Model depth: 5
     """
-    type_: str = Field("MixtapeAlbum", const=True, alias='@type')
+    type_: str = Field(default="MixtapeAlbum", alias='@type')
     
-
-MixtapeAlbum.update_forward_refs()
