@@ -15,7 +15,7 @@ class MobileApplication(SoftwareApplication):
     See: https://schema.org/MobileApplication
     Model depth: 4
     """
-    type_: str = Field("MobileApplication", alias='@type')
+    type_: str = Field(default="MobileApplication", alias='@type')
     carrierRequirements: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Specifies specific carrier(s) requirements for the application (e.g. an application"
@@ -23,6 +23,5 @@ class MobileApplication(SoftwareApplication):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
