@@ -11,6 +11,5 @@ class MobilePhoneStore(Store):
     See: https://schema.org/MobilePhoneStore
     Model depth: 5
     """
-    type_: str = Field("MobilePhoneStore", alias='@type')
+    type_: str = Field(default="MobilePhoneStore", alias='@type')
     
-
