@@ -16,7 +16,7 @@ class MolecularEntity(BioChemEntity):
     See: https://schema.org/MolecularEntity
     Model depth: 3
     """
-    type_: str = Field("MolecularEntity", alias='@type')
+    type_: str = Field(default="MolecularEntity", alias='@type')
     iupacName: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Systematic method of naming chemical compounds as recommended by the International"
@@ -63,7 +63,6 @@ class MolecularEntity(BioChemEntity):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
