@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DayOfWeek import DayOfWeek
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DayOfWeek import DayOfWeek
 class Monday(DayOfWeek):
     """The day of the week between Sunday and Tuesday.
 
-    See https://schema.org/Monday.
-
+    See: https://schema.org/Monday
+    Model depth: 5
     """
-    type_: str = Field("Monday", const=True, alias='@type')
+    type_: str = Field(default="Monday", alias='@type')
     
-
-Monday.update_forward_refs()
