@@ -14,7 +14,7 @@ class MonetaryAmountDistribution(QuantitativeValueDistribution):
     See: https://schema.org/MonetaryAmountDistribution
     Model depth: 5
     """
-    type_: str = Field("MonetaryAmountDistribution", alias='@type')
+    type_: str = Field(default="MonetaryAmountDistribution", alias='@type')
     currency: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The currency in which the monetary amount is expressed. Use standard formats: [ISO 4217"
@@ -25,6 +25,5 @@ class MonetaryAmountDistribution(QuantitativeValueDistribution):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
