@@ -15,7 +15,7 @@ class MonetaryGrant(Grant):
     See: https://schema.org/MonetaryGrant
     Model depth: 4
     """
-    type_: str = Field("MonetaryGrant", alias='@type')
+    type_: str = Field(default="MonetaryGrant", alias='@type')
     funder: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="A person or organization that supports (sponsors) something through some kind of financial"
@@ -27,7 +27,6 @@ class MonetaryGrant(Grant):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
