@@ -16,7 +16,7 @@ class MoneyTransfer(TransferAction):
     See: https://schema.org/MoneyTransfer
     Model depth: 4
     """
-    type_: str = Field("MoneyTransfer", alias='@type')
+    type_: str = Field(default="MoneyTransfer", alias='@type')
     amount: Optional[Union[List[Union[Decimal, 'Number', 'MonetaryAmount', str]], Decimal, 'Number', 'MonetaryAmount', str]] = Field(
         default=None,
         description="The amount of money.",
@@ -28,7 +28,6 @@ class MoneyTransfer(TransferAction):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
