@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AutomotiveBusiness import AutomotiveBusiness
 class MotorcycleRepair(AutomotiveBusiness):
     """A motorcycle repair shop.
 
-    See https://schema.org/MotorcycleRepair.
-
+    See: https://schema.org/MotorcycleRepair
+    Model depth: 5
     """
-    type_: str = Field("MotorcycleRepair", const=True, alias='@type')
+    type_: str = Field(default="MotorcycleRepair", alias='@type')
     
-
-MotorcycleRepair.update_forward_refs()
