@@ -15,7 +15,7 @@ class Movie(CreativeWork):
     See: https://schema.org/Movie
     Model depth: 3
     """
-    type_: str = Field("Movie", alias='@type')
+    type_: str = Field(default="Movie", alias='@type')
     actors: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="An actor, e.g. in tv, radio, movie, video games etc. Actors can be associated with individual"
@@ -79,7 +79,6 @@ class Movie(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.VideoObject import VideoObject
