@@ -14,7 +14,7 @@ class MovieSeries(CreativeWorkSeries):
     See: https://schema.org/MovieSeries
     Model depth: 4
     """
-    type_: str = Field("MovieSeries", alias='@type')
+    type_: str = Field(default="MovieSeries", alias='@type')
     actors: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="An actor, e.g. in tv, radio, movie, video games etc. Actors can be associated with individual"
@@ -50,7 +50,6 @@ class MovieSeries(CreativeWorkSeries):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.VideoObject import VideoObject
