@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 class MultiCenterTrial(MedicalTrialDesign):
     """A trial that takes place at multiple centers.
 
-    See https://schema.org/MultiCenterTrial.
-
+    See: https://schema.org/MultiCenterTrial
+    Model depth: 6
     """
-    type_: str = Field("MultiCenterTrial", const=True, alias='@type')
+    type_: str = Field(default="MultiCenterTrial", alias='@type')
     
-
-MultiCenterTrial.update_forward_refs()
