@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GamePlayMode import GamePlayMode
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GamePlayMode import GamePlayMode
 class MultiPlayer(GamePlayMode):
     """Play mode: MultiPlayer. Requiring or allowing multiple human players to play simultaneously.
 
-    See https://schema.org/MultiPlayer.
-
+    See: https://schema.org/MultiPlayer
+    Model depth: 5
     """
-    type_: str = Field("MultiPlayer", const=True, alias='@type')
+    type_: str = Field(default="MultiPlayer", alias='@type')
     
-
-MultiPlayer.update_forward_refs()
