@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.InfectiousAgentClass import InfectiousAgentClass
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.InfectiousAgentClass import InfectiousAgentClass
 class MulticellularParasite(InfectiousAgentClass):
     """Multicellular parasite that causes an infection.
 
-    See https://schema.org/MulticellularParasite.
-
+    See: https://schema.org/MulticellularParasite
+    Model depth: 6
     """
-    type_: str = Field("MulticellularParasite", const=True, alias='@type')
+    type_: str = Field(default="MulticellularParasite", alias='@type')
     
-
-MulticellularParasite.update_forward_refs()
