@@ -15,7 +15,7 @@ class Muscle(AnatomicalStructure):
     See: https://schema.org/Muscle
     Model depth: 4
     """
-    type_: str = Field("Muscle", alias='@type')
+    type_: str = Field(default="Muscle", alias='@type')
     nerve: Optional[Union[List[Union['Nerve', str]], 'Nerve', str]] = Field(
         default=None,
         description="The underlying innervation associated with the muscle.",
@@ -38,7 +38,6 @@ class Muscle(AnatomicalStructure):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Nerve import Nerve
     from pydantic_schemaorg.Text import Text
