@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -6,10 +9,8 @@ class Musculoskeletal(MedicalSpecialty):
     """A specific branch of medical science that pertains to diagnosis and treatment of disorders"
      "of muscles, ligaments and skeletal system.
 
-    See https://schema.org/Musculoskeletal.
-
+    See: https://schema.org/Musculoskeletal
+    Model depth: 6
     """
-    type_: str = Field("Musculoskeletal", const=True, alias='@type')
+    type_: str = Field(default="Musculoskeletal", alias='@type')
     
-
-Musculoskeletal.update_forward_refs()
