@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class MusculoskeletalExam(PhysicalExam):
     """Musculoskeletal system clinical examination.
 
-    See https://schema.org/MusculoskeletalExam.
-
+    See: https://schema.org/MusculoskeletalExam
+    Model depth: 5
     """
-    type_: str = Field("MusculoskeletalExam", const=True, alias='@type')
+    type_: str = Field(default="MusculoskeletalExam", alias='@type')
     
-
-MusculoskeletalExam.update_forward_refs()
