@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class Museum(CivicStructure):
     """A museum.
 
-    See https://schema.org/Museum.
-
+    See: https://schema.org/Museum
+    Model depth: 4
     """
-    type_: str = Field("Museum", const=True, alias='@type')
+    type_: str = Field(default="Museum", alias='@type')
     
-
-Museum.update_forward_refs()
