@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -6,10 +9,8 @@ class MusicAlbumProductionType(Enumeration):
     """Classification of the album by it's type of content: soundtrack, live album, studio"
      "album, etc.
 
-    See https://schema.org/MusicAlbumProductionType.
-
+    See: https://schema.org/MusicAlbumProductionType
+    Model depth: 4
     """
-    type_: str = Field("MusicAlbumProductionType", const=True, alias='@type')
+    type_: str = Field(default="MusicAlbumProductionType", alias='@type')
     
-
-MusicAlbumProductionType.update_forward_refs()
