@@ -14,7 +14,7 @@ class MusicComposition(CreativeWork):
     See: https://schema.org/MusicComposition
     Model depth: 3
     """
-    type_: str = Field("MusicComposition", alias='@type')
+    type_: str = Field(default="MusicComposition", alias='@type')
     composer: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="The person or organization who wrote a composition, or who is the composer of a work performed"
@@ -58,7 +58,6 @@ class MusicComposition(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
