@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Event import Event
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Event import Event
 class MusicEvent(Event):
     """Event type: Music event.
 
-    See https://schema.org/MusicEvent.
-
+    See: https://schema.org/MusicEvent
+    Model depth: 3
     """
-    type_: str = Field("MusicEvent", const=True, alias='@type')
+    type_: str = Field(default="MusicEvent", alias='@type')
     
-
-MusicEvent.update_forward_refs()
