@@ -14,7 +14,7 @@ class MusicPlaylist(CreativeWork):
     See: https://schema.org/MusicPlaylist
     Model depth: 3
     """
-    type_: str = Field("MusicPlaylist", alias='@type')
+    type_: str = Field(default="MusicPlaylist", alias='@type')
     numTracks: Optional[Union[List[Union[int, 'Integer', str]], int, 'Integer', str]] = Field(
         default=None,
         description="The number of tracks in this album or playlist.",
@@ -23,14 +23,13 @@ class MusicPlaylist(CreativeWork):
         default=None,
         description="A music recording (track)&#x2014;usually a single song.",
     )
-    track: Optional[Union[List[Union['ItemList', 'MusicRecording', str]], 'ItemList', 'MusicRecording', str]] = Field(
+    track: Optional[Union[List[Union['MusicRecording', 'ItemList', str]], 'MusicRecording', 'ItemList', str]] = Field(
         default=None,
         description="A music recording (track)&#x2014;usually a single song. If an ItemList is given, the"
      "list should contain items of type MusicRecording.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Integer import Integer
     from pydantic_schemaorg.MusicRecording import MusicRecording
