@@ -14,7 +14,7 @@ class MusicRecording(CreativeWork):
     See: https://schema.org/MusicRecording
     Model depth: 3
     """
-    type_: str = Field("MusicRecording", alias='@type')
+    type_: str = Field(default="MusicRecording", alias='@type')
     inPlaylist: Optional[Union[List[Union['MusicPlaylist', str]], 'MusicPlaylist', str]] = Field(
         default=None,
         description="The playlist to which this recording belongs.",
@@ -41,7 +41,6 @@ class MusicRecording(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MusicPlaylist import MusicPlaylist
     from pydantic_schemaorg.Duration import Duration
