@@ -14,7 +14,7 @@ class MusicRelease(MusicPlaylist):
     See: https://schema.org/MusicRelease
     Model depth: 4
     """
-    type_: str = Field("MusicRelease", alias='@type')
+    type_: str = Field(default="MusicRelease", alias='@type')
     releaseOf: Optional[Union[List[Union['MusicAlbum', str]], 'MusicAlbum', str]] = Field(
         default=None,
         description="The album this is a release of.",
@@ -43,7 +43,6 @@ class MusicRelease(MusicPlaylist):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MusicAlbum import MusicAlbum
     from pydantic_schemaorg.Duration import Duration
