@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class MusicVenue(CivicStructure):
     """A music venue.
 
-    See https://schema.org/MusicVenue.
-
+    See: https://schema.org/MusicVenue
+    Model depth: 4
     """
-    type_: str = Field("MusicVenue", const=True, alias='@type')
+    type_: str = Field(default="MusicVenue", alias='@type')
     
-
-MusicVenue.update_forward_refs()
