@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Organization import Organization
 class NGO(Organization):
     """Organization: Non-governmental Organization.
 
-    See https://schema.org/NGO.
-
+    See: https://schema.org/NGO
+    Model depth: 3
     """
-    type_: str = Field("NGO", const=True, alias='@type')
+    type_: str = Field(default="NGO", alias='@type')
     
-
-NGO.update_forward_refs()
