@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.NonprofitType import NonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.NonprofitType import NonprofitType
 class NLNonprofitType(NonprofitType):
     """NLNonprofitType: Non-profit organization type originating from the Netherlands.
 
-    See https://schema.org/NLNonprofitType.
-
+    See: https://schema.org/NLNonprofitType
+    Model depth: 5
     """
-    type_: str = Field("NLNonprofitType", const=True, alias='@type')
+    type_: str = Field(default="NLNonprofitType", alias='@type')
     
-
-NLNonprofitType.update_forward_refs()
