@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAndBeautyBusiness import HealthAndBeautyBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAndBeautyBusiness import HealthAndBeautyBusiness
 class NailSalon(HealthAndBeautyBusiness):
     """A nail salon.
 
-    See https://schema.org/NailSalon.
-
+    See: https://schema.org/NailSalon
+    Model depth: 5
     """
-    type_: str = Field("NailSalon", const=True, alias='@type')
+    type_: str = Field(default="NailSalon", alias='@type')
     
-
-NailSalon.update_forward_refs()
