@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class Neck(PhysicalExam):
     """Neck assessment with clinical examination.
 
-    See https://schema.org/Neck.
-
+    See: https://schema.org/Neck
+    Model depth: 5
     """
-    type_: str = Field("Neck", const=True, alias='@type')
+    type_: str = Field(default="Neck", alias='@type')
     
-
-Neck.update_forward_refs()
