@@ -15,7 +15,7 @@ class NewsMediaOrganization(Organization):
     See: https://schema.org/NewsMediaOrganization
     Model depth: 3
     """
-    type_: str = Field("NewsMediaOrganization", alias='@type')
+    type_: str = Field(default="NewsMediaOrganization", alias='@type')
     actionableFeedbackPolicy: Optional[Union[List[Union[AnyUrl, 'URL', 'CreativeWork', str]], AnyUrl, 'URL', 'CreativeWork', str]] = Field(
         default=None,
         description="For a [[NewsMediaOrganization]] or other news-related [[Organization]], a statement"
@@ -82,7 +82,6 @@ class NewsMediaOrganization(Organization):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.CreativeWork import CreativeWork
