@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.USNonprofitType import USNonprofitType
 class Nonprofit501c10(USNonprofitType):
     """Nonprofit501c10: Non-profit type referring to Domestic Fraternal Societies and Associations.
 
-    See https://schema.org/Nonprofit501c10.
-
+    See: https://schema.org/Nonprofit501c10
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501c10", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501c10", alias='@type')
     
-
-Nonprofit501c10.update_forward_refs()
