@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.USNonprofitType import USNonprofitType
 class Nonprofit501c20(USNonprofitType):
     """Nonprofit501c20: Non-profit type referring to Group Legal Services Plan Organizations.
 
-    See https://schema.org/Nonprofit501c20.
-
+    See: https://schema.org/Nonprofit501c20
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501c20", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501c20", alias='@type')
     
-
-Nonprofit501c20.update_forward_refs()
