@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.USNonprofitType import USNonprofitType
 class Nonprofit501c22(USNonprofitType):
     """Nonprofit501c22: Non-profit type referring to Withdrawal Liability Payment Funds.
 
-    See https://schema.org/Nonprofit501c22.
-
+    See: https://schema.org/Nonprofit501c22
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501c22", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501c22", alias='@type')
     
-
-Nonprofit501c22.update_forward_refs()
