@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -6,10 +9,8 @@ class Nonprofit501c26(USNonprofitType):
     """Nonprofit501c26: Non-profit type referring to State-Sponsored Organizations Providing"
      "Health Coverage for High-Risk Individuals.
 
-    See https://schema.org/Nonprofit501c26.
-
+    See: https://schema.org/Nonprofit501c26
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501c26", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501c26", alias='@type')
     
-
-Nonprofit501c26.update_forward_refs()
