@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -6,10 +9,8 @@ class Nonprofit501c4(USNonprofitType):
     """Nonprofit501c4: Non-profit type referring to Civic Leagues, Social Welfare Organizations,"
      "and Local Associations of Employees.
 
-    See https://schema.org/Nonprofit501c4.
-
+    See: https://schema.org/Nonprofit501c4
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501c4", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501c4", alias='@type')
     
-
-Nonprofit501c4.update_forward_refs()
