@@ -12,6 +12,5 @@ class Nonprofit501c5(USNonprofitType):
     See: https://schema.org/Nonprofit501c5
     Model depth: 6
     """
-    type_: str = Field("Nonprofit501c5", alias='@type')
+    type_: str = Field(default="Nonprofit501c5", alias='@type')
     
-
