@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.USNonprofitType import USNonprofitType
 class Nonprofit501c7(USNonprofitType):
     """Nonprofit501c7: Non-profit type referring to Social and Recreational Clubs.
 
-    See https://schema.org/Nonprofit501c7.
-
+    See: https://schema.org/Nonprofit501c7
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501c7", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501c7", alias='@type')
     
-
-Nonprofit501c7.update_forward_refs()
