@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.USNonprofitType import USNonprofitType
 class Nonprofit501c9(USNonprofitType):
     """Nonprofit501c9: Non-profit type referring to Voluntary Employee Beneficiary Associations.
 
-    See https://schema.org/Nonprofit501c9.
-
+    See: https://schema.org/Nonprofit501c9
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501c9", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501c9", alias='@type')
     
-
-Nonprofit501c9.update_forward_refs()
