@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.USNonprofitType import USNonprofitType
 class Nonprofit501d(USNonprofitType):
     """Nonprofit501d: Non-profit type referring to Religious and Apostolic Associations.
 
-    See https://schema.org/Nonprofit501d.
-
+    See: https://schema.org/Nonprofit501d
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501d", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501d", alias='@type')
     
-
-Nonprofit501d.update_forward_refs()
