@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.USNonprofitType import USNonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.USNonprofitType import USNonprofitType
 class Nonprofit501q(USNonprofitType):
     """Nonprofit501q: Non-profit type referring to Credit Counseling Organizations.
 
-    See https://schema.org/Nonprofit501q.
-
+    See: https://schema.org/Nonprofit501q
+    Model depth: 6
     """
-    type_: str = Field("Nonprofit501q", const=True, alias='@type')
+    type_: str = Field(default="Nonprofit501q", alias='@type')
     
-
-Nonprofit501q.update_forward_refs()
