@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.NLNonprofitType import NLNonprofitType
 
@@ -6,10 +9,8 @@ class NonprofitSBBI(NLNonprofitType):
     """NonprofitSBBI: Non-profit type referring to a Social Interest Promoting Institution"
      "(NL).
 
-    See https://schema.org/NonprofitSBBI.
-
+    See: https://schema.org/NonprofitSBBI
+    Model depth: 6
     """
-    type_: str = Field("NonprofitSBBI", const=True, alias='@type')
+    type_: str = Field(default="NonprofitSBBI", alias='@type')
     
-
-NonprofitSBBI.update_forward_refs()
