@@ -12,6 +12,5 @@ class NonprofitType(Enumeration):
     See: https://schema.org/NonprofitType
     Model depth: 4
     """
-    type_: str = Field("NonprofitType", alias='@type')
+    type_: str = Field(default="NonprofitType", alias='@type')
     
-
