@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class Nose(PhysicalExam):
     """Nose function assessment with clinical examination.
 
-    See https://schema.org/Nose.
-
+    See: https://schema.org/Nose
+    Model depth: 5
     """
-    type_: str = Field("Nose", const=True, alias='@type')
+    type_: str = Field(default="Nose", alias='@type')
     
-
-Nose.update_forward_refs()
