@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LegalForceStatus import LegalForceStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LegalForceStatus import LegalForceStatus
 class NotInForce(LegalForceStatus):
     """Indicates that a legislation is currently not in force.
 
-    See https://schema.org/NotInForce.
-
+    See: https://schema.org/NotInForce
+    Model depth: 6
     """
-    type_: str = Field("NotInForce", const=True, alias='@type')
+    type_: str = Field(default="NotInForce", alias='@type')
     
-
-NotInForce.update_forward_refs()
