@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 class NotYetRecruiting(MedicalStudyStatus):
     """Not yet recruiting.
 
-    See https://schema.org/NotYetRecruiting.
-
+    See: https://schema.org/NotYetRecruiting
+    Model depth: 6
     """
-    type_: str = Field("NotYetRecruiting", const=True, alias='@type')
+    type_: str = Field(default="NotYetRecruiting", alias='@type')
     
-
-NotYetRecruiting.update_forward_refs()
