@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LegalService import LegalService
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LegalService import LegalService
 class Notary(LegalService):
     """A notary.
 
-    See https://schema.org/Notary.
-
+    See: https://schema.org/Notary
+    Model depth: 5
     """
-    type_: str = Field("Notary", const=True, alias='@type')
+    type_: str = Field(default="Notary", alias='@type')
     
-
-Notary.update_forward_refs()
