@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DrugPrescriptionStatus import DrugPrescriptionStatus
 
@@ -6,10 +9,8 @@ class OTC(DrugPrescriptionStatus):
     """The character of a medical substance, typically a medicine, of being available over"
      "the counter or not.
 
-    See https://schema.org/OTC.
-
+    See: https://schema.org/OTC
+    Model depth: 6
     """
-    type_: str = Field("OTC", const=True, alias='@type')
+    type_: str = Field(default="OTC", alias='@type')
     
-
-OTC.update_forward_refs()
