@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalObservationalStudyDesign import MedicalObservationalStudyDesign
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalObservationalStudyDesign import MedicalObservatio
 class Observational(MedicalObservationalStudyDesign):
     """An observational study design.
 
-    See https://schema.org/Observational.
-
+    See: https://schema.org/Observational
+    Model depth: 6
     """
-    type_: str = Field("Observational", const=True, alias='@type')
+    type_: str = Field(default="Observational", alias='@type')
     
-
-Observational.update_forward_refs()
