@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
 
@@ -7,10 +10,8 @@ class OccupationalActivity(PhysicalActivityCategory):
      "tables, maid service, carrying a mailbag, picking fruits or vegetables, construction"
      "work, etc.
 
-    See https://schema.org/OccupationalActivity.
-
+    See: https://schema.org/OccupationalActivity
+    Model depth: 5
     """
-    type_: str = Field("OccupationalActivity", const=True, alias='@type')
+    type_: str = Field(default="OccupationalActivity", alias='@type')
     
-
-OccupationalActivity.update_forward_refs()
