@@ -15,13 +15,12 @@ class OccupationalExperienceRequirements(Intangible):
     See: https://schema.org/OccupationalExperienceRequirements
     Model depth: 3
     """
-    type_: str = Field("OccupationalExperienceRequirements", alias='@type')
+    type_: str = Field(default="OccupationalExperienceRequirements", alias='@type')
     monthsOfExperience: Optional[Union[List[Union[Decimal, 'Number', str]], Decimal, 'Number', str]] = Field(
         default=None,
         description="Indicates the minimal number of months of experience required for a position.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
