@@ -26,7 +26,7 @@ class Offer(Intangible):
     See: https://schema.org/Offer
     Model depth: 3
     """
-    type_: str = Field("Offer", alias='@type')
+    type_: str = Field(default="Offer", alias='@type')
     hasMeasurement: Optional[Union[List[Union['QuantitativeValue', str]], 'QuantitativeValue', str]] = Field(
         default=None,
         description="A product measurement, for example the inseam of pants, the wheel size of a bicycle, or"
@@ -93,7 +93,7 @@ class Offer(Intangible):
      "above a certain order volume, or to limit the acceptance of credit cards to purchases"
      "to a certain minimal amount.",
     )
-    acceptedPaymentMethod: Optional[Union[List[Union['LoanOrCredit', 'PaymentMethod', str]], 'LoanOrCredit', 'PaymentMethod', str]] = Field(
+    acceptedPaymentMethod: Optional[Union[List[Union['PaymentMethod', 'LoanOrCredit', str]], 'PaymentMethod', 'LoanOrCredit', str]] = Field(
         default=None,
         description="The payment method(s) accepted by seller for this offer.",
     )
@@ -106,7 +106,7 @@ class Offer(Intangible):
         default=None,
         description="The duration for which the given offer is valid.",
     )
-    category: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text', 'Thing', 'PhysicalActivityCategory']], AnyUrl, 'URL', str, 'Text', 'Thing', 'PhysicalActivityCategory']] = Field(
+    category: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text', 'PhysicalActivityCategory', 'Thing']], AnyUrl, 'URL', str, 'Text', 'PhysicalActivityCategory', 'Thing']] = Field(
         default=None,
         description="A category for the item. Greater signs or slashes can be used to informally indicate a"
      "category hierarchy.",
@@ -115,7 +115,7 @@ class Offer(Intangible):
         default=None,
         description="Specifies a MerchantReturnPolicy that may be applicable.",
     )
-    availabilityStarts: Optional[Union[List[Union[ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]], ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]] = Field(
+    availabilityStarts: Optional[Union[List[Union[ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]], ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]] = Field(
         default=None,
         description="The beginning of the availability of the product or service included in the offer.",
     )
@@ -187,7 +187,7 @@ class Offer(Intangible):
         default=None,
         description="The date when the item becomes valid.",
     )
-    itemOffered: Optional[Union[List[Union['CreativeWork', 'Trip', 'Event', 'Product', 'Service', 'MenuItem', 'AggregateOffer', str]], 'CreativeWork', 'Trip', 'Event', 'Product', 'Service', 'MenuItem', 'AggregateOffer', str]] = Field(
+    itemOffered: Optional[Union[List[Union['Product', 'Event', 'MenuItem', 'AggregateOffer', 'Service', 'Trip', 'CreativeWork', str]], 'Product', 'Event', 'MenuItem', 'AggregateOffer', 'Service', 'Trip', 'CreativeWork', str]] = Field(
         default=None,
         description="An item being offered (or demanded). The transactional nature of the offer or demand"
      "is documented using [[businessFunction]], e.g. sell, lease etc. While several common"
@@ -199,7 +199,7 @@ class Offer(Intangible):
         description="The GTIN-14 code of the product, or the product to which the offer refers. See [GS1 GTIN"
      "Summary](http://www.gs1.org/barcodes/technical/idkeys/gtin) for more details.",
     )
-    availabilityEnds: Optional[Union[List[Union[ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]], ISO8601Date, 'DateTime', ISO8601Date, 'Date', time, 'Time', str]] = Field(
+    availabilityEnds: Optional[Union[List[Union[ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]], ISO8601Date, 'DateTime', time, 'Time', ISO8601Date, 'Date', str]] = Field(
         default=None,
         description="The end of the availability of the product or service included in the offer.",
     )
@@ -277,7 +277,6 @@ class Offer(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
     from pydantic_schemaorg.TypeAndQuantityNode import TypeAndQuantityNode
@@ -292,12 +291,12 @@ if TYPE_CHECKING:
     from pydantic_schemaorg.ItemAvailability import ItemAvailability
     from pydantic_schemaorg.Duration import Duration
     from pydantic_schemaorg.PriceSpecification import PriceSpecification
-    from pydantic_schemaorg.LoanOrCredit import LoanOrCredit
     from pydantic_schemaorg.PaymentMethod import PaymentMethod
+    from pydantic_schemaorg.LoanOrCredit import LoanOrCredit
     from pydantic_schemaorg.BusinessFunction import BusinessFunction
     from pydantic_schemaorg.URL import URL
-    from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
+    from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.MerchantReturnPolicy import MerchantReturnPolicy
     from pydantic_schemaorg.DateTime import DateTime
     from pydantic_schemaorg.Time import Time
@@ -305,13 +304,13 @@ if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.WarrantyPromise import WarrantyPromise
-    from pydantic_schemaorg.CreativeWork import CreativeWork
-    from pydantic_schemaorg.Trip import Trip
-    from pydantic_schemaorg.Event import Event
     from pydantic_schemaorg.Product import Product
-    from pydantic_schemaorg.Service import Service
+    from pydantic_schemaorg.Event import Event
     from pydantic_schemaorg.MenuItem import MenuItem
     from pydantic_schemaorg.AggregateOffer import AggregateOffer
+    from pydantic_schemaorg.Service import Service
+    from pydantic_schemaorg.Trip import Trip
+    from pydantic_schemaorg.CreativeWork import CreativeWork
     from pydantic_schemaorg.Review import Review
     from pydantic_schemaorg.OfferItemCondition import OfferItemCondition
     from pydantic_schemaorg.OfferShippingDetails import OfferShippingDetails
