@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ItemList import ItemList
 
@@ -6,10 +9,8 @@ class OfferCatalog(ItemList):
     """An OfferCatalog is an ItemList that contains related Offers and/or further OfferCatalogs"
      "that are offeredBy the same provider.
 
-    See https://schema.org/OfferCatalog.
-
+    See: https://schema.org/OfferCatalog
+    Model depth: 4
     """
-    type_: str = Field("OfferCatalog", const=True, alias='@type')
+    type_: str = Field(default="OfferCatalog", alias='@type')
     
-
-OfferCatalog.update_forward_refs()
