@@ -14,6 +14,5 @@ class OfferForLease(Offer):
     See: https://schema.org/OfferForLease
     Model depth: 4
     """
-    type_: str = Field("OfferForLease", alias='@type')
+    type_: str = Field(default="OfferForLease", alias='@type')
     
-
