@@ -11,6 +11,5 @@ class OfficeEquipmentStore(Store):
     See: https://schema.org/OfficeEquipmentStore
     Model depth: 5
     """
-    type_: str = Field("OfficeEquipmentStore", alias='@type')
+    type_: str = Field(default="OfficeEquipmentStore", alias='@type')
     
-
