@@ -14,6 +14,5 @@ class OfficialLegalValue(LegalValueLevel):
     See: https://schema.org/OfficialLegalValue
     Model depth: 5
     """
-    type_: str = Field("OfficialLegalValue", alias='@type')
+    type_: str = Field(default="OfficialLegalValue", alias='@type')
     
-
