@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GameServerStatus import GameServerStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GameServerStatus import GameServerStatus
 class OfflinePermanently(GameServerStatus):
     """Game server status: OfflinePermanently. Server is offline and not available.
 
-    See https://schema.org/OfflinePermanently.
-
+    See: https://schema.org/OfflinePermanently
+    Model depth: 6
     """
-    type_: str = Field("OfflinePermanently", const=True, alias='@type')
+    type_: str = Field(default="OfflinePermanently", alias='@type')
     
-
-OfflinePermanently.update_forward_refs()
