@@ -12,6 +12,5 @@ class OnDemandEvent(PublicationEvent):
     See: https://schema.org/OnDemandEvent
     Model depth: 4
     """
-    type_: str = Field("OnDemandEvent", alias='@type')
+    type_: str = Field(default="OnDemandEvent", alias='@type')
     
-
