@@ -11,6 +11,5 @@ class OnSitePickup(DeliveryMethod):
     See: https://schema.org/OnSitePickup
     Model depth: 5
     """
-    type_: str = Field("OnSitePickup", alias='@type')
+    type_: str = Field(default="OnSitePickup", alias='@type')
     
-
