@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GameServerStatus import GameServerStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GameServerStatus import GameServerStatus
 class Online(GameServerStatus):
     """Game server status: Online. Server is available.
 
-    See https://schema.org/Online.
-
+    See: https://schema.org/Online
+    Model depth: 6
     """
-    type_: str = Field("Online", const=True, alias='@type')
+    type_: str = Field(default="Online", alias='@type')
     
-
-Online.update_forward_refs()
