@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.EventAttendanceModeEnumeration import EventAttendanceModeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.EventAttendanceModeEnumeration import EventAttendanceMod
 class OnlineEventAttendanceMode(EventAttendanceModeEnumeration):
     """OnlineEventAttendanceMode - an event that is primarily conducted online.
 
-    See https://schema.org/OnlineEventAttendanceMode.
-
+    See: https://schema.org/OnlineEventAttendanceMode
+    Model depth: 5
     """
-    type_: str = Field("OnlineEventAttendanceMode", const=True, alias='@type')
+    type_: str = Field(default="OnlineEventAttendanceMode", alias='@type')
     
-
-OnlineEventAttendanceMode.update_forward_refs()
