@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ItemAvailability import ItemAvailability
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ItemAvailability import ItemAvailability
 class OnlineOnly(ItemAvailability):
     """Indicates that the item is available only online.
 
-    See https://schema.org/OnlineOnly.
-
+    See: https://schema.org/OnlineOnly
+    Model depth: 5
     """
-    type_: str = Field("OnlineOnly", const=True, alias='@type')
+    type_: str = Field(default="OnlineOnly", alias='@type')
     
-
-OnlineOnly.update_forward_refs()
