@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 
@@ -6,10 +9,8 @@ class OpenTrial(MedicalTrialDesign):
     """A trial design in which the researcher knows the full details of the treatment, and so"
      "does the patient.
 
-    See https://schema.org/OpenTrial.
-
+    See: https://schema.org/OpenTrial
+    Model depth: 6
     """
-    type_: str = Field("OpenTrial", const=True, alias='@type')
+    type_: str = Field(default="OpenTrial", alias='@type')
     
-
-OpenTrial.update_forward_refs()
