@@ -19,7 +19,7 @@ class OpeningHoursSpecification(StructuredValue):
     See: https://schema.org/OpeningHoursSpecification
     Model depth: 4
     """
-    type_: str = Field("OpeningHoursSpecification", alias='@type')
+    type_: str = Field(default="OpeningHoursSpecification", alias='@type')
     opens: Optional[Union[List[Union[time, 'Time', str]], time, 'Time', str]] = Field(
         default=None,
         description="The opening hour of the place or service on the given day(s) of the week.",
@@ -43,7 +43,6 @@ class OpeningHoursSpecification(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Time import Time
     from pydantic_schemaorg.DateTime import DateTime
