@@ -18,7 +18,7 @@ class Order(Intangible):
     See: https://schema.org/Order
     Model depth: 3
     """
-    type_: str = Field("Order", alias='@type')
+    type_: str = Field(default="Order", alias='@type')
     orderDate: Optional[Union[List[Union[ISO8601Date, 'DateTime', ISO8601Date, 'Date', str]], ISO8601Date, 'DateTime', ISO8601Date, 'Date', str]] = Field(
         default=None,
         description="Date order was placed.",
@@ -54,7 +54,7 @@ class Order(Intangible):
         default=None,
         description="Was the offer accepted as a gift for someone other than the buyer.",
     )
-    orderedItem: Optional[Union[List[Union['Product', 'OrderItem', 'Service', str]], 'Product', 'OrderItem', 'Service', str]] = Field(
+    orderedItem: Optional[Union[List[Union['Service', 'Product', 'OrderItem', str]], 'Service', 'Product', 'OrderItem', str]] = Field(
         default=None,
         description="The item ordered.",
     )
@@ -116,7 +116,6 @@ class Order(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.DateTime import DateTime
     from pydantic_schemaorg.Date import Date
@@ -124,9 +123,9 @@ if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.ParcelDelivery import ParcelDelivery
     from pydantic_schemaorg.Boolean import Boolean
+    from pydantic_schemaorg.Service import Service
     from pydantic_schemaorg.Product import Product
     from pydantic_schemaorg.OrderItem import OrderItem
-    from pydantic_schemaorg.Service import Service
     from pydantic_schemaorg.PostalAddress import PostalAddress
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
