@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.OrderStatus import OrderStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.OrderStatus import OrderStatus
 class OrderDelivered(OrderStatus):
     """OrderStatus representing successful delivery of an order.
 
-    See https://schema.org/OrderDelivered.
-
+    See: https://schema.org/OrderDelivered
+    Model depth: 6
     """
-    type_: str = Field("OrderDelivered", const=True, alias='@type')
+    type_: str = Field(default="OrderDelivered", alias='@type')
     
-
-OrderDelivered.update_forward_refs()
