@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.OrderStatus import OrderStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.OrderStatus import OrderStatus
 class OrderProcessing(OrderStatus):
     """OrderStatus representing that an order is being processed.
 
-    See https://schema.org/OrderProcessing.
-
+    See: https://schema.org/OrderProcessing
+    Model depth: 6
     """
-    type_: str = Field("OrderProcessing", const=True, alias='@type')
+    type_: str = Field(default="OrderProcessing", alias='@type')
     
-
-OrderProcessing.update_forward_refs()
