@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.OrderStatus import OrderStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.OrderStatus import OrderStatus
 class OrderReturned(OrderStatus):
     """OrderStatus representing that an order has been returned.
 
-    See https://schema.org/OrderReturned.
-
+    See: https://schema.org/OrderReturned
+    Model depth: 6
     """
-    type_: str = Field("OrderReturned", const=True, alias='@type')
+    type_: str = Field(default="OrderReturned", alias='@type')
     
-
-OrderReturned.update_forward_refs()
