@@ -16,7 +16,7 @@ class Organization(Thing):
     See: https://schema.org/Organization
     Model depth: 2
     """
-    type_: str = Field("Organization", alias='@type')
+    type_: str = Field(default="Organization", alias='@type')
     subOrganization: Optional[Union[List[Union['Organization', str]], 'Organization', str]] = Field(
         default=None,
         description="A relationship between two organizations where the first includes the second, e.g.,"
@@ -122,7 +122,7 @@ class Organization(Thing):
         default=None,
         description="Specifies a MerchantReturnPolicy that may be applicable.",
     )
-    location: Optional[Union[List[Union[str, 'Text', 'Place', 'VirtualLocation', 'PostalAddress']], str, 'Text', 'Place', 'VirtualLocation', 'PostalAddress']] = Field(
+    location: Optional[Union[List[Union[str, 'Text', 'VirtualLocation', 'PostalAddress', 'Place']], str, 'Text', 'VirtualLocation', 'PostalAddress', 'Place']] = Field(
         default=None,
         description="The location of, for example, where an event is happening, where an organization is located,"
      "or where an action takes place.",
@@ -222,7 +222,7 @@ class Organization(Thing):
         default=None,
         description="Upcoming or past events associated with this place or organization.",
     )
-    serviceArea: Optional[Union[List[Union['AdministrativeArea', 'GeoShape', 'Place', str]], 'AdministrativeArea', 'GeoShape', 'Place', str]] = Field(
+    serviceArea: Optional[Union[List[Union['GeoShape', 'AdministrativeArea', 'Place', str]], 'GeoShape', 'AdministrativeArea', 'Place', str]] = Field(
         default=None,
         description="The geographic area where the service is provided.",
     )
@@ -314,7 +314,6 @@ class Organization(Thing):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.ContactPoint import ContactPoint
     from pydantic_schemaorg.Text import Text
