@@ -15,7 +15,7 @@ class OrganizationRole(Role):
     See: https://schema.org/OrganizationRole
     Model depth: 4
     """
-    type_: str = Field("OrganizationRole", alias='@type')
+    type_: str = Field(default="OrganizationRole", alias='@type')
     numberedPosition: Optional[Union[List[Union[Decimal, 'Number', str]], Decimal, 'Number', str]] = Field(
         default=None,
         description="A number associated with a role in an organization, for example, the number on an athlete's"
@@ -23,6 +23,5 @@ class OrganizationRole(Role):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
