@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MediaManipulationRatingEnumeration import MediaManipulationRatingEnumeration
 
@@ -14,10 +17,8 @@ class OriginalMediaContent(MediaManipulationRatingEnumeration):
      "has been misleadingly altered or manipulated, though it may contain false or misleading"
      "claims.
 
-    See https://schema.org/OriginalMediaContent.
-
+    See: https://schema.org/OriginalMediaContent
+    Model depth: 5
     """
-    type_: str = Field("OriginalMediaContent", const=True, alias='@type')
+    type_: str = Field(default="OriginalMediaContent", alias='@type')
     
-
-OriginalMediaContent.update_forward_refs()
