@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration
 class OriginalShippingFees(ReturnFeesEnumeration):
     """Specifies that the customer must pay the original shipping costs when returning a product.
 
-    See https://schema.org/OriginalShippingFees.
-
+    See: https://schema.org/OriginalShippingFees
+    Model depth: 5
     """
-    type_: str = Field("OriginalShippingFees", const=True, alias='@type')
+    type_: str = Field(default="OriginalShippingFees", alias='@type')
     
-
-OriginalShippingFees.update_forward_refs()
