@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalImagingTechnique import MedicalImagingTechnique
 class PET(MedicalImagingTechnique):
     """Positron emission tomography imaging.
 
-    See https://schema.org/PET.
-
+    See: https://schema.org/PET
+    Model depth: 6
     """
-    type_: str = Field("PET", const=True, alias='@type')
+    type_: str = Field(default="PET", alias='@type')
     
-
-PET.update_forward_refs()
