@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType
 class PaidLeave(GovernmentBenefitsType):
     """PaidLeave: this is a benefit for paid leave.
 
-    See https://schema.org/PaidLeave.
-
+    See: https://schema.org/PaidLeave
+    Model depth: 5
     """
-    type_: str = Field("PaidLeave", const=True, alias='@type')
+    type_: str = Field(default="PaidLeave", alias='@type')
     
-
-PaidLeave.update_forward_refs()
