@@ -16,7 +16,7 @@ class ParcelDelivery(Intangible):
     See: https://schema.org/ParcelDelivery
     Model depth: 3
     """
-    type_: str = Field("ParcelDelivery", alias='@type')
+    type_: str = Field(default="ParcelDelivery", alias='@type')
     trackingNumber: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Shipper tracking number.",
@@ -70,7 +70,6 @@ class ParcelDelivery(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Product import Product
