@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DeliveryMethod import DeliveryMethod
 
@@ -7,10 +10,8 @@ class ParcelService(DeliveryMethod):
      "used values: * http://purl.org/goodrelations/v1#DHL * http://purl.org/goodrelations/v1#FederalExpress"
      "* http://purl.org/goodrelations/v1#UPS
 
-    See https://schema.org/ParcelService.
-
+    See: https://schema.org/ParcelService
+    Model depth: 5
     """
-    type_: str = Field("ParcelService", const=True, alias='@type')
+    type_: str = Field(default="ParcelService", alias='@type')
     
-
-ParcelService.update_forward_refs()
