@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GovernmentBenefitsType import GovernmentBenefitsType
 class ParentalSupport(GovernmentBenefitsType):
     """ParentalSupport: this is a benefit for parental support.
 
-    See https://schema.org/ParentalSupport.
-
+    See: https://schema.org/ParentalSupport
+    Model depth: 5
     """
-    type_: str = Field("ParentalSupport", const=True, alias='@type')
+    type_: str = Field(default="ParentalSupport", alias='@type')
     
-
-ParentalSupport.update_forward_refs()
