@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class ParkingFacility(CivicStructure):
     """A parking lot or other parking facility.
 
-    See https://schema.org/ParkingFacility.
-
+    See: https://schema.org/ParkingFacility
+    Model depth: 4
     """
-    type_: str = Field("ParkingFacility", const=True, alias='@type')
+    type_: str = Field(default="ParkingFacility", alias='@type')
     
-
-ParkingFacility.update_forward_refs()
