@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MapCategoryType import MapCategoryType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MapCategoryType import MapCategoryType
 class ParkingMap(MapCategoryType):
     """A parking map.
 
-    See https://schema.org/ParkingMap.
-
+    See: https://schema.org/ParkingMap
+    Model depth: 5
     """
-    type_: str = Field("ParkingMap", const=True, alias='@type')
+    type_: str = Field(default="ParkingMap", alias='@type')
     
-
-ParkingMap.update_forward_refs()
