@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LegalForceStatus import LegalForceStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LegalForceStatus import LegalForceStatus
 class PartiallyInForce(LegalForceStatus):
     """Indicates that parts of the legislation are in force, and parts are not.
 
-    See https://schema.org/PartiallyInForce.
-
+    See: https://schema.org/PartiallyInForce
+    Model depth: 6
     """
-    type_: str = Field("PartiallyInForce", const=True, alias='@type')
+    type_: str = Field(default="PartiallyInForce", alias='@type')
     
-
-PartiallyInForce.update_forward_refs()
