@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Store import Store
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Store import Store
 class PawnShop(Store):
     """A shop that will buy, or lend money against the security of, personal possessions.
 
-    See https://schema.org/PawnShop.
-
+    See: https://schema.org/PawnShop
+    Model depth: 5
     """
-    type_: str = Field("PawnShop", const=True, alias='@type')
+    type_: str = Field(default="PawnShop", alias='@type')
     
-
-PawnShop.update_forward_refs()
