@@ -14,7 +14,7 @@ class PaymentChargeSpecification(PriceSpecification):
     See: https://schema.org/PaymentChargeSpecification
     Model depth: 5
     """
-    type_: str = Field("PaymentChargeSpecification", alias='@type')
+    type_: str = Field(default="PaymentChargeSpecification", alias='@type')
     appliesToDeliveryMethod: Optional[Union[List[Union['DeliveryMethod', str]], 'DeliveryMethod', str]] = Field(
         default=None,
         description="The delivery method(s) to which the delivery charge or payment charge specification"
@@ -26,7 +26,6 @@ class PaymentChargeSpecification(PriceSpecification):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.DeliveryMethod import DeliveryMethod
     from pydantic_schemaorg.PaymentMethod import PaymentMethod
