@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -12,10 +15,8 @@ class PaymentMethod(Enumeration):
      "* http://purl.org/goodrelations/v1#GoogleCheckout * http://purl.org/goodrelations/v1#PayPal"
      "* http://purl.org/goodrelations/v1#PaySwarm
 
-    See https://schema.org/PaymentMethod.
-
+    See: https://schema.org/PaymentMethod
+    Model depth: 4
     """
-    type_: str = Field("PaymentMethod", const=True, alias='@type')
+    type_: str = Field(default="PaymentMethod", alias='@type')
     
-
-PaymentMethod.update_forward_refs()
