@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.StatusEnumeration import StatusEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.StatusEnumeration import StatusEnumeration
 class PaymentStatusType(StatusEnumeration):
     """A specific payment status. For example, PaymentDue, PaymentComplete, etc.
 
-    See https://schema.org/PaymentStatusType.
-
+    See: https://schema.org/PaymentStatusType
+    Model depth: 5
     """
-    type_: str = Field("PaymentStatusType", const=True, alias='@type')
+    type_: str = Field(default="PaymentStatusType", alias='@type')
     
-
-PaymentStatusType.update_forward_refs()
