@@ -1,16 +1,17 @@
+from __future__ import annotations
+
+
 from pydantic import Field
-from pydantic_schemaorg.MedicalBusiness import MedicalBusiness
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
+from pydantic_schemaorg.MedicalBusiness import MedicalBusiness
 
 
-class Pediatric(MedicalBusiness, MedicalSpecialty):
+class Pediatric(MedicalSpecialty, MedicalBusiness):
     """A specific branch of medical science that specializes in the care of infants, children"
      "and adolescents.
 
-    See https://schema.org/Pediatric.
-
+    See: https://schema.org/Pediatric
+    Model depth: 5
     """
-    type_: str = Field("Pediatric", const=True, alias='@type')
+    type_: str = Field(default="Pediatric", alias='@type')
     
-
-Pediatric.update_forward_refs()
