@@ -13,6 +13,5 @@ class PercutaneousProcedure(MedicalProcedureType):
     See: https://schema.org/PercutaneousProcedure
     Model depth: 6
     """
-    type_: str = Field("PercutaneousProcedure", alias='@type')
+    type_: str = Field(default="PercutaneousProcedure", alias='@type')
     
-
