@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class PerformingArtsTheater(CivicStructure):
     """A theater or other performing art center.
 
-    See https://schema.org/PerformingArtsTheater.
-
+    See: https://schema.org/PerformingArtsTheater
+    Model depth: 4
     """
-    type_: str = Field("PerformingArtsTheater", const=True, alias='@type')
+    type_: str = Field(default="PerformingArtsTheater", alias='@type')
     
-
-PerformingArtsTheater.update_forward_refs()
