@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Organization import Organization
 class PerformingGroup(Organization):
     """A performance group, such as a band, an orchestra, or a circus.
 
-    See https://schema.org/PerformingGroup.
-
+    See: https://schema.org/PerformingGroup
+    Model depth: 3
     """
-    type_: str = Field("PerformingGroup", const=True, alias='@type')
+    type_: str = Field(default="PerformingGroup", alias='@type')
     
-
-PerformingGroup.update_forward_refs()
