@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWorkSeries import CreativeWorkSeries
 
@@ -7,10 +10,8 @@ class Periodical(CreativeWorkSeries):
      "designations and intended, such as a magazine, scholarly journal, or newspaper to continue"
      "indefinitely. See also [blog post](http://blog.schema.org/2014/09/schemaorg-support-for-bibliographic_2.html).
 
-    See https://schema.org/Periodical.
-
+    See: https://schema.org/Periodical
+    Model depth: 4
     """
-    type_: str = Field("Periodical", const=True, alias='@type')
+    type_: str = Field(default="Periodical", alias='@type')
     
-
-Periodical.update_forward_refs()
