@@ -15,7 +15,7 @@ class Permit(Intangible):
     See: https://schema.org/Permit
     Model depth: 3
     """
-    type_: str = Field("Permit", alias='@type')
+    type_: str = Field(default="Permit", alias='@type')
     issuedThrough: Optional[Union[List[Union['Service', str]], 'Service', str]] = Field(
         default=None,
         description="The service through with the permit was granted.",
@@ -46,7 +46,6 @@ class Permit(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Service import Service
     from pydantic_schemaorg.Duration import Duration
