@@ -16,7 +16,7 @@ class Person(Thing):
     See: https://schema.org/Person
     Model depth: 2
     """
-    type_: str = Field("Person", alias='@type')
+    type_: str = Field(default="Person", alias='@type')
     contactPoint: Optional[Union[List[Union['ContactPoint', str]], 'ContactPoint', str]] = Field(
         default=None,
         description="A contact point for a person or organization.",
@@ -66,7 +66,7 @@ class Person(Thing):
      "We do not distinguish skill levels or reading/writing/speaking/signing here. Use"
      "language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47).",
     )
-    netWorth: Optional[Union[List[Union['PriceSpecification', 'MonetaryAmount', str]], 'PriceSpecification', 'MonetaryAmount', str]] = Field(
+    netWorth: Optional[Union[List[Union['MonetaryAmount', 'PriceSpecification', str]], 'MonetaryAmount', 'PriceSpecification', str]] = Field(
         default=None,
         description="The total financial value of the person as calculated by subtracting assets from liabilities.",
     )
@@ -294,7 +294,6 @@ class Person(Thing):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.ContactPoint import ContactPoint
     from pydantic_schemaorg.Text import Text
@@ -305,8 +304,8 @@ if TYPE_CHECKING:
     from pydantic_schemaorg.EducationalOrganization import EducationalOrganization
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
     from pydantic_schemaorg.Language import Language
-    from pydantic_schemaorg.PriceSpecification import PriceSpecification
     from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
+    from pydantic_schemaorg.PriceSpecification import PriceSpecification
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.CreativeWork import CreativeWork
     from pydantic_schemaorg.GenderType import GenderType
