@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 class PharmacySpecialty(MedicalSpecialty):
     """The practice or art and science of preparing and dispensing drugs and medicines.
 
-    See https://schema.org/PharmacySpecialty.
-
+    See: https://schema.org/PharmacySpecialty
+    Model depth: 6
     """
-    type_: str = Field("PharmacySpecialty", const=True, alias='@type')
+    type_: str = Field(default="PharmacySpecialty", alias='@type')
     
-
-PharmacySpecialty.update_forward_refs()
