@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class PhysicalActivityCategory(Enumeration):
     """Categories of physical activity, organized by physiologic classification.
 
-    See https://schema.org/PhysicalActivityCategory.
-
+    See: https://schema.org/PhysicalActivityCategory
+    Model depth: 4
     """
-    type_: str = Field("PhysicalActivityCategory", const=True, alias='@type')
+    type_: str = Field(default="PhysicalActivityCategory", alias='@type')
     
-
-PhysicalActivityCategory.update_forward_refs()
