@@ -1,15 +1,16 @@
+from __future__ import annotations
+
+
 from pydantic import Field
-from pydantic_schemaorg.MedicalProcedure import MedicalProcedure
 from pydantic_schemaorg.MedicalEnumeration import MedicalEnumeration
+from pydantic_schemaorg.MedicalProcedure import MedicalProcedure
 
 
-class PhysicalExam(MedicalProcedure, MedicalEnumeration):
+class PhysicalExam(MedicalEnumeration, MedicalProcedure):
     """A type of physical examination of a patient performed by a physician.
 
-    See https://schema.org/PhysicalExam.
-
+    See: https://schema.org/PhysicalExam
+    Model depth: 4
     """
-    type_: str = Field("PhysicalExam", const=True, alias='@type')
+    type_: str = Field(default="PhysicalExam", alias='@type')
     
-
-PhysicalExam.update_forward_refs()
