@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalTherapy import MedicalTherapy
 
@@ -6,10 +9,8 @@ class PhysicalTherapy(MedicalTherapy):
     """A process of progressive physical care and rehabilitation aimed at improving a health"
      "condition.
 
-    See https://schema.org/PhysicalTherapy.
-
+    See: https://schema.org/PhysicalTherapy
+    Model depth: 6
     """
-    type_: str = Field("PhysicalTherapy", const=True, alias='@type')
+    type_: str = Field(default="PhysicalTherapy", alias='@type')
     
-
-PhysicalTherapy.update_forward_refs()
