@@ -15,7 +15,7 @@ class Physician(MedicalBusiness, MedicalOrganization):
     See: https://schema.org/Physician
     Model depth: 4
     """
-    type_: str = Field("Physician", alias='@type')
+    type_: str = Field(default="Physician", alias='@type')
     medicalSpecialty: Optional[Union[List[Union['MedicalSpecialty', str]], 'MedicalSpecialty', str]] = Field(
         default=None,
         description="A medical specialty of the provider.",
@@ -24,16 +24,15 @@ class Physician(MedicalBusiness, MedicalOrganization):
         default=None,
         description="A hospital with which the physician or office is affiliated.",
     )
-    availableService: Optional[Union[List[Union['MedicalTest', 'MedicalProcedure', 'MedicalTherapy', str]], 'MedicalTest', 'MedicalProcedure', 'MedicalTherapy', str]] = Field(
+    availableService: Optional[Union[List[Union['MedicalTest', 'MedicalTherapy', 'MedicalProcedure', str]], 'MedicalTest', 'MedicalTherapy', 'MedicalProcedure', str]] = Field(
         default=None,
         description="A medical service available from this provider.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
     from pydantic_schemaorg.Hospital import Hospital
     from pydantic_schemaorg.MedicalTest import MedicalTest
-    from pydantic_schemaorg.MedicalProcedure import MedicalProcedure
     from pydantic_schemaorg.MedicalTherapy import MedicalTherapy
+    from pydantic_schemaorg.MedicalProcedure import MedicalProcedure
