@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class PlaceOfWorship(CivicStructure):
     """Place of worship, such as a church, synagogue, or mosque.
 
-    See https://schema.org/PlaceOfWorship.
-
+    See: https://schema.org/PlaceOfWorship
+    Model depth: 4
     """
-    type_: str = Field("PlaceOfWorship", const=True, alias='@type')
+    type_: str = Field(default="PlaceOfWorship", alias='@type')
     
-
-PlaceOfWorship.update_forward_refs()
