@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 class PlaceboControlledTrial(MedicalTrialDesign):
     """A placebo-controlled trial design.
 
-    See https://schema.org/PlaceboControlledTrial.
-
+    See: https://schema.org/PlaceboControlledTrial
+    Model depth: 6
     """
-    type_: str = Field("PlaceboControlledTrial", const=True, alias='@type')
+    type_: str = Field(default="PlaceboControlledTrial", alias='@type')
     
-
-PlaceboControlledTrial.update_forward_refs()
