@@ -16,13 +16,12 @@ class PlanAction(OrganizeAction):
     See: https://schema.org/PlanAction
     Model depth: 4
     """
-    type_: str = Field("PlanAction", alias='@type')
+    type_: str = Field(default="PlanAction", alias='@type')
     scheduledTime: Optional[Union[List[Union[ISO8601Date, 'DateTime', str]], ISO8601Date, 'DateTime', str]] = Field(
         default=None,
         description="The time the object is scheduled to.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.DateTime import DateTime
