@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class Playground(CivicStructure):
     """A playground.
 
-    See https://schema.org/Playground.
-
+    See: https://schema.org/Playground
+    Model depth: 4
     """
-    type_: str = Field("Playground", const=True, alias='@type')
+    type_: str = Field(default="Playground", alias='@type')
     
-
-Playground.update_forward_refs()
