@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Episode import Episode
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Episode import Episode
 class PodcastEpisode(Episode):
     """A single episode of a podcast series.
 
-    See https://schema.org/PodcastEpisode.
-
+    See: https://schema.org/PodcastEpisode
+    Model depth: 4
     """
-    type_: str = Field("PodcastEpisode", const=True, alias='@type')
+    type_: str = Field(default="PodcastEpisode", alias='@type')
     
-
-PodcastEpisode.update_forward_refs()
