@@ -1,16 +1,17 @@
+from __future__ import annotations
+
+
 from pydantic import Field
-from pydantic_schemaorg.MedicalBusiness import MedicalBusiness
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
+from pydantic_schemaorg.MedicalBusiness import MedicalBusiness
 
 
-class Podiatric(MedicalBusiness, MedicalSpecialty):
+class Podiatric(MedicalSpecialty, MedicalBusiness):
     """Podiatry is the care of the human foot, especially the diagnosis and treatment of foot"
      "disorders.
 
-    See https://schema.org/Podiatric.
-
+    See: https://schema.org/Podiatric
+    Model depth: 5
     """
-    type_: str = Field("Podiatric", const=True, alias='@type')
+    type_: str = Field(default="Podiatric", alias='@type')
     
-
-Podiatric.update_forward_refs()
