@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.GovernmentOffice import GovernmentOffice
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.GovernmentOffice import GovernmentOffice
 class PostOffice(GovernmentOffice):
     """A post office.
 
-    See https://schema.org/PostOffice.
-
+    See: https://schema.org/PostOffice
+    Model depth: 5
     """
-    type_: str = Field("PostOffice", const=True, alias='@type')
+    type_: str = Field(default="PostOffice", alias='@type')
     
-
-PostOffice.update_forward_refs()
