@@ -14,7 +14,7 @@ class PostalAddress(ContactPoint):
     See: https://schema.org/PostalAddress
     Model depth: 5
     """
-    type_: str = Field("PostalAddress", alias='@type')
+    type_: str = Field(default="PostalAddress", alias='@type')
     postalCode: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The postal code. For example, 94043.",
@@ -44,7 +44,6 @@ class PostalAddress(ContactPoint):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Country import Country
