@@ -15,7 +15,7 @@ class PostalCodeRangeSpecification(StructuredValue):
     See: https://schema.org/PostalCodeRangeSpecification
     Model depth: 4
     """
-    type_: str = Field("PostalCodeRangeSpecification", alias='@type')
+    type_: str = Field(default="PostalCodeRangeSpecification", alias='@type')
     postalCodeEnd: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Last postal code in the range (included). Needs to be after [[postalCodeBegin]].",
@@ -26,6 +26,5 @@ class PostalCodeRangeSpecification(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
