@@ -11,6 +11,5 @@ class PotentialActionStatus(ActionStatusType):
     See: https://schema.org/PotentialActionStatus
     Model depth: 6
     """
-    type_: str = Field("PotentialActionStatus", alias='@type')
+    type_: str = Field(default="PotentialActionStatus", alias='@type')
     
-
