@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DrugPrescriptionStatus import DrugPrescriptionStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DrugPrescriptionStatus import DrugPrescriptionStatus
 class PrescriptionOnly(DrugPrescriptionStatus):
     """Available by prescription only.
 
-    See https://schema.org/PrescriptionOnly.
-
+    See: https://schema.org/PrescriptionOnly
+    Model depth: 6
     """
-    type_: str = Field("PrescriptionOnly", const=True, alias='@type')
+    type_: str = Field(default="PrescriptionOnly", alias='@type')
     
-
-PrescriptionOnly.update_forward_refs()
