@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DigitalDocument import DigitalDocument
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DigitalDocument import DigitalDocument
 class PresentationDigitalDocument(DigitalDocument):
     """A file containing slides or used for a presentation.
 
-    See https://schema.org/PresentationDigitalDocument.
-
+    See: https://schema.org/PresentationDigitalDocument
+    Model depth: 4
     """
-    type_: str = Field("PresentationDigitalDocument", const=True, alias='@type')
+    type_: str = Field(default="PresentationDigitalDocument", alias='@type')
     
-
-PresentationDigitalDocument.update_forward_refs()
