@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class PriceTypeEnumeration(Enumeration):
     """Enumerates different price types, for example list price, invoice price, and sale price.
 
-    See https://schema.org/PriceTypeEnumeration.
-
+    See: https://schema.org/PriceTypeEnumeration
+    Model depth: 4
     """
-    type_: str = Field("PriceTypeEnumeration", const=True, alias='@type')
+    type_: str = Field(default="PriceTypeEnumeration", alias='@type')
     
-
-PriceTypeEnumeration.update_forward_refs()
