@@ -13,6 +13,5 @@ class PrimaryCare(MedicalSpecialty, MedicalBusiness):
     See: https://schema.org/PrimaryCare
     Model depth: 5
     """
-    type_: str = Field("PrimaryCare", alias='@type')
+    type_: str = Field(default="PrimaryCare", alias='@type')
     
-
