@@ -17,7 +17,7 @@ class Product(Thing):
     See: https://schema.org/Product
     Model depth: 2
     """
-    type_: str = Field("Product", alias='@type')
+    type_: str = Field(default="Product", alias='@type')
     pattern: Optional[Union[List[Union[str, 'Text', 'DefinedTerm']], str, 'Text', 'DefinedTerm']] = Field(
         default=None,
         description="A pattern that something has, for example 'polka dot', 'striped', 'Canadian flag'."
@@ -30,7 +30,7 @@ class Product(Thing):
      "the gauge of a screw. Usually an exact measurement, but can also be a range of measurements"
      "for adjustable products, for example belts and ski bindings.",
     )
-    offers: Optional[Union[List[Union['Demand', 'Offer', str]], 'Demand', 'Offer', str]] = Field(
+    offers: Optional[Union[List[Union['Offer', 'Demand', str]], 'Offer', 'Demand', str]] = Field(
         default=None,
         description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the"
      "DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]]"
@@ -117,7 +117,7 @@ class Product(Thing):
         description="The brand(s) associated with a product or service, or the brand(s) maintained by an organization"
      "or business person.",
     )
-    category: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text', 'Thing', 'PhysicalActivityCategory']], AnyUrl, 'URL', str, 'Text', 'Thing', 'PhysicalActivityCategory']] = Field(
+    category: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text', 'PhysicalActivityCategory', 'Thing']], AnyUrl, 'URL', str, 'Text', 'PhysicalActivityCategory', 'Thing']] = Field(
         default=None,
         description="A category for the item. Greater signs or slashes can be used to informally indicate a"
      "category hierarchy.",
@@ -135,7 +135,7 @@ class Product(Thing):
         default=None,
         description="A slogan or motto associated with the item.",
     )
-    isSimilarTo: Optional[Union[List[Union['Product', 'Service', str]], 'Product', 'Service', str]] = Field(
+    isSimilarTo: Optional[Union[List[Union['Service', 'Product', str]], 'Service', 'Product', str]] = Field(
         default=None,
         description="A pointer to another, functionally similar product (or multiple products).",
     )
@@ -143,7 +143,7 @@ class Product(Thing):
         default=None,
         description="The height of the item.",
     )
-    size: Optional[Union[List[Union[str, 'Text', 'SizeSpecification', 'DefinedTerm', 'QuantitativeValue']], str, 'Text', 'SizeSpecification', 'DefinedTerm', 'QuantitativeValue']] = Field(
+    size: Optional[Union[List[Union[str, 'Text', 'QuantitativeValue', 'SizeSpecification', 'DefinedTerm']], str, 'Text', 'QuantitativeValue', 'SizeSpecification', 'DefinedTerm']] = Field(
         default=None,
         description="A standardized size of a product or creative work, specified either through a simple"
      "textual string (for example 'XL', '32Wx34L'), a QuantitativeValue with a unitCode,"
@@ -196,7 +196,7 @@ class Product(Thing):
         default=None,
         description="A material that something is made from, e.g. leather, wool, cotton, paper.",
     )
-    isRelatedTo: Optional[Union[List[Union['Product', 'Service', str]], 'Product', 'Service', str]] = Field(
+    isRelatedTo: Optional[Union[List[Union['Service', 'Product', str]], 'Service', 'Product', str]] = Field(
         default=None,
         description="A pointer to another, somehow related product (or multiple products).",
     )
@@ -270,13 +270,12 @@ class Product(Thing):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.DefinedTerm import DefinedTerm
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
-    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.Offer import Offer
+    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.ProductModel import ProductModel
     from pydantic_schemaorg.Distance import Distance
     from pydantic_schemaorg.Date import Date
@@ -285,8 +284,8 @@ if TYPE_CHECKING:
     from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.Brand import Brand
     from pydantic_schemaorg.URL import URL
-    from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
+    from pydantic_schemaorg.Thing import Thing
     from pydantic_schemaorg.MerchantReturnPolicy import MerchantReturnPolicy
     from pydantic_schemaorg.EnergyConsumptionDetails import EnergyConsumptionDetails
     from pydantic_schemaorg.Service import Service
