@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -11,10 +14,8 @@ class ProfessionalService(LocalBusiness):
      "[[RoofingContractor]]. [[LegalService]] was introduced as a more inclusive supertype"
      "of [[Attorney]].
 
-    See https://schema.org/ProfessionalService.
-
+    See: https://schema.org/ProfessionalService
+    Model depth: 4
     """
-    type_: str = Field("ProfessionalService", const=True, alias='@type')
+    type_: str = Field(default="ProfessionalService", alias='@type')
     
-
-ProfessionalService.update_forward_refs()
