@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WebPage import WebPage
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WebPage import WebPage
 class ProfilePage(WebPage):
     """Web page type: Profile page.
 
-    See https://schema.org/ProfilePage.
-
+    See: https://schema.org/ProfilePage
+    Model depth: 4
     """
-    type_: str = Field("ProfilePage", const=True, alias='@type')
+    type_: str = Field(default="ProfilePage", alias='@type')
     
-
-ProfilePage.update_forward_refs()
