@@ -16,7 +16,7 @@ class ProgramMembership(Intangible):
     See: https://schema.org/ProgramMembership
     Model depth: 3
     """
-    type_: str = Field("ProgramMembership", alias='@type')
+    type_: str = Field(default="ProgramMembership", alias='@type')
     membershipNumber: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="A unique identifier for the membership.",
@@ -45,7 +45,6 @@ class ProgramMembership(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Number import Number
