@@ -20,7 +20,7 @@ class PropertyValue(StructuredValue):
     See: https://schema.org/PropertyValue
     Model depth: 4
     """
-    type_: str = Field("PropertyValue", alias='@type')
+    type_: str = Field(default="PropertyValue", alias='@type')
     measurementTechnique: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text']], AnyUrl, 'URL', str, 'Text']] = Field(
         default=None,
         description="A technique or technology used in a [[Dataset]] (or [[DataDownload]], [[DataCatalog]]),"
@@ -73,22 +73,21 @@ class PropertyValue(StructuredValue):
         default=None,
         description="The upper value of some characteristic or property.",
     )
-    valueReference: Optional[Union[List[Union[str, 'Text', 'PropertyValue', 'StructuredValue', 'Enumeration', 'QualitativeValue', 'DefinedTerm', 'MeasurementTypeEnumeration', 'QuantitativeValue']], str, 'Text', 'PropertyValue', 'StructuredValue', 'Enumeration', 'QualitativeValue', 'DefinedTerm', 'MeasurementTypeEnumeration', 'QuantitativeValue']] = Field(
+    valueReference: Optional[Union[List[Union[str, 'Text', 'PropertyValue', 'DefinedTerm', 'QualitativeValue', 'Enumeration', 'MeasurementTypeEnumeration', 'QuantitativeValue', 'StructuredValue']], str, 'Text', 'PropertyValue', 'DefinedTerm', 'QualitativeValue', 'Enumeration', 'MeasurementTypeEnumeration', 'QuantitativeValue', 'StructuredValue']] = Field(
         default=None,
         description="A secondary value that provides additional information on the original value, e.g."
      "a reference temperature or a type of measurement.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.Boolean import Boolean
     from pydantic_schemaorg.StructuredValue import StructuredValue
-    from pydantic_schemaorg.Enumeration import Enumeration
-    from pydantic_schemaorg.QualitativeValue import QualitativeValue
     from pydantic_schemaorg.DefinedTerm import DefinedTerm
+    from pydantic_schemaorg.QualitativeValue import QualitativeValue
+    from pydantic_schemaorg.Enumeration import Enumeration
     from pydantic_schemaorg.MeasurementTypeEnumeration import MeasurementTypeEnumeration
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
