@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.InfectiousAgentClass import InfectiousAgentClass
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.InfectiousAgentClass import InfectiousAgentClass
 class Protozoa(InfectiousAgentClass):
     """Single-celled organism that causes an infection.
 
-    See https://schema.org/Protozoa.
-
+    See: https://schema.org/Protozoa
+    Model depth: 6
     """
-    type_: str = Field("Protozoa", const=True, alias='@type')
+    type_: str = Field(default="Protozoa", alias='@type')
     
-
-Protozoa.update_forward_refs()
