@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DayOfWeek import DayOfWeek
 
@@ -9,10 +12,8 @@ class PublicHolidays(DayOfWeek):
      "specification it can be used to indicate opening hours on public holidays, overriding"
      "general opening hours for the day of the week on which a public holiday occurs.
 
-    See https://schema.org/PublicHolidays.
-
+    See: https://schema.org/PublicHolidays
+    Model depth: 5
     """
-    type_: str = Field("PublicHolidays", const=True, alias='@type')
+    type_: str = Field(default="PublicHolidays", alias='@type')
     
-
-PublicHolidays.update_forward_refs()
