@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 class PublicSwimmingPool(SportsActivityLocation):
     """A public swimming pool.
 
-    See https://schema.org/PublicSwimmingPool.
-
+    See: https://schema.org/PublicSwimmingPool
+    Model depth: 5
     """
-    type_: str = Field("PublicSwimmingPool", const=True, alias='@type')
+    type_: str = Field(default="PublicSwimmingPool", alias='@type')
     
-
-PublicSwimmingPool.update_forward_refs()
