@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -7,10 +10,8 @@ class PublicToilet(CivicStructure):
      "also urinals) which is available for use by the general public, or by customers or employees"
      "of certain businesses.
 
-    See https://schema.org/PublicToilet.
-
+    See: https://schema.org/PublicToilet
+    Model depth: 4
     """
-    type_: str = Field("PublicToilet", const=True, alias='@type')
+    type_: str = Field(default="PublicToilet", alias='@type')
     
-
-PublicToilet.update_forward_refs()
