@@ -15,7 +15,7 @@ class PublicationVolume(CreativeWork):
     See: https://schema.org/PublicationVolume
     Model depth: 3
     """
-    type_: str = Field("PublicationVolume", alias='@type')
+    type_: str = Field(default="PublicationVolume", alias='@type')
     pageStart: Optional[Union[List[Union[int, 'Integer', str, 'Text']], int, 'Integer', str, 'Text']] = Field(
         default=None,
         description="The page on which the work starts; for example \"135\" or \"xiii\".",
@@ -35,7 +35,6 @@ class PublicationVolume(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Integer import Integer
     from pydantic_schemaorg.Text import Text
