@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LearningResource import LearningResource
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LearningResource import LearningResource
 class Quiz(LearningResource):
     """Quiz: A test of knowledge, skills and abilities.
 
-    See https://schema.org/Quiz.
-
+    See: https://schema.org/Quiz
+    Model depth: 4
     """
-    type_: str = Field("Quiz", const=True, alias='@type')
+    type_: str = Field(default="Quiz", alias='@type')
     
-
-Quiz.update_forward_refs()
