@@ -17,7 +17,7 @@ class Quotation(CreativeWork):
     See: https://schema.org/Quotation
     Model depth: 3
     """
-    type_: str = Field("Quotation", alias='@type')
+    type_: str = Field(default="Quotation", alias='@type')
     spokenByCharacter: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="The (e.g. fictional) character, Person or Organization to whom the quotation is attributed"
@@ -25,7 +25,6 @@ class Quotation(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
