@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -6,10 +9,8 @@ class RVPark(CivicStructure):
     """A place offering space for \"Recreational Vehicles\", Caravans, mobile homes and the"
      "like.
 
-    See https://schema.org/RVPark.
-
+    See: https://schema.org/RVPark
+    Model depth: 4
     """
-    type_: str = Field("RVPark", const=True, alias='@type')
+    type_: str = Field(default="RVPark", alias='@type')
     
-
-RVPark.update_forward_refs()
