@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalTherapy import MedicalTherapy
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalTherapy import MedicalTherapy
 class RadiationTherapy(MedicalTherapy):
     """A process of care using radiation aimed at improving a health condition.
 
-    See https://schema.org/RadiationTherapy.
-
+    See: https://schema.org/RadiationTherapy
+    Model depth: 6
     """
-    type_: str = Field("RadiationTherapy", const=True, alias='@type')
+    type_: str = Field(default="RadiationTherapy", alias='@type')
     
-
-RadiationTherapy.update_forward_refs()
