@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Clip import Clip
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Clip import Clip
 class RadioClip(Clip):
     """A short radio program or a segment/part of a radio program.
 
-    See https://schema.org/RadioClip.
-
+    See: https://schema.org/RadioClip
+    Model depth: 4
     """
-    type_: str = Field("RadioClip", const=True, alias='@type')
+    type_: str = Field(default="RadioClip", alias='@type')
     
-
-RadioClip.update_forward_refs()
