@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWorkSeason import CreativeWorkSeason
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CreativeWorkSeason import CreativeWorkSeason
 class RadioSeason(CreativeWorkSeason):
     """Season dedicated to radio broadcast and associated online delivery.
 
-    See https://schema.org/RadioSeason.
-
+    See: https://schema.org/RadioSeason
+    Model depth: 4
     """
-    type_: str = Field("RadioSeason", const=True, alias='@type')
+    type_: str = Field(default="RadioSeason", alias='@type')
     
-
-RadioSeason.update_forward_refs()
