@@ -15,7 +15,7 @@ class RadioSeries(CreativeWorkSeries):
     See: https://schema.org/RadioSeries
     Model depth: 4
     """
-    type_: str = Field("RadioSeries", alias='@type')
+    type_: str = Field(default="RadioSeries", alias='@type')
     actors: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="An actor, e.g. in tv, radio, movie, video games etc. Actors can be associated with individual"
@@ -79,7 +79,6 @@ class RadioSeries(CreativeWorkSeries):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.CreativeWorkSeason import CreativeWorkSeason
