@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalTrialDesign import MedicalTrialDesign
 class RandomizedTrial(MedicalTrialDesign):
     """A randomized trial design.
 
-    See https://schema.org/RandomizedTrial.
-
+    See: https://schema.org/RandomizedTrial
+    Model depth: 6
     """
-    type_: str = Field("RandomizedTrial", const=True, alias='@type')
+    type_: str = Field(default="RandomizedTrial", alias='@type')
     
-
-RandomizedTrial.update_forward_refs()
