@@ -15,7 +15,7 @@ class Rating(Intangible):
     See: https://schema.org/Rating
     Model depth: 3
     """
-    type_: str = Field("Rating", alias='@type')
+    type_: str = Field(default="Rating", alias='@type')
     worstRating: Optional[Union[List[Union[Decimal, 'Number', str, 'Text']], Decimal, 'Number', str, 'Text']] = Field(
         default=None,
         description="The lowest value allowed in this rating system. If worstRating is omitted, 1 is assumed.",
@@ -49,7 +49,6 @@ class Rating(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.Text import Text
