@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AssessAction import AssessAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AssessAction import AssessAction
 class ReactAction(AssessAction):
     """The act of responding instinctively and emotionally to an object, expressing a sentiment.
 
-    See https://schema.org/ReactAction.
-
+    See: https://schema.org/ReactAction
+    Model depth: 4
     """
-    type_: str = Field("ReactAction", const=True, alias='@type')
+    type_: str = Field(default="ReactAction", alias='@type')
     
-
-ReactAction.update_forward_refs()
