@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ConsumeAction import ConsumeAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ConsumeAction import ConsumeAction
 class ReadAction(ConsumeAction):
     """The act of consuming written content.
 
-    See https://schema.org/ReadAction.
-
+    See: https://schema.org/ReadAction
+    Model depth: 4
     """
-    type_: str = Field("ReadAction", const=True, alias='@type')
+    type_: str = Field(default="ReadAction", alias='@type')
     
-
-ReadAction.update_forward_refs()
