@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DigitalDocumentPermissionType import DigitalDocumentPermissionType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DigitalDocumentPermissionType import DigitalDocumentPerm
 class ReadPermission(DigitalDocumentPermissionType):
     """Permission to read or view the document.
 
-    See https://schema.org/ReadPermission.
-
+    See: https://schema.org/ReadPermission
+    Model depth: 5
     """
-    type_: str = Field("ReadPermission", const=True, alias='@type')
+    type_: str = Field(default="ReadPermission", alias='@type')
     
-
-ReadPermission.update_forward_refs()
