@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class RealEstateAgent(LocalBusiness):
     """A real-estate agent.
 
-    See https://schema.org/RealEstateAgent.
-
+    See: https://schema.org/RealEstateAgent
+    Model depth: 4
     """
-    type_: str = Field("RealEstateAgent", const=True, alias='@type')
+    type_: str = Field(default="RealEstateAgent", alias='@type')
     
-
-RealEstateAgent.update_forward_refs()
