@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DriveWheelConfigurationValue import DriveWheelConfigurationValue
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DriveWheelConfigurationValue import DriveWheelConfigurat
 class RearWheelDriveConfiguration(DriveWheelConfigurationValue):
     """Real-wheel drive is a transmission layout where the engine drives the rear wheels.
 
-    See https://schema.org/RearWheelDriveConfiguration.
-
+    See: https://schema.org/RearWheelDriveConfiguration
+    Model depth: 6
     """
-    type_: str = Field("RearWheelDriveConfiguration", const=True, alias='@type')
+    type_: str = Field(default="RearWheelDriveConfiguration", alias='@type')
     
-
-RearWheelDriveConfiguration.update_forward_refs()
