@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.OfferItemCondition import OfferItemCondition
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.OfferItemCondition import OfferItemCondition
 class RefurbishedCondition(OfferItemCondition):
     """Indicates that the item is refurbished.
 
-    See https://schema.org/RefurbishedCondition.
-
+    See: https://schema.org/RefurbishedCondition
+    Model depth: 5
     """
-    type_: str = Field("RefurbishedCondition", const=True, alias='@type')
+    type_: str = Field(default="RefurbishedCondition", alias='@type')
     
-
-RefurbishedCondition.update_forward_refs()
