@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.InteractAction import InteractAction
 
@@ -10,10 +13,8 @@ class RegisterAction(InteractAction):
      "object. * [[SubscribeAction]]: Unlike SubscribeAction, RegisterAction doesn't"
      "imply that the agent is expecting updates from the object.
 
-    See https://schema.org/RegisterAction.
-
+    See: https://schema.org/RegisterAction
+    Model depth: 4
     """
-    type_: str = Field("RegisterAction", const=True, alias='@type')
+    type_: str = Field(default="RegisterAction", alias='@type')
     
-
-RegisterAction.update_forward_refs()
