@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AllocateAction import AllocateAction
 
@@ -6,10 +9,8 @@ class RejectAction(AllocateAction):
     """The act of rejecting to/adopting an object. Related actions: * [[AcceptAction]]: The"
      "antonym of RejectAction.
 
-    See https://schema.org/RejectAction.
-
+    See: https://schema.org/RejectAction
+    Model depth: 5
     """
-    type_: str = Field("RejectAction", const=True, alias='@type')
+    type_: str = Field(default="RejectAction", alias='@type')
     
-
-RejectAction.update_forward_refs()
