@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -6,10 +9,8 @@ class Renal(MedicalSpecialty):
     """A specific branch of medical science that pertains to the study of the kidneys and its"
      "respective disease states.
 
-    See https://schema.org/Renal.
-
+    See: https://schema.org/Renal
+    Model depth: 6
     """
-    type_: str = Field("Renal", const=True, alias='@type')
+    type_: str = Field(default="Renal", alias='@type')
     
-
-Renal.update_forward_refs()
