@@ -16,7 +16,7 @@ class RentAction(TradeAction):
     See: https://schema.org/RentAction
     Model depth: 4
     """
-    type_: str = Field("RentAction", alias='@type')
+    type_: str = Field(default="RentAction", alias='@type')
     landlord: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="A sub property of participant. The owner of the real estate property.",
@@ -27,7 +27,6 @@ class RentAction(TradeAction):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
