@@ -16,7 +16,7 @@ class RentalCarReservation(Reservation):
     See: https://schema.org/RentalCarReservation
     Model depth: 4
     """
-    type_: str = Field("RentalCarReservation", alias='@type')
+    type_: str = Field(default="RentalCarReservation", alias='@type')
     pickupLocation: Optional[Union[List[Union['Place', str]], 'Place', str]] = Field(
         default=None,
         description="Where a taxi will pick up a passenger or a rental car can be picked up.",
@@ -35,7 +35,6 @@ class RentalCarReservation(Reservation):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Place import Place
     from pydantic_schemaorg.DateTime import DateTime
