@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CarUsageType import CarUsageType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CarUsageType import CarUsageType
 class RentalVehicleUsage(CarUsageType):
     """Indicates the usage of the vehicle as a rental car.
 
-    See https://schema.org/RentalVehicleUsage.
-
+    See: https://schema.org/RentalVehicleUsage
+    Model depth: 5
     """
-    type_: str = Field("RentalVehicleUsage", const=True, alias='@type')
+    type_: str = Field(default="RentalVehicleUsage", alias='@type')
     
-
-RentalVehicleUsage.update_forward_refs()
