@@ -15,7 +15,7 @@ class RepaymentSpecification(StructuredValue):
     See: https://schema.org/RepaymentSpecification
     Model depth: 4
     """
-    type_: str = Field("RepaymentSpecification", alias='@type')
+    type_: str = Field(default="RepaymentSpecification", alias='@type')
     loanPaymentAmount: Optional[Union[List[Union['MonetaryAmount', str]], 'MonetaryAmount', str]] = Field(
         default=None,
         description="The amount of money to pay in a single payment.",
@@ -42,7 +42,6 @@ class RepaymentSpecification(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.MonetaryAmount import MonetaryAmount
     from pydantic_schemaorg.Number import Number
