@@ -15,13 +15,12 @@ class ReplyAction(CommunicateAction):
     See: https://schema.org/ReplyAction
     Model depth: 5
     """
-    type_: str = Field("ReplyAction", alias='@type')
+    type_: str = Field(default="ReplyAction", alias='@type')
     resultComment: Optional[Union[List[Union['Comment', str]], 'Comment', str]] = Field(
         default=None,
         description="A sub property of result. The Comment created or sent as a result of this action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Comment import Comment
