@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DoseSchedule import DoseSchedule
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DoseSchedule import DoseSchedule
 class ReportedDoseSchedule(DoseSchedule):
     """A patient-reported or observed dosing schedule for a drug or supplement.
 
-    See https://schema.org/ReportedDoseSchedule.
-
+    See: https://schema.org/ReportedDoseSchedule
+    Model depth: 5
     """
-    type_: str = Field("ReportedDoseSchedule", const=True, alias='@type')
+    type_: str = Field(default="ReportedDoseSchedule", alias='@type')
     
-
-ReportedDoseSchedule.update_forward_refs()
