@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Organization import Organization
 class ResearchOrganization(Organization):
     """A Research Organization (e.g. scientific institute, research company).
 
-    See https://schema.org/ResearchOrganization.
-
+    See: https://schema.org/ResearchOrganization
+    Model depth: 3
     """
-    type_: str = Field("ResearchOrganization", const=True, alias='@type')
+    type_: str = Field(default="ResearchOrganization", alias='@type')
     
-
-ResearchOrganization.update_forward_refs()
