@@ -11,6 +11,5 @@ class ResearchProject(Project):
     See: https://schema.org/ResearchProject
     Model depth: 4
     """
-    type_: str = Field("ResearchProject", alias='@type')
+    type_: str = Field(default="ResearchProject", alias='@type')
     
-
