@@ -19,7 +19,7 @@ class Reservation(Intangible):
     See: https://schema.org/Reservation
     Model depth: 3
     """
-    type_: str = Field("Reservation", alias='@type')
+    type_: str = Field(default="Reservation", alias='@type')
     reservationId: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="A unique identifier for the reservation.",
@@ -88,7 +88,6 @@ class Reservation(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.ProgramMembership import ProgramMembership
