@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReservationStatusType import ReservationStatusType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReservationStatusType import ReservationStatusType
 class ReservationConfirmed(ReservationStatusType):
     """The status of a confirmed reservation.
 
-    See https://schema.org/ReservationConfirmed.
-
+    See: https://schema.org/ReservationConfirmed
+    Model depth: 6
     """
-    type_: str = Field("ReservationConfirmed", const=True, alias='@type')
+    type_: str = Field(default="ReservationConfirmed", alias='@type')
     
-
-ReservationConfirmed.update_forward_refs()
