@@ -12,6 +12,5 @@ class ReservationHold(ReservationStatusType):
     See: https://schema.org/ReservationHold
     Model depth: 6
     """
-    type_: str = Field("ReservationHold", alias='@type')
+    type_: str = Field(default="ReservationHold", alias='@type')
     
-
