@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.StatusEnumeration import StatusEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.StatusEnumeration import StatusEnumeration
 class ReservationStatusType(StatusEnumeration):
     """Enumerated status values for Reservation.
 
-    See https://schema.org/ReservationStatusType.
-
+    See: https://schema.org/ReservationStatusType
+    Model depth: 5
     """
-    type_: str = Field("ReservationStatusType", const=True, alias='@type')
+    type_: str = Field(default="ReservationStatusType", alias='@type')
     
-
-ReservationStatusType.update_forward_refs()
