@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.BodyOfWater import BodyOfWater
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.BodyOfWater import BodyOfWater
 class Reservoir(BodyOfWater):
     """A reservoir of water, typically an artificially created lake, like the Lake Kariba reservoir.
 
-    See https://schema.org/Reservoir.
-
+    See: https://schema.org/Reservoir
+    Model depth: 5
     """
-    type_: str = Field("Reservoir", const=True, alias='@type')
+    type_: str = Field(default="Reservoir", alias='@type')
     
-
-Reservoir.update_forward_refs()
