@@ -14,13 +14,12 @@ class Residence(Place):
     See: https://schema.org/Residence
     Model depth: 3
     """
-    type_: str = Field("Residence", alias='@type')
+    type_: str = Field(default="Residence", alias='@type')
     accommodationFloorPlan: Optional[Union[List[Union['FloorPlan', str]], 'FloorPlan', str]] = Field(
         default=None,
         description="A floorplan of some [[Accommodation]].",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.FloorPlan import FloorPlan
