@@ -13,6 +13,5 @@ class RespiratoryTherapy(MedicalSpecialty, MedicalTherapy):
     See: https://schema.org/RespiratoryTherapy
     Model depth: 6
     """
-    type_: str = Field("RespiratoryTherapy", alias='@type')
+    type_: str = Field(default="RespiratoryTherapy", alias='@type')
     
-
