@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 class Restaurant(FoodEstablishment):
     """A restaurant.
 
-    See https://schema.org/Restaurant.
-
+    See: https://schema.org/Restaurant
+    Model depth: 5
     """
-    type_: str = Field("Restaurant", const=True, alias='@type')
+    type_: str = Field(default="Restaurant", alias='@type')
     
-
-Restaurant.update_forward_refs()
