@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReturnFeesEnumeration import ReturnFeesEnumeration
 class RestockingFees(ReturnFeesEnumeration):
     """Specifies that the customer must pay a restocking fee when returning a product
 
-    See https://schema.org/RestockingFees.
-
+    See: https://schema.org/RestockingFees
+    Model depth: 5
     """
-    type_: str = Field("RestockingFees", const=True, alias='@type')
+    type_: str = Field(default="RestockingFees", alias='@type')
     
-
-RestockingFees.update_forward_refs()
