@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 class ResultsAvailable(MedicalStudyStatus):
     """Results are available.
 
-    See https://schema.org/ResultsAvailable.
-
+    See: https://schema.org/ResultsAvailable
+    Model depth: 6
     """
-    type_: str = Field("ResultsAvailable", const=True, alias='@type')
+    type_: str = Field(default="ResultsAvailable", alias='@type')
     
-
-ResultsAvailable.update_forward_refs()
