@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 class ResultsNotAvailable(MedicalStudyStatus):
     """Results are not available.
 
-    See https://schema.org/ResultsNotAvailable.
-
+    See: https://schema.org/ResultsNotAvailable
+    Model depth: 6
     """
-    type_: str = Field("ResultsNotAvailable", const=True, alias='@type')
+    type_: str = Field(default="ResultsNotAvailable", alias='@type')
     
-
-ResultsNotAvailable.update_forward_refs()
