@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration
 class ReturnAtKiosk(ReturnMethodEnumeration):
     """Specifies that product returns must be made at a kiosk.
 
-    See https://schema.org/ReturnAtKiosk.
-
+    See: https://schema.org/ReturnAtKiosk
+    Model depth: 5
     """
-    type_: str = Field("ReturnAtKiosk", const=True, alias='@type')
+    type_: str = Field(default="ReturnAtKiosk", alias='@type')
     
-
-ReturnAtKiosk.update_forward_refs()
