@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class ReturnFeesEnumeration(Enumeration):
     """Enumerates several kinds of policies for product return fees.
 
-    See https://schema.org/ReturnFeesEnumeration.
-
+    See: https://schema.org/ReturnFeesEnumeration
+    Model depth: 4
     """
-    type_: str = Field("ReturnFeesEnumeration", const=True, alias='@type')
+    type_: str = Field(default="ReturnFeesEnumeration", alias='@type')
     
-
-ReturnFeesEnumeration.update_forward_refs()
