@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReturnMethodEnumeration import ReturnMethodEnumeration
 class ReturnInStore(ReturnMethodEnumeration):
     """Specifies that product returns must be made in a store.
 
-    See https://schema.org/ReturnInStore.
-
+    See: https://schema.org/ReturnInStore
+    Model depth: 5
     """
-    type_: str = Field("ReturnInStore", const=True, alias='@type')
+    type_: str = Field(default="ReturnInStore", alias='@type')
     
-
-ReturnInStore.update_forward_refs()
