@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReturnLabelSourceEnumeration import ReturnLabelSourceEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReturnLabelSourceEnumeration import ReturnLabelSourceEnu
 class ReturnLabelCustomerResponsibility(ReturnLabelSourceEnumeration):
     """Indicated that creating a return label is the responsibility of the customer.
 
-    See https://schema.org/ReturnLabelCustomerResponsibility.
-
+    See: https://schema.org/ReturnLabelCustomerResponsibility
+    Model depth: 5
     """
-    type_: str = Field("ReturnLabelCustomerResponsibility", const=True, alias='@type')
+    type_: str = Field(default="ReturnLabelCustomerResponsibility", alias='@type')
     
-
-ReturnLabelCustomerResponsibility.update_forward_refs()
