@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReturnLabelSourceEnumeration import ReturnLabelSourceEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReturnLabelSourceEnumeration import ReturnLabelSourceEnu
 class ReturnLabelDownloadAndPrint(ReturnLabelSourceEnumeration):
     """Indicated that a return label must be downloaded and printed by the customer.
 
-    See https://schema.org/ReturnLabelDownloadAndPrint.
-
+    See: https://schema.org/ReturnLabelDownloadAndPrint
+    Model depth: 5
     """
-    type_: str = Field("ReturnLabelDownloadAndPrint", const=True, alias='@type')
+    type_: str = Field(default="ReturnLabelDownloadAndPrint", alias='@type')
     
-
-ReturnLabelDownloadAndPrint.update_forward_refs()
