@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReturnLabelSourceEnumeration import ReturnLabelSourceEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReturnLabelSourceEnumeration import ReturnLabelSourceEnu
 class ReturnLabelInBox(ReturnLabelSourceEnumeration):
     """Specifies that a return label will be provided by the seller in the shipping box.
 
-    See https://schema.org/ReturnLabelInBox.
-
+    See: https://schema.org/ReturnLabelInBox
+    Model depth: 5
     """
-    type_: str = Field("ReturnLabelInBox", const=True, alias='@type')
+    type_: str = Field(default="ReturnLabelInBox", alias='@type')
     
-
-ReturnLabelInBox.update_forward_refs()
