@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class ReturnLabelSourceEnumeration(Enumeration):
     """Enumerates several types of return labels for product returns.
 
-    See https://schema.org/ReturnLabelSourceEnumeration.
-
+    See: https://schema.org/ReturnLabelSourceEnumeration
+    Model depth: 4
     """
-    type_: str = Field("ReturnLabelSourceEnumeration", const=True, alias='@type')
+    type_: str = Field(default="ReturnLabelSourceEnumeration", alias='@type')
     
-
-ReturnLabelSourceEnumeration.update_forward_refs()
