@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Enumeration import Enumeration
 class ReturnMethodEnumeration(Enumeration):
     """Enumerates several types of product return methods.
 
-    See https://schema.org/ReturnMethodEnumeration.
-
+    See: https://schema.org/ReturnMethodEnumeration
+    Model depth: 4
     """
-    type_: str = Field("ReturnMethodEnumeration", const=True, alias='@type')
+    type_: str = Field(default="ReturnMethodEnumeration", alias='@type')
     
-
-ReturnMethodEnumeration.update_forward_refs()
