@@ -14,7 +14,7 @@ class Review(CreativeWork):
     See: https://schema.org/Review
     Model depth: 3
     """
-    type_: str = Field("Review", alias='@type')
+    type_: str = Field(default="Review", alias='@type')
     associatedMediaReview: Optional[Union[List[Union['Review', str]], 'Review', str]] = Field(
         default=None,
         description="An associated [[MediaReview]], related by specific common content, topic or claim."
@@ -54,7 +54,7 @@ class Review(CreativeWork):
         default=None,
         description="The actual body of the review.",
     )
-    negativeNotes: Optional[Union[List[Union[str, 'Text', 'WebContent', 'ItemList', 'ListItem']], str, 'Text', 'WebContent', 'ItemList', 'ListItem']] = Field(
+    negativeNotes: Optional[Union[List[Union[str, 'Text', 'ListItem', 'WebContent', 'ItemList']], str, 'Text', 'ListItem', 'WebContent', 'ItemList']] = Field(
         default=None,
         description="Indicates, in the context of a [[Review]] (e.g. framed as 'pro' vs 'con' considerations),"
      "negative considerations - either as unstructured text, or a list.",
@@ -65,7 +65,6 @@ class Review(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.ItemList import ItemList
