@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -6,10 +9,8 @@ class Rheumatologic(MedicalSpecialty):
     """A specific branch of medical science that deals with the study and treatment of rheumatic,"
      "autoimmune or joint diseases.
 
-    See https://schema.org/Rheumatologic.
-
+    See: https://schema.org/Rheumatologic
+    Model depth: 6
     """
-    type_: str = Field("Rheumatologic", const=True, alias='@type')
+    type_: str = Field(default="Rheumatologic", alias='@type')
     
-
-Rheumatologic.update_forward_refs()
