@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class RisksOrComplicationsHealthAspect(HealthAspectEnumeration):
     """Information about the risk factors and possible complications that may follow a topic.
 
-    See https://schema.org/RisksOrComplicationsHealthAspect.
-
+    See: https://schema.org/RisksOrComplicationsHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("RisksOrComplicationsHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="RisksOrComplicationsHealthAspect", alias='@type')
     
-
-RisksOrComplicationsHealthAspect.update_forward_refs()
