@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.BodyOfWater import BodyOfWater
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.BodyOfWater import BodyOfWater
 class RiverBodyOfWater(BodyOfWater):
     """A river (for example, the broad majestic Shannon).
 
-    See https://schema.org/RiverBodyOfWater.
-
+    See: https://schema.org/RiverBodyOfWater
+    Model depth: 5
     """
-    type_: str = Field("RiverBodyOfWater", const=True, alias='@type')
+    type_: str = Field(default="RiverBodyOfWater", alias='@type')
     
-
-RiverBodyOfWater.update_forward_refs()
