@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RsvpResponseType import RsvpResponseType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RsvpResponseType import RsvpResponseType
 class RsvpResponseMaybe(RsvpResponseType):
     """The invitee may or may not attend.
 
-    See https://schema.org/RsvpResponseMaybe.
-
+    See: https://schema.org/RsvpResponseMaybe
+    Model depth: 5
     """
-    type_: str = Field("RsvpResponseMaybe", const=True, alias='@type')
+    type_: str = Field(default="RsvpResponseMaybe", alias='@type')
     
-
-RsvpResponseMaybe.update_forward_refs()
