@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RsvpResponseType import RsvpResponseType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RsvpResponseType import RsvpResponseType
 class RsvpResponseYes(RsvpResponseType):
     """The invitee will attend.
 
-    See https://schema.org/RsvpResponseYes.
-
+    See: https://schema.org/RsvpResponseYes
+    Model depth: 5
     """
-    type_: str = Field("RsvpResponseYes", const=True, alias='@type')
+    type_: str = Field(default="RsvpResponseYes", alias='@type')
     
-
-RsvpResponseYes.update_forward_refs()
