@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PriceTypeEnumeration import PriceTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PriceTypeEnumeration import PriceTypeEnumeration
 class SRP(PriceTypeEnumeration):
     """Represents the suggested retail price (\"SRP\") of an offered product.
 
-    See https://schema.org/SRP.
-
+    See: https://schema.org/SRP
+    Model depth: 5
     """
-    type_: str = Field("SRP", const=True, alias='@type')
+    type_: str = Field(default="SRP", alias='@type')
     
-
-SRP.update_forward_refs()
