@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class SafetyHealthAspect(HealthAspectEnumeration):
     """Content about the safety-related aspects of a health topic.
 
-    See https://schema.org/SafetyHealthAspect.
-
+    See: https://schema.org/SafetyHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("SafetyHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="SafetyHealthAspect", alias='@type')
     
-
-SafetyHealthAspect.update_forward_refs()
