@@ -11,6 +11,5 @@ class SaleEvent(Event):
     See: https://schema.org/SaleEvent
     Model depth: 3
     """
-    type_: str = Field("SaleEvent", alias='@type')
+    type_: str = Field(default="SaleEvent", alias='@type')
     
-
