@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MediaManipulationRatingEnumeration import MediaManipulationRatingEnumeration
 
@@ -19,10 +22,8 @@ class SatireOrParodyContent(MediaManipulationRatingEnumeration):
      "in that context. (Reshares of satire/parody content that do not include relevant context"
      "are more likely to fall under the “missing context” rating.)
 
-    See https://schema.org/SatireOrParodyContent.
-
+    See: https://schema.org/SatireOrParodyContent
+    Model depth: 5
     """
-    type_: str = Field("SatireOrParodyContent", const=True, alias='@type')
+    type_: str = Field(default="SatireOrParodyContent", alias='@type')
     
-
-SatireOrParodyContent.update_forward_refs()
