@@ -13,6 +13,5 @@ class ScheduleAction(PlanAction):
     See: https://schema.org/ScheduleAction
     Model depth: 5
     """
-    type_: str = Field("ScheduleAction", alias='@type')
+    type_: str = Field(default="ScheduleAction", alias='@type')
     
-
