@@ -11,6 +11,5 @@ class School(EducationalOrganization):
     See: https://schema.org/School
     Model depth: 4
     """
-    type_: str = Field("School", alias='@type')
+    type_: str = Field(default="School", alias='@type')
     
-
