@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 class SchoolDistrict(AdministrativeArea):
     """A School District is an administrative area for the administration of schools.
 
-    See https://schema.org/SchoolDistrict.
-
+    See: https://schema.org/SchoolDistrict
+    Model depth: 4
     """
-    type_: str = Field("SchoolDistrict", const=True, alias='@type')
+    type_: str = Field(default="SchoolDistrict", alias='@type')
     
-
-SchoolDistrict.update_forward_refs()
