@@ -14,7 +14,7 @@ class ScreeningEvent(Event):
     See: https://schema.org/ScreeningEvent
     Model depth: 3
     """
-    type_: str = Field("ScreeningEvent", alias='@type')
+    type_: str = Field(default="ScreeningEvent", alias='@type')
     workPresented: Optional[Union[List[Union['Movie', str]], 'Movie', str]] = Field(
         default=None,
         description="The movie presented during this event.",
@@ -29,7 +29,6 @@ class ScreeningEvent(Event):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Movie import Movie
     from pydantic_schemaorg.Text import Text
