@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CreativeWork import CreativeWork
 class Sculpture(CreativeWork):
     """A piece of sculpture.
 
-    See https://schema.org/Sculpture.
-
+    See: https://schema.org/Sculpture
+    Model depth: 3
     """
-    type_: str = Field("Sculpture", const=True, alias='@type')
+    type_: str = Field(default="Sculpture", alias='@type')
     
-
-Sculpture.update_forward_refs()
