@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.BodyOfWater import BodyOfWater
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.BodyOfWater import BodyOfWater
 class SeaBodyOfWater(BodyOfWater):
     """A sea (for example, the Caspian sea).
 
-    See https://schema.org/SeaBodyOfWater.
-
+    See: https://schema.org/SeaBodyOfWater
+    Model depth: 5
     """
-    type_: str = Field("SeaBodyOfWater", const=True, alias='@type')
+    type_: str = Field(default="SeaBodyOfWater", alias='@type')
     
-
-SeaBodyOfWater.update_forward_refs()
