@@ -15,13 +15,12 @@ class SearchAction(Action):
     See: https://schema.org/SearchAction
     Model depth: 3
     """
-    type_: str = Field("SearchAction", alias='@type')
+    type_: str = Field(default="SearchAction", alias='@type')
     query: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="A sub property of instrument. The query used on this action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
