@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CreativeWork import CreativeWork
 class Season(CreativeWork):
     """A media season e.g. tv, radio, video game etc.
 
-    See https://schema.org/Season.
-
+    See: https://schema.org/Season
+    Model depth: 3
     """
-    type_: str = Field("Season", const=True, alias='@type')
+    type_: str = Field(default="Season", alias='@type')
     
-
-Season.update_forward_refs()
