@@ -14,7 +14,7 @@ class Seat(Intangible):
     See: https://schema.org/Seat
     Model depth: 3
     """
-    type_: str = Field("Seat", alias='@type')
+    type_: str = Field(default="Seat", alias='@type')
     seatNumber: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The location of the reserved seat (e.g., 27).",
@@ -33,7 +33,6 @@ class Seat(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.QualitativeValue import QualitativeValue
