@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MapCategoryType import MapCategoryType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MapCategoryType import MapCategoryType
 class SeatingMap(MapCategoryType):
     """A seating map.
 
-    See https://schema.org/SeatingMap.
-
+    See: https://schema.org/SeatingMap
+    Model depth: 5
     """
-    type_: str = Field("SeatingMap", const=True, alias='@type')
+    type_: str = Field(default="SeatingMap", alias='@type')
     
-
-SeatingMap.update_forward_refs()
