@@ -16,7 +16,7 @@ class SeekToAction(Action):
     See: https://schema.org/SeekToAction
     Model depth: 3
     """
-    type_: str = Field("SeekToAction", alias='@type')
+    type_: str = Field(default="SeekToAction", alias='@type')
     startOffset: Optional[Union[List[Union[Decimal, 'Number', 'HyperTocEntry', str]], Decimal, 'Number', 'HyperTocEntry', str]] = Field(
         default=None,
         description="The start time of the clip expressed as the number of seconds from the beginning of the"
@@ -24,7 +24,6 @@ class SeekToAction(Action):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.HyperTocEntry import HyperTocEntry
