@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class SelfStorage(LocalBusiness):
     """A self-storage facility.
 
-    See https://schema.org/SelfStorage.
-
+    See: https://schema.org/SelfStorage
+    Model depth: 4
     """
-    type_: str = Field("SelfStorage", const=True, alias='@type')
+    type_: str = Field(default="SelfStorage", alias='@type')
     
-
-SelfStorage.update_forward_refs()
