@@ -15,7 +15,7 @@ class SellAction(TradeAction):
     See: https://schema.org/SellAction
     Model depth: 4
     """
-    type_: str = Field("SellAction", alias='@type')
+    type_: str = Field(default="SellAction", alias='@type')
     buyer: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="A sub property of participant. The participant/person/organization that bought the"
@@ -27,7 +27,6 @@ class SellAction(TradeAction):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
