@@ -17,8 +17,8 @@ class SendAction(TransferAction):
     See: https://schema.org/SendAction
     Model depth: 4
     """
-    type_: str = Field("SendAction", alias='@type')
-    recipient: Optional[Union[List[Union['Person', 'Organization', 'Audience', 'ContactPoint', str]], 'Person', 'Organization', 'Audience', 'ContactPoint', str]] = Field(
+    type_: str = Field(default="SendAction", alias='@type')
+    recipient: Optional[Union[List[Union['Person', 'Audience', 'Organization', 'ContactPoint', str]], 'Person', 'Audience', 'Organization', 'ContactPoint', str]] = Field(
         default=None,
         description="A sub property of participant. The participant who is at the receiving end of the action.",
     )
@@ -28,10 +28,9 @@ class SendAction(TransferAction):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
-    from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.Audience import Audience
+    from pydantic_schemaorg.Organization import Organization
     from pydantic_schemaorg.ContactPoint import ContactPoint
     from pydantic_schemaorg.DeliveryMethod import DeliveryMethod
