@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Intangible import Intangible
 
@@ -6,10 +9,8 @@ class Series(Intangible):
     """A Series in schema.org is a group of related items, typically but not necessarily of the"
      "same kind. See also [[CreativeWorkSeries]], [[EventSeries]].
 
-    See https://schema.org/Series.
-
+    See: https://schema.org/Series
+    Model depth: 3
     """
-    type_: str = Field("Series", const=True, alias='@type')
+    type_: str = Field(default="Series", alias='@type')
     
-
-Series.update_forward_refs()
