@@ -16,7 +16,7 @@ class ServiceChannel(Intangible):
     See: https://schema.org/ServiceChannel
     Model depth: 3
     """
-    type_: str = Field("ServiceChannel", alias='@type')
+    type_: str = Field(default="ServiceChannel", alias='@type')
     processingTime: Optional[Union[List[Union['Duration', str]], 'Duration', str]] = Field(
         default=None,
         description="Estimated processing time for the service using this channel.",
@@ -54,7 +54,6 @@ class ServiceChannel(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Duration import Duration
     from pydantic_schemaorg.Place import Place
