@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CreativeWork import CreativeWork
 class SheetMusic(CreativeWork):
     """Printed music, as opposed to performed or recorded music.
 
-    See https://schema.org/SheetMusic.
-
+    See: https://schema.org/SheetMusic
+    Model depth: 3
     """
-    type_: str = Field("SheetMusic", const=True, alias='@type')
+    type_: str = Field(default="SheetMusic", alias='@type')
     
-
-SheetMusic.update_forward_refs()
