@@ -18,7 +18,7 @@ class ShippingRateSettings(StructuredValue):
     See: https://schema.org/ShippingRateSettings
     Model depth: 4
     """
-    type_: str = Field("ShippingRateSettings", alias='@type')
+    type_: str = Field(default="ShippingRateSettings", alias='@type')
     shippingLabel: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Label to match an [[OfferShippingDetails]] with a [[ShippingRateSettings]] (within"
@@ -38,7 +38,7 @@ class ShippingRateSettings(StructuredValue):
         description="The shipping rate is the cost of shipping to the specified destination. Typically, the"
      "maxValue and currency values (of the [[MonetaryAmount]]) are most appropriate.",
     )
-    freeShippingThreshold: Optional[Union[List[Union['DeliveryChargeSpecification', 'MonetaryAmount', str]], 'DeliveryChargeSpecification', 'MonetaryAmount', str]] = Field(
+    freeShippingThreshold: Optional[Union[List[Union['MonetaryAmount', 'DeliveryChargeSpecification', str]], 'MonetaryAmount', 'DeliveryChargeSpecification', str]] = Field(
         default=None,
         description="A monetary value above which (or equal to) the shipping rate becomes free. Intended to"
      "be used via an [[OfferShippingDetails]] with [[shippingSettingsLink]] matching"
@@ -55,7 +55,6 @@ class ShippingRateSettings(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Boolean import Boolean
