@@ -11,6 +11,5 @@ class ShoppingCenter(LocalBusiness):
     See: https://schema.org/ShoppingCenter
     Model depth: 4
     """
-    type_: str = Field("ShoppingCenter", alias='@type')
+    type_: str = Field(default="ShoppingCenter", alias='@type')
     
-
