@@ -11,6 +11,5 @@ class SingleRelease(MusicAlbumReleaseType):
     See: https://schema.org/SingleRelease
     Model depth: 5
     """
-    type_: str = Field("SingleRelease", alias='@type')
+    type_: str = Field(default="SingleRelease", alias='@type')
     
-
