@@ -11,6 +11,5 @@ class SizeGroupEnumeration(Enumeration):
     See: https://schema.org/SizeGroupEnumeration
     Model depth: 4
     """
-    type_: str = Field("SizeGroupEnumeration", alias='@type')
+    type_: str = Field(default="SizeGroupEnumeration", alias='@type')
     
-
