@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.SizeSystemEnumeration import SizeSystemEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.SizeSystemEnumeration import SizeSystemEnumeration
 class SizeSystemMetric(SizeSystemEnumeration):
     """Metric size system.
 
-    See https://schema.org/SizeSystemMetric.
-
+    See: https://schema.org/SizeSystemMetric
+    Model depth: 5
     """
-    type_: str = Field("SizeSystemMetric", const=True, alias='@type')
+    type_: str = Field(default="SizeSystemMetric", alias='@type')
     
-
-SizeSystemMetric.update_forward_refs()
