@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Resort import Resort
 from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
@@ -6,10 +9,8 @@ from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 class SkiResort(Resort, SportsActivityLocation):
     """A ski resort.
 
-    See https://schema.org/SkiResort.
-
+    See: https://schema.org/SkiResort
+    Model depth: 5
     """
-    type_: str = Field("SkiResort", const=True, alias='@type')
+    type_: str = Field(default="SkiResort", alias='@type')
     
-
-SkiResort.update_forward_refs()
