@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalExam import PhysicalExam
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PhysicalExam import PhysicalExam
 class Skin(PhysicalExam):
     """Skin assessment with clinical examination.
 
-    See https://schema.org/Skin.
-
+    See: https://schema.org/Skin
+    Model depth: 5
     """
-    type_: str = Field("Skin", const=True, alias='@type')
+    type_: str = Field(default="Skin", alias='@type')
     
-
-Skin.update_forward_refs()
