@@ -15,7 +15,7 @@ class SolveMathAction(Action):
     See: https://schema.org/SolveMathAction
     Model depth: 3
     """
-    type_: str = Field("SolveMathAction", alias='@type')
+    type_: str = Field(default="SolveMathAction", alias='@type')
     eduQuestionType: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="For questions that are part of learning resources (e.g. Quiz), eduQuestionType indicates"
@@ -24,6 +24,5 @@ class SolveMathAction(Action):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
