@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 class SoundtrackAlbum(MusicAlbumProductionType):
     """SoundtrackAlbum.
 
-    See https://schema.org/SoundtrackAlbum.
-
+    See: https://schema.org/SoundtrackAlbum
+    Model depth: 5
     """
-    type_: str = Field("SoundtrackAlbum", const=True, alias='@type')
+    type_: str = Field(default="SoundtrackAlbum", alias='@type')
     
-
-SoundtrackAlbum.update_forward_refs()
