@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -6,10 +9,8 @@ class Specialty(Enumeration):
     """Any branch of a field in which people typically develop specific expertise, usually"
      "after significant study, time, and effort.
 
-    See https://schema.org/Specialty.
-
+    See: https://schema.org/Specialty
+    Model depth: 4
     """
-    type_: str = Field("Specialty", const=True, alias='@type')
+    type_: str = Field(default="Specialty", alias='@type')
     
-
-Specialty.update_forward_refs()
