@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -7,10 +10,8 @@ class SpeechPathology(MedicalSpecialty):
      "and voice, as stuttering, lisping, or lalling, and of language disturbances, as aphasia"
      "or delayed language acquisition.
 
-    See https://schema.org/SpeechPathology.
-
+    See: https://schema.org/SpeechPathology
+    Model depth: 6
     """
-    type_: str = Field("SpeechPathology", const=True, alias='@type')
+    type_: str = Field(default="SpeechPathology", alias='@type')
     
-
-SpeechPathology.update_forward_refs()
