@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MusicAlbumProductionType import MusicAlbumProductionType
 class SpokenWordAlbum(MusicAlbumProductionType):
     """SpokenWordAlbum.
 
-    See https://schema.org/SpokenWordAlbum.
-
+    See: https://schema.org/SpokenWordAlbum
+    Model depth: 5
     """
-    type_: str = Field("SpokenWordAlbum", const=True, alias='@type')
+    type_: str = Field(default="SpokenWordAlbum", alias='@type')
     
-
-SpokenWordAlbum.update_forward_refs()
