@@ -15,7 +15,7 @@ class SportsEvent(Event):
     See: https://schema.org/SportsEvent
     Model depth: 3
     """
-    type_: str = Field("SportsEvent", alias='@type')
+    type_: str = Field(default="SportsEvent", alias='@type')
     sport: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text']], AnyUrl, 'URL', str, 'Text']] = Field(
         default=None,
         description="A type of sport (e.g. Baseball).",
@@ -24,7 +24,7 @@ class SportsEvent(Event):
         default=None,
         description="The away team in a sports event.",
     )
-    homeTeam: Optional[Union[List[Union['Person', 'SportsTeam', str]], 'Person', 'SportsTeam', str]] = Field(
+    homeTeam: Optional[Union[List[Union['SportsTeam', 'Person', str]], 'SportsTeam', 'Person', str]] = Field(
         default=None,
         description="The home team in a sports event.",
     )
@@ -34,7 +34,6 @@ class SportsEvent(Event):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.Text import Text
