@@ -16,14 +16,13 @@ class SportsOrganization(Organization):
     See: https://schema.org/SportsOrganization
     Model depth: 3
     """
-    type_: str = Field("SportsOrganization", alias='@type')
+    type_: str = Field(default="SportsOrganization", alias='@type')
     sport: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text']], AnyUrl, 'URL', str, 'Text']] = Field(
         default=None,
         description="A type of sport (e.g. Baseball).",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.Text import Text
