@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DigitalDocument import DigitalDocument
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DigitalDocument import DigitalDocument
 class SpreadsheetDigitalDocument(DigitalDocument):
     """A spreadsheet file.
 
-    See https://schema.org/SpreadsheetDigitalDocument.
-
+    See: https://schema.org/SpreadsheetDigitalDocument
+    Model depth: 4
     """
-    type_: str = Field("SpreadsheetDigitalDocument", const=True, alias='@type')
+    type_: str = Field(default="SpreadsheetDigitalDocument", alias='@type')
     
-
-SpreadsheetDigitalDocument.update_forward_refs()
