@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class StagesHealthAspect(HealthAspectEnumeration):
     """Stages that can be observed from a topic.
 
-    See https://schema.org/StagesHealthAspect.
-
+    See: https://schema.org/StagesHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("StagesHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="StagesHealthAspect", alias='@type')
     
-
-StagesHealthAspect.update_forward_refs()
