@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AdministrativeArea import AdministrativeArea
 class State(AdministrativeArea):
     """A state or province of a country.
 
-    See https://schema.org/State.
-
+    See: https://schema.org/State
+    Model depth: 4
     """
-    type_: str = Field("State", const=True, alias='@type')
+    type_: str = Field(default="State", alias='@type')
     
-
-State.update_forward_refs()
