@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -8,10 +11,8 @@ class Statement(CreativeWork):
      "(e.g. in Fact Checking), consider using [[Claim]] instead. Use the [[text]] property"
      "to capture the text of the statement.
 
-    See https://schema.org/Statement.
-
+    See: https://schema.org/Statement
+    Model depth: 3
     """
-    type_: str = Field("Statement", const=True, alias='@type')
+    type_: str = Field(default="Statement", alias='@type')
     
-
-Statement.update_forward_refs()
