@@ -25,7 +25,7 @@ class StatisticalPopulation(Intangible):
     See: https://schema.org/StatisticalPopulation
     Model depth: 3
     """
-    type_: str = Field("StatisticalPopulation", alias='@type')
+    type_: str = Field(default="StatisticalPopulation", alias='@type')
     numConstraints: Optional[Union[List[Union[int, 'Integer', str]], int, 'Integer', str]] = Field(
         default=None,
         description="Indicates the number of constraints (not counting [[populationType]]) defined for"
@@ -43,7 +43,6 @@ class StatisticalPopulation(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Integer import Integer
     from pydantic_schemaorg.Class import Class
