@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.QualitativeValue import QualitativeValue
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.QualitativeValue import QualitativeValue
 class SteeringPositionValue(QualitativeValue):
     """A value indicating a steering position.
 
-    See https://schema.org/SteeringPositionValue.
-
+    See: https://schema.org/SteeringPositionValue
+    Model depth: 5
     """
-    type_: str = Field("SteeringPositionValue", const=True, alias='@type')
+    type_: str = Field(default="SteeringPositionValue", alias='@type')
     
-
-SteeringPositionValue.update_forward_refs()
