@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RefundTypeEnumeration import RefundTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RefundTypeEnumeration import RefundTypeEnumeration
 class StoreCreditRefund(RefundTypeEnumeration):
     """Specifies that the customer receives a store credit as refund when returning a product
 
-    See https://schema.org/StoreCreditRefund.
-
+    See: https://schema.org/StoreCreditRefund
+    Model depth: 5
     """
-    type_: str = Field("StoreCreditRefund", const=True, alias='@type')
+    type_: str = Field(default="StoreCreditRefund", alias='@type')
     
-
-StoreCreditRefund.update_forward_refs()
