@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PhysicalActivityCategory import PhysicalActivityCategory
 
@@ -6,10 +9,8 @@ class StrengthTraining(PhysicalActivityCategory):
     """Physical activity that is engaged in to improve muscle and bone strength. Also referred"
      "to as resistance training.
 
-    See https://schema.org/StrengthTraining.
-
+    See: https://schema.org/StrengthTraining
+    Model depth: 5
     """
-    type_: str = Field("StrengthTraining", const=True, alias='@type')
+    type_: str = Field(default="StrengthTraining", alias='@type')
     
-
-StrengthTraining.update_forward_refs()
