@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Intangible import Intangible
 
@@ -6,10 +9,8 @@ class StructuredValue(Intangible):
     """Structured values are used when the value of a property has a more complex structure than"
      "simply being a textual value or a reference to another thing.
 
-    See https://schema.org/StructuredValue.
-
+    See: https://schema.org/StructuredValue
+    Model depth: 3
     """
-    type_: str = Field("StructuredValue", const=True, alias='@type')
+    type_: str = Field(default="StructuredValue", alias='@type')
     
-
-StructuredValue.update_forward_refs()
