@@ -11,6 +11,5 @@ class StudioAlbum(MusicAlbumProductionType):
     See: https://schema.org/StudioAlbum
     Model depth: 5
     """
-    type_: str = Field("StudioAlbum", alias='@type')
+    type_: str = Field(default="StudioAlbum", alias='@type')
     
-
