@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.InteractAction import InteractAction
 
@@ -11,10 +14,8 @@ class SubscribeAction(InteractAction):
      "* [[JoinAction]]: Unlike JoinAction, SubscribeAction implies that the agent is interested"
      "in continuing receiving updates from the object.
 
-    See https://schema.org/SubscribeAction.
-
+    See: https://schema.org/SubscribeAction
+    Model depth: 4
     """
-    type_: str = Field("SubscribeAction", const=True, alias='@type')
+    type_: str = Field(default="SubscribeAction", alias='@type')
     
-
-SubscribeAction.update_forward_refs()
