@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.PriceComponentTypeEnumeration import PriceComponentTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.PriceComponentTypeEnumeration import PriceComponentTypeE
 class Subscription(PriceComponentTypeEnumeration):
     """Represents the subscription pricing component of the total price for an offered product.
 
-    See https://schema.org/Subscription.
-
+    See: https://schema.org/Subscription
+    Model depth: 5
     """
-    type_: str = Field("Subscription", const=True, alias='@type')
+    type_: str = Field(default="Subscription", alias='@type')
     
-
-Subscription.update_forward_refs()
