@@ -28,14 +28,14 @@ class SuperficialAnatomy(MedicalEntity):
     See: https://schema.org/SuperficialAnatomy
     Model depth: 3
     """
-    type_: str = Field("SuperficialAnatomy", alias='@type')
+    type_: str = Field(default="SuperficialAnatomy", alias='@type')
     significance: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The significance associated with the superficial anatomy; as an example, how characteristics"
      "of the superficial anatomy can suggest underlying medical conditions or courses of"
      "treatment.",
     )
-    relatedAnatomy: Optional[Union[List[Union['AnatomicalSystem', 'AnatomicalStructure', str]], 'AnatomicalSystem', 'AnatomicalStructure', str]] = Field(
+    relatedAnatomy: Optional[Union[List[Union['AnatomicalStructure', 'AnatomicalSystem', str]], 'AnatomicalStructure', 'AnatomicalSystem', str]] = Field(
         default=None,
         description="Anatomical systems or structures that relate to the superficial anatomy.",
     )
@@ -55,10 +55,9 @@ class SuperficialAnatomy(MedicalEntity):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
-    from pydantic_schemaorg.AnatomicalSystem import AnatomicalSystem
     from pydantic_schemaorg.AnatomicalStructure import AnatomicalStructure
+    from pydantic_schemaorg.AnatomicalSystem import AnatomicalSystem
     from pydantic_schemaorg.MedicalCondition import MedicalCondition
     from pydantic_schemaorg.MedicalTherapy import MedicalTherapy
