@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -6,10 +9,8 @@ class Surgical(MedicalSpecialty):
     """A specific branch of medical science that pertains to treating diseases, injuries and"
      "deformities by manual and instrumental means.
 
-    See https://schema.org/Surgical.
-
+    See: https://schema.org/Surgical
+    Model depth: 6
     """
-    type_: str = Field("Surgical", const=True, alias='@type')
+    type_: str = Field(default="Surgical", alias='@type')
     
-
-Surgical.update_forward_refs()
