@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalProcedure import MedicalProcedure
 
@@ -6,10 +9,8 @@ class SurgicalProcedure(MedicalProcedure):
     """A medical procedure involving an incision with instruments; performed for diagnose,"
      "or therapeutic purposes.
 
-    See https://schema.org/SurgicalProcedure.
-
+    See: https://schema.org/SurgicalProcedure
+    Model depth: 4
     """
-    type_: str = Field("SurgicalProcedure", const=True, alias='@type')
+    type_: str = Field(default="SurgicalProcedure", alias='@type')
     
-
-SurgicalProcedure.update_forward_refs()
