@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalStudyStatus import MedicalStudyStatus
 class Suspended(MedicalStudyStatus):
     """Suspended.
 
-    See https://schema.org/Suspended.
-
+    See: https://schema.org/Suspended
+    Model depth: 6
     """
-    type_: str = Field("Suspended", const=True, alias='@type')
+    type_: str = Field(default="Suspended", alias='@type')
     
-
-Suspended.update_forward_refs()
