@@ -14,13 +14,12 @@ class TVClip(Clip):
     See: https://schema.org/TVClip
     Model depth: 4
     """
-    type_: str = Field("TVClip", alias='@type')
+    type_: str = Field(default="TVClip", alias='@type')
     partOfTVSeries: Optional[Union[List[Union['TVSeries', str]], 'TVSeries', str]] = Field(
         default=None,
         description="The TV series to which this episode or season belongs.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.TVSeries import TVSeries
