@@ -16,7 +16,7 @@ class TVSeries(CreativeWorkSeries, CreativeWork):
     See: https://schema.org/TVSeries
     Model depth: 3
     """
-    type_: str = Field("TVSeries", alias='@type')
+    type_: str = Field(default="TVSeries", alias='@type')
     actors: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="An actor, e.g. in tv, radio, movie, video games etc. Actors can be associated with individual"
@@ -90,7 +90,6 @@ class TVSeries(CreativeWorkSeries, CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.CreativeWorkSeason import CreativeWorkSeason
