@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.TransferAction import TransferAction
 
@@ -7,10 +10,8 @@ class TakeAction(TransferAction):
      "actions: * [[GiveAction]]: The reciprocal of TakeAction. * [[ReceiveAction]]: Unlike"
      "ReceiveAction, TakeAction implies that ownership has been transfered.
 
-    See https://schema.org/TakeAction.
-
+    See: https://schema.org/TakeAction
+    Model depth: 4
     """
-    type_: str = Field("TakeAction", const=True, alias='@type')
+    type_: str = Field(default="TakeAction", alias='@type')
     
-
-TakeAction.update_forward_refs()
