@@ -11,6 +11,5 @@ class TattooParlor(HealthAndBeautyBusiness):
     See: https://schema.org/TattooParlor
     Model depth: 5
     """
-    type_: str = Field("TattooParlor", alias='@type')
+    type_: str = Field(default="TattooParlor", alias='@type')
     
-
