@@ -17,7 +17,7 @@ class TaxiReservation(Reservation):
     See: https://schema.org/TaxiReservation
     Model depth: 4
     """
-    type_: str = Field("TaxiReservation", alias='@type')
+    type_: str = Field(default="TaxiReservation", alias='@type')
     partySize: Optional[Union[List[Union[int, 'Integer', 'QuantitativeValue', str]], int, 'Integer', 'QuantitativeValue', str]] = Field(
         default=None,
         description="Number of people the reservation should accommodate.",
@@ -32,7 +32,6 @@ class TaxiReservation(Reservation):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Integer import Integer
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
