@@ -11,6 +11,5 @@ class TaxiStand(CivicStructure):
     See: https://schema.org/TaxiStand
     Model depth: 4
     """
-    type_: str = Field("TaxiStand", alias='@type')
+    type_: str = Field(default="TaxiStand", alias='@type')
     
-
