@@ -11,6 +11,5 @@ class TelevisionChannel(BroadcastChannel):
     See: https://schema.org/TelevisionChannel
     Model depth: 4
     """
-    type_: str = Field("TelevisionChannel", alias='@type')
+    type_: str = Field(default="TelevisionChannel", alias='@type')
     
-
