@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.SportsActivityLocation import SportsActivityLocation
 class TennisComplex(SportsActivityLocation):
     """A tennis complex.
 
-    See https://schema.org/TennisComplex.
-
+    See: https://schema.org/TennisComplex
+    Model depth: 5
     """
-    type_: str = Field("TennisComplex", const=True, alias='@type')
+    type_: str = Field(default="TennisComplex", alias='@type')
     
-
-TennisComplex.update_forward_refs()
