@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DigitalDocument import DigitalDocument
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DigitalDocument import DigitalDocument
 class TextDigitalDocument(DigitalDocument):
     """A file composed primarily of text.
 
-    See https://schema.org/TextDigitalDocument.
-
+    See: https://schema.org/TextDigitalDocument
+    Model depth: 4
     """
-    type_: str = Field("TextDigitalDocument", const=True, alias='@type')
+    type_: str = Field(default="TextDigitalDocument", alias='@type')
     
-
-TextDigitalDocument.update_forward_refs()
