@@ -11,6 +11,5 @@ class TheaterGroup(PerformingGroup):
     See: https://schema.org/TheaterGroup
     Model depth: 4
     """
-    type_: str = Field("TheaterGroup", alias='@type')
+    type_: str = Field(default="TheaterGroup", alias='@type')
     
-
