@@ -15,13 +15,12 @@ class Thesis(CreativeWork):
     See: https://schema.org/Thesis
     Model depth: 3
     """
-    type_: str = Field("Thesis", alias='@type')
+    type_: str = Field(default="Thesis", alias='@type')
     inSupportOf: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Qualification, candidature, degree, application that Thesis supports.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
