@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DayOfWeek import DayOfWeek
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DayOfWeek import DayOfWeek
 class Thursday(DayOfWeek):
     """The day of the week between Wednesday and Friday.
 
-    See https://schema.org/Thursday.
-
+    See: https://schema.org/Thursday
+    Model depth: 5
     """
-    type_: str = Field("Thursday", const=True, alias='@type')
+    type_: str = Field(default="Thursday", alias='@type')
     
-
-Thursday.update_forward_refs()
