@@ -17,7 +17,7 @@ class Ticket(Intangible):
     See: https://schema.org/Ticket
     Model depth: 3
     """
-    type_: str = Field("Ticket", alias='@type')
+    type_: str = Field(default="Ticket", alias='@type')
     underName: Optional[Union[List[Union['Person', 'Organization', str]], 'Person', 'Organization', str]] = Field(
         default=None,
         description="The person or organization the reservation or ticket is for.",
@@ -60,7 +60,6 @@ class Ticket(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
