@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.AchieveAction import AchieveAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.AchieveAction import AchieveAction
 class TieAction(AchieveAction):
     """The act of reaching a draw in a competitive activity.
 
-    See https://schema.org/TieAction.
-
+    See: https://schema.org/TieAction
+    Model depth: 4
     """
-    type_: str = Field("TieAction", const=True, alias='@type')
+    type_: str = Field(default="TieAction", alias='@type')
     
-
-TieAction.update_forward_refs()
