@@ -21,7 +21,7 @@ class TouristDestination(Place):
     See: https://schema.org/TouristDestination
     Model depth: 3
     """
-    type_: str = Field("TouristDestination", alias='@type')
+    type_: str = Field(default="TouristDestination", alias='@type')
     includesAttraction: Optional[Union[List[Union['TouristAttraction', str]], 'TouristAttraction', str]] = Field(
         default=None,
         description="Attraction located at destination.",
@@ -33,7 +33,6 @@ class TouristDestination(Place):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.TouristAttraction import TouristAttraction
     from pydantic_schemaorg.Text import Text
