@@ -17,7 +17,7 @@ class TouristTrip(Trip):
     See: https://schema.org/TouristTrip
     Model depth: 4
     """
-    type_: str = Field("TouristTrip", alias='@type')
+    type_: str = Field(default="TouristTrip", alias='@type')
     touristType: Optional[Union[List[Union[str, 'Text', 'Audience']], str, 'Text', 'Audience']] = Field(
         default=None,
         description="Attraction suitable for type(s) of tourist. eg. Children, visitors from a particular"
@@ -25,7 +25,6 @@ class TouristTrip(Trip):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Audience import Audience
