@@ -17,13 +17,12 @@ class TrackAction(FindAction):
     See: https://schema.org/TrackAction
     Model depth: 4
     """
-    type_: str = Field("TrackAction", alias='@type')
+    type_: str = Field(default="TrackAction", alias='@type')
     deliveryMethod: Optional[Union[List[Union['DeliveryMethod', str]], 'DeliveryMethod', str]] = Field(
         default=None,
         description="A sub property of instrument. The method of delivery.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.DeliveryMethod import DeliveryMethod
