@@ -17,7 +17,7 @@ class TradeAction(Action):
     See: https://schema.org/TradeAction
     Model depth: 3
     """
-    type_: str = Field("TradeAction", alias='@type')
+    type_: str = Field(default="TradeAction", alias='@type')
     priceCurrency: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="The currency of the price, or a price component when attached to [[PriceSpecification]]"
@@ -50,7 +50,6 @@ class TradeAction(Action):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
     from pydantic_schemaorg.Number import Number
