@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Reservation import Reservation
 
@@ -7,10 +10,8 @@ class TrainReservation(Reservation):
      "e.g. in confirmation emails or HTML pages with individual confirmations of reservations."
      "For offers of tickets, use [[Offer]].
 
-    See https://schema.org/TrainReservation.
-
+    See: https://schema.org/TrainReservation
+    Model depth: 4
     """
-    type_: str = Field("TrainReservation", const=True, alias='@type')
+    type_: str = Field(default="TrainReservation", alias='@type')
     
-
-TrainReservation.update_forward_refs()
