@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CivicStructure import CivicStructure
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.CivicStructure import CivicStructure
 class TrainStation(CivicStructure):
     """A train station.
 
-    See https://schema.org/TrainStation.
-
+    See: https://schema.org/TrainStation
+    Model depth: 4
     """
-    type_: str = Field("TrainStation", const=True, alias='@type')
+    type_: str = Field(default="TrainStation", alias='@type')
     
-
-TrainStation.update_forward_refs()
