@@ -15,7 +15,7 @@ class TransferAction(Action):
     See: https://schema.org/TransferAction
     Model depth: 3
     """
-    type_: str = Field("TransferAction", alias='@type')
+    type_: str = Field(default="TransferAction", alias='@type')
     fromLocation: Optional[Union[List[Union['Place', str]], 'Place', str]] = Field(
         default=None,
         description="A sub property of location. The original location of the object or the agent before the"
@@ -27,6 +27,5 @@ class TransferAction(Action):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Place import Place
