@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MapCategoryType import MapCategoryType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MapCategoryType import MapCategoryType
 class TransitMap(MapCategoryType):
     """A transit map.
 
-    See https://schema.org/TransitMap.
-
+    See: https://schema.org/TransitMap
+    Model depth: 5
     """
-    type_: str = Field("TransitMap", const=True, alias='@type')
+    type_: str = Field(default="TransitMap", alias='@type')
     
-
-TransitMap.update_forward_refs()
