@@ -15,13 +15,12 @@ class TravelAction(MoveAction):
     See: https://schema.org/TravelAction
     Model depth: 4
     """
-    type_: str = Field("TravelAction", alias='@type')
+    type_: str = Field(default="TravelAction", alias='@type')
     distance: Optional[Union[List[Union['Distance', str]], 'Distance', str]] = Field(
         default=None,
         description="The distance travelled, e.g. exercising or travelling.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Distance import Distance
