@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.LocalBusiness import LocalBusiness
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.LocalBusiness import LocalBusiness
 class TravelAgency(LocalBusiness):
     """A travel agency.
 
-    See https://schema.org/TravelAgency.
-
+    See: https://schema.org/TravelAgency
+    Model depth: 4
     """
-    type_: str = Field("TravelAgency", const=True, alias='@type')
+    type_: str = Field(default="TravelAgency", alias='@type')
     
-
-TravelAgency.update_forward_refs()
