@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalIndication import MedicalIndication
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalIndication import MedicalIndication
 class TreatmentIndication(MedicalIndication):
     """An indication for treating an underlying condition, symptom, etc.
 
-    See https://schema.org/TreatmentIndication.
-
+    See: https://schema.org/TreatmentIndication
+    Model depth: 4
     """
-    type_: str = Field("TreatmentIndication", const=True, alias='@type')
+    type_: str = Field(default="TreatmentIndication", alias='@type')
     
-
-TreatmentIndication.update_forward_refs()
