@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.HealthAspectEnumeration import HealthAspectEnumeration
 class TreatmentsHealthAspect(HealthAspectEnumeration):
     """Treatments or related therapies for a Topic.
 
-    See https://schema.org/TreatmentsHealthAspect.
-
+    See: https://schema.org/TreatmentsHealthAspect
+    Model depth: 5
     """
-    type_: str = Field("TreatmentsHealthAspect", const=True, alias='@type')
+    type_: str = Field(default="TreatmentsHealthAspect", alias='@type')
     
-
-TreatmentsHealthAspect.update_forward_refs()
