@@ -16,8 +16,8 @@ class Trip(Intangible):
     See: https://schema.org/Trip
     Model depth: 3
     """
-    type_: str = Field("Trip", alias='@type')
-    offers: Optional[Union[List[Union['Demand', 'Offer', str]], 'Demand', 'Offer', str]] = Field(
+    type_: str = Field(default="Trip", alias='@type')
+    offers: Optional[Union[List[Union['Offer', 'Demand', str]], 'Offer', 'Demand', str]] = Field(
         default=None,
         description="An offer to provide this item&#x2014;for example, an offer to sell a product, rent the"
      "DVD of a movie, perform a service, or give away tickets to an event. Use [[businessFunction]]"
@@ -30,7 +30,7 @@ class Trip(Intangible):
         default=None,
         description="The expected departure time.",
     )
-    itinerary: Optional[Union[List[Union['ItemList', 'Place', str]], 'ItemList', 'Place', str]] = Field(
+    itinerary: Optional[Union[List[Union['Place', 'ItemList', str]], 'Place', 'ItemList', str]] = Field(
         default=None,
         description="Destination(s) ( [[Place]] ) that make up a trip. For a trip where destination order is"
      "important use [[ItemList]] to specify that order (see examples).",
@@ -57,13 +57,12 @@ class Trip(Intangible):
     )
     
 
-
 if TYPE_CHECKING:
-    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.Offer import Offer
+    from pydantic_schemaorg.Demand import Demand
     from pydantic_schemaorg.DateTime import DateTime
     from pydantic_schemaorg.Time import Time
-    from pydantic_schemaorg.ItemList import ItemList
     from pydantic_schemaorg.Place import Place
+    from pydantic_schemaorg.ItemList import ItemList
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.Organization import Organization
