@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.NonprofitType import NonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.NonprofitType import NonprofitType
 class UKNonprofitType(NonprofitType):
     """UKNonprofitType: Non-profit organization type originating from the United Kingdom.
 
-    See https://schema.org/UKNonprofitType.
-
+    See: https://schema.org/UKNonprofitType
+    Model depth: 5
     """
-    type_: str = Field("UKNonprofitType", const=True, alias='@type')
+    type_: str = Field(default="UKNonprofitType", alias='@type')
     
-
-UKNonprofitType.update_forward_refs()
