@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.NonprofitType import NonprofitType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.NonprofitType import NonprofitType
 class USNonprofitType(NonprofitType):
     """USNonprofitType: Non-profit organization type originating from the United States.
 
-    See https://schema.org/USNonprofitType.
-
+    See: https://schema.org/USNonprofitType
+    Model depth: 5
     """
-    type_: str = Field("USNonprofitType", const=True, alias='@type')
+    type_: str = Field(default="USNonprofitType", alias='@type')
     
-
-USNonprofitType.update_forward_refs()
