@@ -14,6 +14,5 @@ class UnRegisterAction(InteractAction):
     See: https://schema.org/UnRegisterAction
     Model depth: 4
     """
-    type_: str = Field("UnRegisterAction", alias='@type')
+    type_: str = Field(default="UnRegisterAction", alias='@type')
     
-
