@@ -12,6 +12,5 @@ class UnincorporatedAssociationCharity(UKNonprofitType):
     See: https://schema.org/UnincorporatedAssociationCharity
     Model depth: 6
     """
-    type_: str = Field("UnincorporatedAssociationCharity", alias='@type')
+    type_: str = Field(default="UnincorporatedAssociationCharity", alias='@type')
     
-
