@@ -16,7 +16,7 @@ class UnitPriceSpecification(PriceSpecification):
     See: https://schema.org/UnitPriceSpecification
     Model depth: 5
     """
-    type_: str = Field("UnitPriceSpecification", alias='@type')
+    type_: str = Field(default="UnitPriceSpecification", alias='@type')
     billingStart: Optional[Union[List[Union[Decimal, 'Number', str]], Decimal, 'Number', str]] = Field(
         default=None,
         description="Specifies after how much time this price (or price component) becomes valid and billing"
@@ -67,7 +67,6 @@ class UnitPriceSpecification(PriceSpecification):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Number import Number
     from pydantic_schemaorg.Text import Text
