@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSpecialty import MedicalSpecialty
 
@@ -6,10 +9,8 @@ class Urologic(MedicalSpecialty):
     """A specific branch of medical science that is concerned with the diagnosis and treatment"
      "of diseases pertaining to the urinary tract and the urogenital system.
 
-    See https://schema.org/Urologic.
-
+    See: https://schema.org/Urologic
+    Model depth: 6
     """
-    type_: str = Field("Urologic", const=True, alias='@type')
+    type_: str = Field(default="Urologic", alias='@type')
     
-
-Urologic.update_forward_refs()
