@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.OfferItemCondition import OfferItemCondition
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.OfferItemCondition import OfferItemCondition
 class UsedCondition(OfferItemCondition):
     """Indicates that the item is used.
 
-    See https://schema.org/UsedCondition.
-
+    See: https://schema.org/UsedCondition
+    Model depth: 5
     """
-    type_: str = Field("UsedCondition", const=True, alias='@type')
+    type_: str = Field(default="UsedCondition", alias='@type')
     
-
-UsedCondition.update_forward_refs()
