@@ -18,7 +18,7 @@ class UserComments(UserInteraction):
     See: https://schema.org/UserComments
     Model depth: 4
     """
-    type_: str = Field("UserComments", alias='@type')
+    type_: str = Field(default="UserComments", alias='@type')
     discusses: Optional[Union[List[Union['CreativeWork', str]], 'CreativeWork', str]] = Field(
         default=None,
         description="Specifies the CreativeWork associated with the UserComment.",
@@ -42,7 +42,6 @@ class UserComments(UserInteraction):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.CreativeWork import CreativeWork
     from pydantic_schemaorg.Text import Text
