@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.UserInteraction import UserInteraction
 
@@ -7,10 +10,8 @@ class UserDownloads(UserInteraction):
      "pages. It is generally better to use [[Action]]-based vocabulary, alongside types"
      "such as [[Comment]].
 
-    See https://schema.org/UserDownloads.
-
+    See: https://schema.org/UserDownloads
+    Model depth: 4
     """
-    type_: str = Field("UserDownloads", const=True, alias='@type')
+    type_: str = Field(default="UserDownloads", alias='@type')
     
-
-UserDownloads.update_forward_refs()
