@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.UserInteraction import UserInteraction
 
@@ -7,10 +10,8 @@ class UserPageVisits(UserInteraction):
      "pages. It is generally better to use [[Action]]-based vocabulary, alongside types"
      "such as [[Comment]].
 
-    See https://schema.org/UserPageVisits.
-
+    See: https://schema.org/UserPageVisits
+    Model depth: 4
     """
-    type_: str = Field("UserPageVisits", const=True, alias='@type')
+    type_: str = Field(default="UserPageVisits", alias='@type')
     
-
-UserPageVisits.update_forward_refs()
