@@ -13,6 +13,5 @@ class UserPlays(UserInteraction):
     See: https://schema.org/UserPlays
     Model depth: 4
     """
-    type_: str = Field("UserPlays", alias='@type')
+    type_: str = Field(default="UserPlays", alias='@type')
     
-
