@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.UserInteraction import UserInteraction
 
@@ -7,10 +10,8 @@ class UserPlusOnes(UserInteraction):
      "pages. It is generally better to use [[Action]]-based vocabulary, alongside types"
      "such as [[Comment]].
 
-    See https://schema.org/UserPlusOnes.
-
+    See: https://schema.org/UserPlusOnes
+    Model depth: 4
     """
-    type_: str = Field("UserPlusOnes", const=True, alias='@type')
+    type_: str = Field(default="UserPlusOnes", alias='@type')
     
-
-UserPlusOnes.update_forward_refs()
