@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Review import Review
 
@@ -6,10 +9,8 @@ class UserReview(Review):
     """A review created by an end-user (e.g. consumer, purchaser, attendee etc.), in contrast"
      "with [[CriticReview]].
 
-    See https://schema.org/UserReview.
-
+    See: https://schema.org/UserReview
+    Model depth: 4
     """
-    type_: str = Field("UserReview", const=True, alias='@type')
+    type_: str = Field(default="UserReview", alias='@type')
     
-
-UserReview.update_forward_refs()
