@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 class VeganDiet(RestrictedDiet):
     """A diet exclusive of all animal products.
 
-    See https://schema.org/VeganDiet.
-
+    See: https://schema.org/VeganDiet
+    Model depth: 5
     """
-    type_: str = Field("VeganDiet", const=True, alias='@type')
+    type_: str = Field(default="VeganDiet", alias='@type')
     
-
-VeganDiet.update_forward_refs()
