@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.RestrictedDiet import RestrictedDiet
 class VegetarianDiet(RestrictedDiet):
     """A diet exclusive of animal meat.
 
-    See https://schema.org/VegetarianDiet.
-
+    See: https://schema.org/VegetarianDiet
+    Model depth: 5
     """
-    type_: str = Field("VegetarianDiet", const=True, alias='@type')
+    type_: str = Field(default="VegetarianDiet", alias='@type')
     
-
-VegetarianDiet.update_forward_refs()
