@@ -14,7 +14,7 @@ class Vein(Vessel):
     See: https://schema.org/Vein
     Model depth: 5
     """
-    type_: str = Field("Vein", alias='@type')
+    type_: str = Field(default="Vein", alias='@type')
     tributary: Optional[Union[List[Union['AnatomicalStructure', str]], 'AnatomicalStructure', str]] = Field(
         default=None,
         description="The anatomical or organ system that the vein flows into; a larger structure that the vein"
@@ -24,14 +24,13 @@ class Vein(Vessel):
         default=None,
         description="The vasculature that the vein drains into.",
     )
-    regionDrained: Optional[Union[List[Union['AnatomicalSystem', 'AnatomicalStructure', str]], 'AnatomicalSystem', 'AnatomicalStructure', str]] = Field(
+    regionDrained: Optional[Union[List[Union['AnatomicalStructure', 'AnatomicalSystem', str]], 'AnatomicalStructure', 'AnatomicalSystem', str]] = Field(
         default=None,
         description="The anatomical or organ system drained by this vessel; generally refers to a specific"
      "part of an organ.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.AnatomicalStructure import AnatomicalStructure
     from pydantic_schemaorg.Vessel import Vessel
