@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalOrganization import MedicalOrganization
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MedicalOrganization import MedicalOrganization
 class VeterinaryCare(MedicalOrganization):
     """A vet's office.
 
-    See https://schema.org/VeterinaryCare.
-
+    See: https://schema.org/VeterinaryCare
+    Model depth: 4
     """
-    type_: str = Field("VeterinaryCare", const=True, alias='@type')
+    type_: str = Field(default="VeterinaryCare", alias='@type')
     
-
-VeterinaryCare.update_forward_refs()
