@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MediaGallery import MediaGallery
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MediaGallery import MediaGallery
 class VideoGallery(MediaGallery):
     """Web page type: Video gallery page.
 
-    See https://schema.org/VideoGallery.
-
+    See: https://schema.org/VideoGallery
+    Model depth: 6
     """
-    type_: str = Field("VideoGallery", const=True, alias='@type')
+    type_: str = Field(default="VideoGallery", alias='@type')
     
-
-VideoGallery.update_forward_refs()
