@@ -17,7 +17,7 @@ class VideoGame(Game, SoftwareApplication):
     See: https://schema.org/VideoGame
     Model depth: 4
     """
-    type_: str = Field("VideoGame", alias='@type')
+    type_: str = Field(default="VideoGame", alias='@type')
     actors: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="An actor, e.g. in tv, radio, movie, video games etc. Actors can be associated with individual"
@@ -70,7 +70,6 @@ class VideoGame(Game, SoftwareApplication):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.VideoObject import VideoObject
