@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Clip import Clip
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Clip import Clip
 class VideoGameClip(Clip):
     """A short segment/part of a video game.
 
-    See https://schema.org/VideoGameClip.
-
+    See: https://schema.org/VideoGameClip
+    Model depth: 4
     """
-    type_: str = Field("VideoGameClip", const=True, alias='@type')
+    type_: str = Field(default="VideoGameClip", alias='@type')
     
-
-VideoGameClip.update_forward_refs()
