@@ -14,7 +14,7 @@ class VideoObject(MediaObject):
     See: https://schema.org/VideoObject
     Model depth: 4
     """
-    type_: str = Field("VideoObject", alias='@type')
+    type_: str = Field(default="VideoObject", alias='@type')
     actors: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="An actor, e.g. in tv, radio, movie, video games etc. Actors can be associated with individual"
@@ -66,7 +66,6 @@ class VideoObject(MediaObject):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
     from pydantic_schemaorg.ImageObject import ImageObject
