@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.VideoObject import VideoObject
 
@@ -9,10 +12,8 @@ class VideoObjectSnapshot(VideoObject):
      "e.g. creator or dateCreated that aren't represented in their actual content, do not"
      "affect this notion of identity.
 
-    See https://schema.org/VideoObjectSnapshot.
-
+    See: https://schema.org/VideoObjectSnapshot
+    Model depth: 5
     """
-    type_: str = Field("VideoObjectSnapshot", const=True, alias='@type')
+    type_: str = Field(default="VideoObjectSnapshot", alias='@type')
     
-
-VideoObjectSnapshot.update_forward_refs()
