@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ConsumeAction import ConsumeAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ConsumeAction import ConsumeAction
 class ViewAction(ConsumeAction):
     """The act of consuming static visual content.
 
-    See https://schema.org/ViewAction.
-
+    See: https://schema.org/ViewAction
+    Model depth: 4
     """
-    type_: str = Field("ViewAction", const=True, alias='@type')
+    type_: str = Field(default="ViewAction", alias='@type')
     
-
-ViewAction.update_forward_refs()
