@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Intangible import Intangible
 
@@ -8,10 +11,8 @@ class VirtualLocation(Intangible):
      "an event, virtual locations should not be confused with physical locations in the real"
      "world.
 
-    See https://schema.org/VirtualLocation.
-
+    See: https://schema.org/VirtualLocation
+    Model depth: 3
     """
-    type_: str = Field("VirtualLocation", const=True, alias='@type')
+    type_: str = Field(default="VirtualLocation", alias='@type')
     
-
-VirtualLocation.update_forward_refs()
