@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.InfectiousAgentClass import InfectiousAgentClass
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.InfectiousAgentClass import InfectiousAgentClass
 class Virus(InfectiousAgentClass):
     """Pathogenic virus that causes viral infection.
 
-    See https://schema.org/Virus.
-
+    See: https://schema.org/Virus
+    Model depth: 6
     """
-    type_: str = Field("Virus", const=True, alias='@type')
+    type_: str = Field(default="Virus", alias='@type')
     
-
-Virus.update_forward_refs()
