@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Event import Event
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.Event import Event
 class VisualArtsEvent(Event):
     """Event type: Visual arts event.
 
-    See https://schema.org/VisualArtsEvent.
-
+    See: https://schema.org/VisualArtsEvent
+    Model depth: 3
     """
-    type_: str = Field("VisualArtsEvent", const=True, alias='@type')
+    type_: str = Field(default="VisualArtsEvent", alias='@type')
     
-
-VisualArtsEvent.update_forward_refs()
