@@ -15,7 +15,7 @@ class VisualArtwork(CreativeWork):
     See: https://schema.org/VisualArtwork
     Model depth: 3
     """
-    type_: str = Field("VisualArtwork", alias='@type')
+    type_: str = Field(default="VisualArtwork", alias='@type')
     artworkSurface: Optional[Union[List[Union[AnyUrl, 'URL', str, 'Text']], AnyUrl, 'URL', str, 'Text']] = Field(
         default=None,
         description="The supporting materials for the artwork, e.g. Canvas, Paper, Wood, Board, etc.",
@@ -75,7 +75,6 @@ class VisualArtwork(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.Text import Text
