@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MedicalSign import MedicalSign
 
@@ -6,10 +9,8 @@ class VitalSign(MedicalSign):
     """Vital signs are measures of various physiological functions in order to assess the most"
      "basic body functions.
 
-    See https://schema.org/VitalSign.
-
+    See: https://schema.org/VitalSign
+    Model depth: 6
     """
-    type_: str = Field("VitalSign", const=True, alias='@type')
+    type_: str = Field(default="VitalSign", alias='@type')
     
-
-VitalSign.update_forward_refs()
