@@ -14,13 +14,12 @@ class VoteAction(ChooseAction):
     See: https://schema.org/VoteAction
     Model depth: 5
     """
-    type_: str = Field("VoteAction", alias='@type')
+    type_: str = Field(default="VoteAction", alias='@type')
     candidate: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="A sub property of object. The candidate subject of this action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
