@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WebPageElement import WebPageElement
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WebPageElement import WebPageElement
 class WPFooter(WebPageElement):
     """The footer section of the page.
 
-    See https://schema.org/WPFooter.
-
+    See: https://schema.org/WPFooter
+    Model depth: 4
     """
-    type_: str = Field("WPFooter", const=True, alias='@type')
+    type_: str = Field(default="WPFooter", alias='@type')
     
-
-WPFooter.update_forward_refs()
