@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WebPageElement import WebPageElement
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WebPageElement import WebPageElement
 class WPSideBar(WebPageElement):
     """A sidebar section of the page.
 
-    See https://schema.org/WPSideBar.
-
+    See: https://schema.org/WPSideBar
+    Model depth: 4
     """
-    type_: str = Field("WPSideBar", const=True, alias='@type')
+    type_: str = Field(default="WPSideBar", alias='@type')
     
-
-WPSideBar.update_forward_refs()
