@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ReactAction import ReactAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ReactAction import ReactAction
 class WantAction(ReactAction):
     """The act of expressing a desire about the object. An agent wants an object.
 
-    See https://schema.org/WantAction.
-
+    See: https://schema.org/WantAction
+    Model depth: 5
     """
-    type_: str = Field("WantAction", const=True, alias='@type')
+    type_: str = Field(default="WantAction", alias='@type')
     
-
-WantAction.update_forward_refs()
