@@ -15,7 +15,7 @@ class WarrantyPromise(StructuredValue):
     See: https://schema.org/WarrantyPromise
     Model depth: 4
     """
-    type_: str = Field("WarrantyPromise", alias='@type')
+    type_: str = Field(default="WarrantyPromise", alias='@type')
     warrantyScope: Optional[Union[List[Union['WarrantyScope', str]], 'WarrantyScope', str]] = Field(
         default=None,
         description="The scope of the warranty promise.",
@@ -27,7 +27,6 @@ class WarrantyPromise(StructuredValue):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.WarrantyScope import WarrantyScope
     from pydantic_schemaorg.QuantitativeValue import QuantitativeValue
