@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Enumeration import Enumeration
 
@@ -7,10 +10,8 @@ class WarrantyScope(Enumeration):
      "or malfunction of a product. Commonly used values: * http://purl.org/goodrelations/v1#Labor-BringIn"
      "* http://purl.org/goodrelations/v1#PartsAndLabor-BringIn * http://purl.org/goodrelations/v1#PartsAndLabor-PickUp
 
-    See https://schema.org/WarrantyScope.
-
+    See: https://schema.org/WarrantyScope
+    Model depth: 4
     """
-    type_: str = Field("WarrantyScope", const=True, alias='@type')
+    type_: str = Field(default="WarrantyScope", alias='@type')
     
-
-WarrantyScope.update_forward_refs()
