@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.ConsumeAction import ConsumeAction
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.ConsumeAction import ConsumeAction
 class WatchAction(ConsumeAction):
     """The act of consuming dynamic/moving visual content.
 
-    See https://schema.org/WatchAction.
-
+    See: https://schema.org/WatchAction
+    Model depth: 4
     """
-    type_: str = Field("WatchAction", const=True, alias='@type')
+    type_: str = Field(default="WatchAction", alias='@type')
     
-
-WatchAction.update_forward_refs()
