@@ -11,6 +11,5 @@ class Waterfall(BodyOfWater):
     See: https://schema.org/Waterfall
     Model depth: 5
     """
-    type_: str = Field("Waterfall", alias='@type')
+    type_: str = Field(default="Waterfall", alias='@type')
     
-
