@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasur
 class WearableMeasurementBack(WearableMeasurementTypeEnumeration):
     """Measurement of the back section, for example of a jacket
 
-    See https://schema.org/WearableMeasurementBack.
-
+    See: https://schema.org/WearableMeasurementBack
+    Model depth: 6
     """
-    type_: str = Field("WearableMeasurementBack", const=True, alias='@type')
+    type_: str = Field(default="WearableMeasurementBack", alias='@type')
     
-
-WearableMeasurementBack.update_forward_refs()
