@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasur
 class WearableMeasurementChestOrBust(WearableMeasurementTypeEnumeration):
     """Measurement of the chest/bust section, for example of a suit
 
-    See https://schema.org/WearableMeasurementChestOrBust.
-
+    See: https://schema.org/WearableMeasurementChestOrBust
+    Model depth: 6
     """
-    type_: str = Field("WearableMeasurementChestOrBust", const=True, alias='@type')
+    type_: str = Field(default="WearableMeasurementChestOrBust", alias='@type')
     
-
-WearableMeasurementChestOrBust.update_forward_refs()
