@@ -11,6 +11,5 @@ class WearableMeasurementCollar(WearableMeasurementTypeEnumeration):
     See: https://schema.org/WearableMeasurementCollar
     Model depth: 6
     """
-    type_: str = Field("WearableMeasurementCollar", alias='@type')
+    type_: str = Field(default="WearableMeasurementCollar", alias='@type')
     
-
