@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasur
 class WearableMeasurementHips(WearableMeasurementTypeEnumeration):
     """Measurement of the hip section, for example of a skirt
 
-    See https://schema.org/WearableMeasurementHips.
-
+    See: https://schema.org/WearableMeasurementHips
+    Model depth: 6
     """
-    type_: str = Field("WearableMeasurementHips", const=True, alias='@type')
+    type_: str = Field(default="WearableMeasurementHips", alias='@type')
     
-
-WearableMeasurementHips.update_forward_refs()
