@@ -11,6 +11,5 @@ class WearableMeasurementInseam(WearableMeasurementTypeEnumeration):
     See: https://schema.org/WearableMeasurementInseam
     Model depth: 6
     """
-    type_: str = Field("WearableMeasurementInseam", alias='@type')
+    type_: str = Field(default="WearableMeasurementInseam", alias='@type')
     
-
