@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasur
 class WearableMeasurementLength(WearableMeasurementTypeEnumeration):
     """Represents the length, for example of a dress
 
-    See https://schema.org/WearableMeasurementLength.
-
+    See: https://schema.org/WearableMeasurementLength
+    Model depth: 6
     """
-    type_: str = Field("WearableMeasurementLength", const=True, alias='@type')
+    type_: str = Field(default="WearableMeasurementLength", alias='@type')
     
-
-WearableMeasurementLength.update_forward_refs()
