@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasur
 class WearableMeasurementOutsideLeg(WearableMeasurementTypeEnumeration):
     """Measurement of the outside leg, for example of pants
 
-    See https://schema.org/WearableMeasurementOutsideLeg.
-
+    See: https://schema.org/WearableMeasurementOutsideLeg
+    Model depth: 6
     """
-    type_: str = Field("WearableMeasurementOutsideLeg", const=True, alias='@type')
+    type_: str = Field(default="WearableMeasurementOutsideLeg", alias='@type')
     
-
-WearableMeasurementOutsideLeg.update_forward_refs()
