@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasur
 class WearableMeasurementSleeve(WearableMeasurementTypeEnumeration):
     """Measurement of the sleeve length, for example of a shirt
 
-    See https://schema.org/WearableMeasurementSleeve.
-
+    See: https://schema.org/WearableMeasurementSleeve
+    Model depth: 6
     """
-    type_: str = Field("WearableMeasurementSleeve", const=True, alias='@type')
+    type_: str = Field(default="WearableMeasurementSleeve", alias='@type')
     
-
-WearableMeasurementSleeve.update_forward_refs()
