@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.MeasurementTypeEnumeration import MeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.MeasurementTypeEnumeration import MeasurementTypeEnumera
 class WearableMeasurementTypeEnumeration(MeasurementTypeEnumeration):
     """Enumerates common types of measurement for wearables products.
 
-    See https://schema.org/WearableMeasurementTypeEnumeration.
-
+    See: https://schema.org/WearableMeasurementTypeEnumeration
+    Model depth: 5
     """
-    type_: str = Field("WearableMeasurementTypeEnumeration", const=True, alias='@type')
+    type_: str = Field(default="WearableMeasurementTypeEnumeration", alias='@type')
     
-
-WearableMeasurementTypeEnumeration.update_forward_refs()
