@@ -11,6 +11,5 @@ class WearableMeasurementWaist(WearableMeasurementTypeEnumeration):
     See: https://schema.org/WearableMeasurementWaist
     Model depth: 6
     """
-    type_: str = Field("WearableMeasurementWaist", alias='@type')
+    type_: str = Field(default="WearableMeasurementWaist", alias='@type')
     
-
