@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasurementTypeEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableMeasurementTypeEnumeration import WearableMeasur
 class WearableMeasurementWidth(WearableMeasurementTypeEnumeration):
     """Measurement of the width, for example of shoes
 
-    See https://schema.org/WearableMeasurementWidth.
-
+    See: https://schema.org/WearableMeasurementWidth
+    Model depth: 6
     """
-    type_: str = Field("WearableMeasurementWidth", const=True, alias='@type')
+    type_: str = Field(default="WearableMeasurementWidth", alias='@type')
     
-
-WearableMeasurementWidth.update_forward_refs()
