@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupBig(WearableSizeGroupEnumeration):
     """Size group \"Big\" for wearables.
 
-    See https://schema.org/WearableSizeGroupBig.
-
+    See: https://schema.org/WearableSizeGroupBig
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupBig", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupBig", alias='@type')
     
-
-WearableSizeGroupBig.update_forward_refs()
