@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupBoys(WearableSizeGroupEnumeration):
     """Size group \"Boys\" for wearables.
 
-    See https://schema.org/WearableSizeGroupBoys.
-
+    See: https://schema.org/WearableSizeGroupBoys
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupBoys", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupBoys", alias='@type')
     
-
-WearableSizeGroupBoys.update_forward_refs()
