@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupHusky(WearableSizeGroupEnumeration):
     """Size group \"Husky\" (or \"Stocky\") for wearables.
 
-    See https://schema.org/WearableSizeGroupHusky.
-
+    See: https://schema.org/WearableSizeGroupHusky
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupHusky", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupHusky", alias='@type')
     
-
-WearableSizeGroupHusky.update_forward_refs()
