@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupJuniors(WearableSizeGroupEnumeration):
     """Size group \"Juniors\" for wearables.
 
-    See https://schema.org/WearableSizeGroupJuniors.
-
+    See: https://schema.org/WearableSizeGroupJuniors
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupJuniors", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupJuniors", alias='@type')
     
-
-WearableSizeGroupJuniors.update_forward_refs()
