@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupMens(WearableSizeGroupEnumeration):
     """Size group \"Mens\" for wearables.
 
-    See https://schema.org/WearableSizeGroupMens.
-
+    See: https://schema.org/WearableSizeGroupMens
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupMens", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupMens", alias='@type')
     
-
-WearableSizeGroupMens.update_forward_refs()
