@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupMisses(WearableSizeGroupEnumeration):
     """Size group \"Misses\" (also known as \"Missy\") for wearables.
 
-    See https://schema.org/WearableSizeGroupMisses.
-
+    See: https://schema.org/WearableSizeGroupMisses
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupMisses", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupMisses", alias='@type')
     
-
-WearableSizeGroupMisses.update_forward_refs()
