@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupPlus(WearableSizeGroupEnumeration):
     """Size group \"Plus\" for wearables.
 
-    See https://schema.org/WearableSizeGroupPlus.
-
+    See: https://schema.org/WearableSizeGroupPlus
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupPlus", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupPlus", alias='@type')
     
-
-WearableSizeGroupPlus.update_forward_refs()
