@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupRegular(WearableSizeGroupEnumeration):
     """Size group \"Regular\" for wearables.
 
-    See https://schema.org/WearableSizeGroupRegular.
-
+    See: https://schema.org/WearableSizeGroupRegular
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupRegular", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupRegular", alias='@type')
     
-
-WearableSizeGroupRegular.update_forward_refs()
