@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupTall(WearableSizeGroupEnumeration):
     """Size group \"Tall\" for wearables.
 
-    See https://schema.org/WearableSizeGroupTall.
-
+    See: https://schema.org/WearableSizeGroupTall
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupTall", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupTall", alias='@type')
     
-
-WearableSizeGroupTall.update_forward_refs()
