@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeGroupEnumeration import WearableSizeGroupEnu
 class WearableSizeGroupWomens(WearableSizeGroupEnumeration):
     """Size group \"Womens\" for wearables.
 
-    See https://schema.org/WearableSizeGroupWomens.
-
+    See: https://schema.org/WearableSizeGroupWomens
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeGroupWomens", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeGroupWomens", alias='@type')
     
-
-WearableSizeGroupWomens.update_forward_refs()
