@@ -11,6 +11,5 @@ class WearableSizeSystemAU(WearableSizeSystemEnumeration):
     See: https://schema.org/WearableSizeSystemAU
     Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemAU", alias='@type')
+    type_: str = Field(default="WearableSizeSystemAU", alias='@type')
     
-
