@@ -11,6 +11,5 @@ class WearableSizeSystemBR(WearableSizeSystemEnumeration):
     See: https://schema.org/WearableSizeSystemBR
     Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemBR", alias='@type')
+    type_: str = Field(default="WearableSizeSystemBR", alias='@type')
     
-
