@@ -11,6 +11,5 @@ class WearableSizeSystemContinental(WearableSizeSystemEnumeration):
     See: https://schema.org/WearableSizeSystemContinental
     Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemContinental", alias='@type')
+    type_: str = Field(default="WearableSizeSystemContinental", alias='@type')
     
-
