@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemE
 class WearableSizeSystemDE(WearableSizeSystemEnumeration):
     """German size system for wearables.
 
-    See https://schema.org/WearableSizeSystemDE.
-
+    See: https://schema.org/WearableSizeSystemDE
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemDE", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeSystemDE", alias='@type')
     
-
-WearableSizeSystemDE.update_forward_refs()
