@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemE
 class WearableSizeSystemEN13402(WearableSizeSystemEnumeration):
     """EN 13402 (joint European standard for size labelling of clothes).
 
-    See https://schema.org/WearableSizeSystemEN13402.
-
+    See: https://schema.org/WearableSizeSystemEN13402
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemEN13402", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeSystemEN13402", alias='@type')
     
-
-WearableSizeSystemEN13402.update_forward_refs()
