@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemE
 class WearableSizeSystemFR(WearableSizeSystemEnumeration):
     """French size system for wearables.
 
-    See https://schema.org/WearableSizeSystemFR.
-
+    See: https://schema.org/WearableSizeSystemFR
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemFR", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeSystemFR", alias='@type')
     
-
-WearableSizeSystemFR.update_forward_refs()
