@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemE
 class WearableSizeSystemGS1(WearableSizeSystemEnumeration):
     """GS1 (formerly NRF) size system for wearables.
 
-    See https://schema.org/WearableSizeSystemGS1.
-
+    See: https://schema.org/WearableSizeSystemGS1
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemGS1", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeSystemGS1", alias='@type')
     
-
-WearableSizeSystemGS1.update_forward_refs()
