@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemE
 class WearableSizeSystemIT(WearableSizeSystemEnumeration):
     """Italian size system for wearables.
 
-    See https://schema.org/WearableSizeSystemIT.
-
+    See: https://schema.org/WearableSizeSystemIT
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemIT", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeSystemIT", alias='@type')
     
-
-WearableSizeSystemIT.update_forward_refs()
