@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemE
 class WearableSizeSystemMX(WearableSizeSystemEnumeration):
     """Mexican size system for wearables.
 
-    See https://schema.org/WearableSizeSystemMX.
-
+    See: https://schema.org/WearableSizeSystemMX
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemMX", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeSystemMX", alias='@type')
     
-
-WearableSizeSystemMX.update_forward_refs()
