@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemEnumeration
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.WearableSizeSystemEnumeration import WearableSizeSystemE
 class WearableSizeSystemUK(WearableSizeSystemEnumeration):
     """United Kingdom size system for wearables.
 
-    See https://schema.org/WearableSizeSystemUK.
-
+    See: https://schema.org/WearableSizeSystemUK
+    Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemUK", const=True, alias='@type')
+    type_: str = Field(default="WearableSizeSystemUK", alias='@type')
     
-
-WearableSizeSystemUK.update_forward_refs()
