@@ -11,6 +11,5 @@ class WearableSizeSystemUS(WearableSizeSystemEnumeration):
     See: https://schema.org/WearableSizeSystemUS
     Model depth: 6
     """
-    type_: str = Field("WearableSizeSystemUS", alias='@type')
+    type_: str = Field(default="WearableSizeSystemUS", alias='@type')
     
-
