@@ -15,14 +15,13 @@ class WebAPI(Service):
     See: https://schema.org/WebAPI
     Model depth: 4
     """
-    type_: str = Field("WebAPI", alias='@type')
+    type_: str = Field(default="WebAPI", alias='@type')
     documentation: Optional[Union[List[Union[AnyUrl, 'URL', 'CreativeWork', str]], AnyUrl, 'URL', 'CreativeWork', str]] = Field(
         default=None,
         description="Further documentation describing the Web API in more detail.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.CreativeWork import CreativeWork
