@@ -14,7 +14,7 @@ class WebApplication(SoftwareApplication):
     See: https://schema.org/WebApplication
     Model depth: 4
     """
-    type_: str = Field("WebApplication", alias='@type')
+    type_: str = Field(default="WebApplication", alias='@type')
     browserRequirements: Optional[Union[List[Union[str, 'Text']], str, 'Text']] = Field(
         default=None,
         description="Specifies browser requirements in human-readable text. For example, 'requires HTML5"
@@ -22,6 +22,5 @@ class WebApplication(SoftwareApplication):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Text import Text
