@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.CreativeWork import CreativeWork
 
@@ -10,10 +13,8 @@ class WebContent(CreativeWork):
      "always be stated. (The intent is that the existing types [[WebPage]], [[WebSite]] and"
      "[[WebPageElement]] will eventually be declared as subtypes of [[WebContent]]).
 
-    See https://schema.org/WebContent.
-
+    See: https://schema.org/WebContent
+    Model depth: 3
     """
-    type_: str = Field("WebContent", const=True, alias='@type')
+    type_: str = Field(default="WebContent", alias='@type')
     
-
-WebContent.update_forward_refs()
