@@ -19,7 +19,7 @@ class WebPage(CreativeWork):
     See: https://schema.org/WebPage
     Model depth: 3
     """
-    type_: str = Field("WebPage", alias='@type')
+    type_: str = Field(default="WebPage", alias='@type')
     significantLink: Optional[Union[List[Union[AnyUrl, 'URL', str]], AnyUrl, 'URL', str]] = Field(
         default=None,
         description="One of the more significant URLs on the page. Typically, these are the non-navigation"
@@ -78,7 +78,6 @@ class WebPage(CreativeWork):
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.URL import URL
     from pydantic_schemaorg.SpeakableSpecification import SpeakableSpecification
