@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DayOfWeek import DayOfWeek
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DayOfWeek import DayOfWeek
 class Wednesday(DayOfWeek):
     """The day of the week between Tuesday and Thursday.
 
-    See https://schema.org/Wednesday.
-
+    See: https://schema.org/Wednesday
+    Model depth: 5
     """
-    type_: str = Field("Wednesday", const=True, alias='@type')
+    type_: str = Field(default="Wednesday", alias='@type')
     
-
-Wednesday.update_forward_refs()
