@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DrugCostCategory import DrugCostCategory
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DrugCostCategory import DrugCostCategory
 class Wholesale(DrugCostCategory):
     """The drug's cost represents the wholesale acquisition cost of the drug.
 
-    See https://schema.org/Wholesale.
-
+    See: https://schema.org/Wholesale
+    Model depth: 6
     """
-    type_: str = Field("Wholesale", const=True, alias='@type')
+    type_: str = Field(default="Wholesale", alias='@type')
     
-
-Wholesale.update_forward_refs()
