@@ -11,6 +11,5 @@ class WholesaleStore(Store):
     See: https://schema.org/WholesaleStore
     Model depth: 5
     """
-    type_: str = Field("WholesaleStore", alias='@type')
+    type_: str = Field(default="WholesaleStore", alias='@type')
     
-
