@@ -14,13 +14,12 @@ class WinAction(AchieveAction):
     See: https://schema.org/WinAction
     Model depth: 4
     """
-    type_: str = Field("WinAction", alias='@type')
+    type_: str = Field(default="WinAction", alias='@type')
     loser: Optional[Union[List[Union['Person', str]], 'Person', str]] = Field(
         default=None,
         description="A sub property of participant. The loser of the action.",
     )
     
 
-
 if TYPE_CHECKING:
     from pydantic_schemaorg.Person import Person
