@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.FoodEstablishment import FoodEstablishment
 class Winery(FoodEstablishment):
     """A winery.
 
-    See https://schema.org/Winery.
-
+    See: https://schema.org/Winery
+    Model depth: 5
     """
-    type_: str = Field("Winery", const=True, alias='@type')
+    type_: str = Field(default="Winery", alias='@type')
     
-
-Winery.update_forward_refs()
