@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.Organization import Organization
 
@@ -7,10 +10,8 @@ class WorkersUnion(Organization):
      "that promotes the interests of its worker members by collectively bargaining with management,"
      "organizing, and political lobbying.
 
-    See https://schema.org/WorkersUnion.
-
+    See: https://schema.org/WorkersUnion
+    Model depth: 3
     """
-    type_: str = Field("WorkersUnion", const=True, alias='@type')
+    type_: str = Field(default="WorkersUnion", alias='@type')
     
-
-WorkersUnion.update_forward_refs()
