@@ -1,3 +1,6 @@
+from __future__ import annotations
+
+
 from pydantic import Field
 from pydantic_schemaorg.DigitalDocumentPermissionType import DigitalDocumentPermissionType
 
@@ -5,10 +8,8 @@ from pydantic_schemaorg.DigitalDocumentPermissionType import DigitalDocumentPerm
 class WritePermission(DigitalDocumentPermissionType):
     """Permission to write or edit the document.
 
-    See https://schema.org/WritePermission.
-
+    See: https://schema.org/WritePermission
+    Model depth: 5
     """
-    type_: str = Field("WritePermission", const=True, alias='@type')
+    type_: str = Field(default="WritePermission", alias='@type')
     
-
-WritePermission.update_forward_refs()
